<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class BranchController extends Controller
{

    public function getBranches(Request $request)
    {
        $branches = Branch::all();
        return view("branches", compact("branches"));
    }

    public function ajaxBranches(Request $request)
    {
        $branches = Branch::all();

        $main_json = [];
        $i = 0;

        foreach ($branches as $branch) {
            if ($branch->branch_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $branch->branch_name;
            $main_json[$i][$v++] = $branch->branch_phone_number;
            $main_json[$i][$v++] = $branch->branch_email;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $branch->branch_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $branch->id . '" class="menu-link px-3 editBranch">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $branch->id . '"
                    class="menu-link px-3 deleteBranch"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function createBranch(Request $request)
    {
        $branch = new Branch();
        $branch->branch_name = $request->branchName;
        $branch->branch_logo = $request->branchLogo;
        $branch->branch_address = $request->branchAddress;
        $branch->branch_phone_number = $request->branchPhoneNumber;
        $branch->branch_email = $request->branchEmail;
        $branch->branch_website = $request->branchWebsite;
        $branch->save();

        return response()->json(["status" => "success"]);
    }

    public function editBranchForm(Request $request)
    {
        $branch = Branch::find($request->branchId);
        $branchStatus = $branch->branch_status === 'Active' ? 'checked' : '';
        $title = "Edit Branch";
        $body = "";
        $body .= '
                <form id="editBranchForm">
                <input value="' . $branch->id . '" name="branchId" class="d-none">
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter branch name" name="branchName" value="' . $branch->branch_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Phone Number</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter branch phone number" name="branchPhoneNumber" value="' . $branch->branch_phone_number . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Email</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="email" class="form-control form-control-solid" placeholder="Enter branch email" name="branchEmail" value="' . $branch->branch_email . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Website</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter branch website" name="branchWebsite" value="' . $branch->branch_website . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Address</label>
                    <!--end::Label-->
                    <!--begin::Text Area-->
                    <textarea name="branchAddress" placeholder="Enter branch address" class="form-control form-control-solid h-100px">' . $branch->branch_address . '</textarea>
                    <!--end::Text Area-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="branchStatus" name="branchStatus" ' . $branchStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="branchStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
                </form>
                           ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editBranch(Request $request)
    {
        $branch = Branch::where("id", $request->branchId)->first();
        $branch->branch_name = $request->branchName;
        $branch->branch_address = $request->branchAddress;
        $branch->branch_website = $request->branchWebsite;
        $branch->branch_phone_number = $request->branchPhoneNumber;
        $branch->branch_email = $request->branchEmail;
        if ($request->branchStatus) {
            $branch->branch_status = $request->branchStatus;
        } else {
            $branch->branch_status = "Inactive";
        }
        $branch->save();

        return response()->json(["status" => "success"]);
    }

    public function deleteBranch(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'branch_id')) {
                $hasBranchId = DB::table($table)->where('branch_id', $request->branchId)->exists();
                if ($hasBranchId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Branch has data!"]);
                }
            }
        }
        Branch::where("id", $request->branchId)->delete();
        return response()->json(["status" => "success"]);
    }
}
