<?php

namespace App\Http\Controllers;

use App\Models\Contact;
use App\Models\ContactGroup;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class ContactController extends Controller
{

    public function getContacts(Request $request)
    {
        $contacts = Contact::all();
        $contactGroups = ContactGroup::all();
        return view("contacts", compact("contacts", "contactGroups"));
    }

    public function ajaxContacts(Request $request)
    {
        $contacts = Contact::all();
        $main_json = [];
        $i = 0;

        foreach ($contacts as $contact) {
            if ($contact->contact_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $type_badge = $contact->contact_type === "BASIC" ? "badge-warning" : "badge-info";
            $v = 0;
            $main_json[$i][$v++] = $contact->contact_name;
            $main_json[$i][$v++] = '<span class="badge ' . $type_badge . '">' . $contact->contact_type . '</span>';
            $main_json[$i][$v++] = $contact->contact_email;
            $main_json[$i][$v++] = $contact->contact_phone_number;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $contact->contact_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $contact->id . '" class="menu-link px-3 editContact">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $contact->id . '"
                    class="menu-link px-3 deleteContact"
                    data-kt-contact-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function createContact(Request $request)
    {
        $contact = new Contact();
        $contact->contact_name = $request->contactName;
        $contact->contact_phone_number = $request->contactPhoneNumber;
        $contact->contact_email = $request->contactEmail;
        $contact->contact_address = $request->contactAddress;
        $contact->contact_type = $request->contactType;
        $contact->contact_status = isset($request->contactStatus) ? $request->contactStatus : "Active";
        $contact->save();

        return response()->json(["status" => "success"]);
    }

    public function editContactForm(Request $request)
    {

        $contact = Contact::find($request->contactId);
        $contactStatus = $contact->contact_status === 'Active' ? 'checked' : '';

        $basic_selected = $contact->contact_type === 'BASIC' ? 'selected' : '';
        $premium_selected = $contact->contact_type === 'PREMIUM' ? 'selected' : '';
        $title = "Edit Contact";
        $body = "";

        $body .= '
                <form id="editContactForm">
                <input value="' . $contact->id . '" name="contactId" class="d-none">
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter contact name" name="contactName" value="' . $contact->contact_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Select Contact Type</label>
                    <!--end::Label-->

                    <!--begin::Select-->
                    <select class="contactType" data-width="100%" data-live-search="true" name="contactType" data-placeholder="Select Contact Type" data-dropdown-parent="#emptyModal">
                        <option value="BASIC" ' . $basic_selected . '>BASIC</option>
                        <option value="PREMIUM" ' . $premium_selected . '>PREMIUM</option>
                        </select>
                    <!--end::Select-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Phone Number</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter contact phone number" name="contactPhoneNumber" value="' . $contact->contact_phone_number . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Email</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <input type="email" class="form-control form-control-solid" placeholder="Enter contact email" name="contactEmail" value="' . $contact->contact_email . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Address</label>
                    <!--end::Label-->
                    <!--begin::Text Area-->
                    <textarea name="contactAddress" placeholder="Enter contact address" class="form-control form-control-solid h-100px">' . $contact->contact_address . '</textarea>
                    <!--end::Text Area-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="contactStatus" name="contactStatus" ' . $contactStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="contactStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
                </form>
                           ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editContact(Request $request)
    {
        $contact = Contact::where("id", $request->contactId)->first();
        $contact->contact_name = $request->contactName;
        $contact->contact_phone_number = $request->contactPhoneNumber;
        $contact->contact_email = $request->contactEmail;
        $contact->contact_type = $request->contactType;
        if (isset($request->contactStatus)) {
            $contact->contact_status = $request->contactStatus;
        } else {
            $contact->contact_status = "Inactive";
        }
        $contact->contact_address = $request->contactAddress;
        $contact->save();

        return response()->json(["status" => "success"]);
    }

    public function deleteContact(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'contact_id')) {
                $hasBranchId = DB::table($table)->where('contact_id', $request->branchId)->exists();
                if ($hasBranchId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Contact has data!"]);
                }
            }
        }
        Contact::where("id", $request->contactId)->delete();
        return response()->json(["status" => "success"]);
    }
}
