<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\ItemOrder;
use App\Models\Item;
use App\Models\ItemPurchase;
use App\Models\ItemWaste;
use App\Models\OrderPayment;
use App\Models\PurchasePayment;
use App\Models\Waste;
use App\Models\Purchase;
use App\Models\ItemCategory;
use App\Models\Transaction;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class DashboardController extends Controller
{
    public function getDashboard(Request $request)
    {
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->startOfMonth()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : Carbon::parse($startDate)->endOfMonth()->format('Y-m-d');
        return view("dashboard", compact("startDate", "endDate"));
    }

    public function getMonthSummary(Request $request)
    {
        $orders = Order::orderByDesc("id")->get();
        $purchases = Purchase::orderByDesc("id")->get();
        $wastes = Waste::orderByDesc("id")->get();

        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->startOfMonth()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : Carbon::parse($startDate)->endOfMonth()->format('Y-m-d');

        $lastStartDate = Carbon::parse($startDate)->subMonth()->startOfMonth()->format('Y-m-d');
        $lastEndDate = Carbon::parse($endDate)->subMonth()->endOfMonth()->format('Y-m-d');

        $lastOrderIds = $orders->whereBetween("order_date", [$lastStartDate, $lastEndDate])->whereIn("order_status", ["Paid", "Settled"])->pluck("id")->toArray();
        $orderIds = $orders->whereBetween("order_date", [$startDate, $endDate])->whereIn("order_status", ["Paid", "Settled"])->pluck("id")->toArray();
        $itemOrders = ItemOrder::whereIn("order_id", $orderIds)->get();
        $lastItemOrders = ItemOrder::whereIn("order_id", $lastOrderIds)->get();

        $orderPayments = OrderPayment::whereIn("order_id", $orderIds)->get();
        $lastOrderPayments = OrderPayment::whereIn("order_id", $lastOrderIds)->get();

        // dd($orders);
        $totalSales = $itemOrders->map(function ($itemOrder) {
            
            return $itemOrder->order_price;
        })->sum();

        // dd($totalSales);

        $lastTotalSales = $lastItemOrders->map(function ($itemOrder) {
            return $itemOrder->order_price;
        })->sum();

        $changeOrderIds = $orderPayments->whereBetween("payment_date", [$startDate, $endDate])->pluck("order_id");
        $changeAmount = Order::whereIn("id", $changeOrderIds)->sum("change_amount");
        $lastChangeOrderIds = $lastOrderPayments->whereBetween("payment_date", [$startDate, $endDate])->pluck("order_id");
        $lastChangeAmount = Order::whereIn("id", $lastChangeOrderIds)->sum("change_amount");

        $paidSales = $orderPayments->whereBetween("payment_date", [$startDate, $endDate])->sum("payment_amount") - $changeAmount;
        $indebtSales = $totalSales - $paidSales;

        $lastPaidSales = $lastOrderPayments->whereBetween("payment_date", [$startDate, $endDate])->sum("payment_amount") - $lastChangeAmount;
        $lastIndebtSales = $lastTotalSales - $lastPaidSales;

        $lastPurchaseIds = $purchases->whereBetween("purchase_date", [$lastStartDate, $lastEndDate])->pluck("id")->toArray();
        $purchaseIds = $purchases->whereBetween("purchase_date", [$startDate, $endDate])->pluck("id")->toArray();
        $itemPurchases = ItemPurchase::whereIn("purchase_id", $purchaseIds)->get();
        $lastItemPurchases = ItemPurchase::whereIn("purchase_id", $lastPurchaseIds)->get();

        $purchasePayments = PurchasePayment::whereIn("purchase_id", $purchaseIds)->get();
        $lastPurchasePayments = PurchasePayment::whereIn("purchase_id", $lastPurchaseIds)->get();

        $totalPurchases = $itemPurchases->map(function ($itemPurchase) {
            return $itemPurchase->cost_price;
        })->sum();

        $lastTotalPurchases = $lastItemPurchases->map(function ($itemPurchase) {
            return $itemPurchase->cost_price;
        })->sum();

        $paidPurchases = $purchasePayments->whereBetween("payment_date", [$startDate, $endDate])->sum("payment_amount");
        $indebtPurchases = $totalPurchases - $paidPurchases;

        $lastPaidPurchases = $lastPurchasePayments->whereBetween("payment_date", [$startDate, $endDate])->sum("payment_amount") - $lastChangeAmount;
        $lastIndebtPurchases = $lastTotalPurchases - $lastPaidPurchases;

        $totalWastes = Waste::whereBetween("waste_date", [Carbon::parse($startDate)->format("Y-m-d"), Carbon::parse($endDate)->format("Y-m-d")])
            ->with('itemWastes')
            ->get()
            ->flatMap(function ($waste) {
                return $waste->itemWastes;
            })
            ->sum(function ($itemWaste) {
                return $itemWaste->waste_quantity * $itemWaste->waste_price;
            });

        $lastTotalWastes = Waste::whereBetween("waste_date", [Carbon::parse($lastStartDate)->format("Y-m-d"), Carbon::parse($lastEndDate)->format("Y-m-d")])
            ->with('itemWastes')
            ->get()
            ->flatMap(function ($waste) {
                return $waste->itemWastes;
            })
            ->sum(function ($itemWaste) {
                return $itemWaste->waste_quantity * $itemWaste->waste_price;
            });


        // $lastWasteIds = $wastes->whereBetween("waste_date", [$lastStartDate, $lastEndDate])->pluck("id")->toArray();
        // $wasteIds = Waste::whereBetween("waste_date", [$startDate, $endDate])->pluck("id")->toArray();
        // $itemWastes = ItemWaste::whereIn("waste_id", $wasteIds)->get();
        // $lastItemWastes = ItemWaste::whereIn("waste_id", $lastWasteIds)->get();

        // $totalWastes = $itemWastes->map(function ($itemWaste) {
        //     return $itemWaste->waste_price * $itemWaste->waste_quantity;
        // })->sum();
        // $lastTotalWastes = $lastItemWastes->map(function ($itemWaste) {
        //     return $itemWaste->waste_price * $itemWaste->waste_quantity;
        // })->sum();


        // $totalIncome = $paidSales + $indebtPurchases;
        $lastTotalIncome = $lastPaidSales + $lastIndebtPurchases;

        // $totalExpense = $indebtSales + $paidPurchases + $totalWastes;
        $lastTotalExpense = $lastIndebtSales + $lastPaidPurchases + $lastTotalWastes;

        $totalIncome = $totalSales;
        $totalExpense = $totalPurchases + $totalWastes;
        
        $totalNetProfit = $totalIncome - $totalExpense;
        $lastTotalNetProfit = $lastTotalIncome - $lastTotalExpense;


        $totalSalesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($totalSales < $lastTotalSales) {
            $totalSalesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $totalSales = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($totalSales, 2) . '</div>' . $totalSalesIcon;
        $paidSalesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($paidSales < $lastPaidSales) {
            $paidSalesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $paidSales = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($paidSales, 2) . '</div>' . $paidSalesIcon;

        $indebtSalesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($indebtSales < $lastIndebtSales) {
            $indebtSalesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $indebtSales = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($indebtSales, 2) . '</div>' . $indebtSalesIcon;

        $totalPurchasesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($totalPurchases < $lastTotalPurchases) {
            $totalPurchasesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $totalPurchases = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($totalPurchases, 2) . '</div>' . $totalPurchasesIcon;
        $paidPurchasesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($paidPurchases < $lastPaidPurchases) {
            $paidPurchasesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $paidPurchases = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($paidPurchases, 2) . '</div>' . $paidPurchasesIcon;

        $indebtPurchasesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($indebtPurchases < $lastIndebtPurchases) {
            $indebtPurchasesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $indebtPurchases = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($indebtPurchases, 2) . '</div>' . $indebtPurchasesIcon;


        $totalWastesIcon = '<i class="ki-duotone ki-arrow-up fs-5 text-success ms-1"><span class="path1"></span><span class="path2"></span></i>';
        if ($totalWastes < $lastTotalWastes) {
            $totalWastesIcon = '<i class="ki-duotone ki-arrow-down fs-5 text-danger ms-1"><span class="path1"></span><span class="path2"></span></i>';
        }

        $totalWastes = '<div class="fw-bold fs-7 text-gray-800 pe-1">₦' . number_format($totalWastes, 2) . '</div>' . $totalWastesIcon;


        return response()->json(["status" => "success", "totalWastes" => $totalWastes, "totalSales" => $totalSales, "paidSales" => $paidSales, "indebtSales" => $indebtSales, "totalPurchases" => $totalPurchases, "paidPurchases" => $paidPurchases, "indebtPurchases" => $indebtPurchases, "netProfit" => number_format($totalNetProfit, 2)]);
    }

    public function monthlySalesAnalysis(Request $request)
    {

        $startDate = Carbon::createFromFormat('Y-m-d', $request->startDate);
        $endDate = Carbon::createFromFormat('Y-m-d', $request->endDate);

        $dateArray = [];
        $dates = [];
        $labels = [];

        while ($startDate <= $endDate) {
            $dateArray[] = $startDate->toDateString();
            $startDate->addDay();
        }

        $totalItemsAmount = 0;
        foreach ($dateArray as $date) {
            $orderIds = Order::where('order_date', $date)->whereIn("order_status", ["Paid", "Settled"])->pluck("id")->toArray();
            $itemOrders = ItemOrder::whereIn("order_id", $orderIds)->get();
            $totalItemsAmount = $itemOrders->sum("order_price");
            $labels[] = $totalItemsAmount;
            $dates[] = Carbon::parse($date)->format("D, d M Y");
        }

        return response()->json(["status" => "success", "labels" => $dates, "data" => $labels, "totalSaleAmount" => number_format($totalItemsAmount, 2)]);
    }

    public function saleItemsSummary(Request $request)
    {

        $itemIds = [];

        $startDate = $request->startDate;
        $endDate = $request->endDate;
        $orders = Order::orderByDesc("id");
        $orderIds = $orders->whereBetween("order_date", [$startDate, $endDate])->whereIn("order_status", ["Paid", "Settled"])->pluck("id")->toArray();

        $itemOrders = ItemOrder::whereIn("order_id", $orderIds)->get();
        $itemIds = $itemOrders->map(function ($itemOrder) {
            return $itemOrder->itemPurchase->item->id;
        })->toArray();

        $items = Item::whereIn("id", array_unique($itemIds))->orderByDesc("id")->get();

        $itemOrdersGrouped = collect($itemOrders)->groupBy(function ($itemOrder) {
            return $itemOrder->itemPurchase->item_id;
        })->map(function ($groupedOrders) {
            return [
                'total_quantity' => $groupedOrders->sum('order_quantity'),
                'total_amount' => $groupedOrders->sum('order_price'),
            ];
        })->toArray();

        $allSaleItems = [];
        foreach ($items as $item) {
            $itemCategoryName = $item->itemCategory->item_category_name;
            $itemName = $item->item_name;
            $totalAmount = $itemOrdersGrouped[$item->id]['total_amount'] ?? 0;
            $totalQuantity = $itemOrdersGrouped[$item->id]['total_quantity'] ?? 0;
            $allSaleItems[] = ["category_name" => $itemCategoryName, "sale_item_name" => $itemName, "sale_item_quantity" => $totalQuantity, "sale_item_amount" => $totalAmount];
        }

        usort($allSaleItems, function ($a, $b) {
            if ($a['sale_item_quantity'] === $b['sale_item_quantity']) {
                return $b['sale_item_amount'] <=> $a['sale_item_amount'];
            }
            return $b['sale_item_quantity'] <=> $a['sale_item_quantity'];
        });

        $top10QtyItems = array_slice($allSaleItems, 0, 10);

        usort($allSaleItems, function ($a, $b) {
            if ($a['sale_item_amount'] === $b['sale_item_amount']) {
                return $b['sale_item_quantity'] <=> $a['sale_item_quantity'];
            }
            return $b['sale_item_amount'] <=> $a['sale_item_amount'];
        });

        $top10AmountItems = array_slice($allSaleItems, 0, 10);

        usort($allSaleItems, function ($a, $b) {
            return $a['sale_item_amount'] <=> $b['sale_item_amount'];
        });

        $bottom10AmountItems = array_slice($allSaleItems, 0, 10);

        $highSaleItemsQty = "";
        $lowSaleItemsAmt = "";
        $bestSaleItemsAmt = "";

        if (count($top10QtyItems) > 0) {
            foreach ($top10QtyItems as $top10QtyItem) {
                $highSaleItemsQty .= '<div class="d-flex align-items-center mt-2 mb-2">
                                    <!--begin::Symbol-->
                                    <div class="symbol symbol-30px me-5 d-none">
                                                    <span class="symbol-label">
                                                        <i class="ki-duotone ki-abstract-25 fs-3 text-gray-600"><span class="path1"></span><span
                                                                class="path2"></span></i>
                                                    </span>
                                    </div>
                                    <!--end::Symbol-->

                                    <!--begin::Container-->
                                    <div class="d-flex align-items-center flex-stack flex-wrap d-grid gap-1 flex-row-fluid">
                                        <!--begin::Content-->
                                        <div class="me-5">
                                            <!--begin::Title-->
                                            <a href="#" class="text-gray-800 fw-bold text-hover-primary fs-8">' . $top10QtyItem["sale_item_name"] . ' (' . intval($top10QtyItem["sale_item_quantity"]) . ')</a>
                                            <!--end::Title-->

                                            <!--begin::Desc-->
                                            <span class="text-gray-400 fw-semibold fs-10 d-block text-start ps-0">' . $top10QtyItem["category_name"] . '</span>
                                            <!--end::Desc-->
                                        </div>
                                        <!--end::Content-->

                                        <!--begin::Wrapper-->
                                        <div class="d-flex align-items-center">
                                            <!--begin::Number-->
                                            <span class="text-gray-800 fw-bold fs-8 me-3">₦' . number_format($top10QtyItem["sale_item_amount"], 2) . '</span>
                                            <!--end::Number-->
                                        </div>
                                        <!--end::Wrapper-->
                                    </div>
                                    <!--end::Container-->
                                </div>';
            }
        } else {
            $highSaleItemsQty = '<div class="card-body">
                                    <div class="mt-0 d-flex flex-column align-items-center justify-content-center"><img style="width:100px;" src="' . url("empty.png") . '"><p class="text-center" style="font-weight:900;!important;">No Items!</p>
                                    </div>
                                 </div>';
        }

        if (count($top10AmountItems) > 0) {
            foreach ($top10AmountItems as $top10QtyItem) {
                $bestSaleItemsAmt .= '<div class="d-flex align-items-center mt-2 mb-2">
                                    <!--begin::Symbol-->
                                    <div class="symbol symbol-30px me-5 d-none">
                                                    <span class="symbol-label">
                                                        <i class="ki-duotone ki-abstract-25 fs-3 text-gray-600"><span class="path1"></span><span
                                                                class="path2"></span></i>
                                                    </span>
                                    </div>
                                    <!--end::Symbol-->

                                    <!--begin::Container-->
                                    <div class="d-flex align-items-center flex-stack flex-wrap d-grid gap-1 flex-row-fluid">
                                        <!--begin::Content-->
                                        <div class="me-5">
                                            <!--begin::Title-->
                                            <a href="#" class="text-gray-800 fw-bold text-hover-primary fs-8">' . $top10QtyItem["sale_item_name"] . ' (' . intval($top10QtyItem["sale_item_quantity"]) . ')</a>
                                            <!--end::Title-->

                                            <!--begin::Desc-->
                                            <span class="text-gray-400 fw-semibold fs-10 d-block text-start ps-0">' . $top10QtyItem["category_name"] . '</span>
                                            <!--end::Desc-->
                                        </div>
                                        <!--end::Content-->

                                        <!--begin::Wrapper-->
                                        <div class="d-flex align-items-center">
                                            <!--begin::Number-->
                                            <span class="text-gray-800 fw-bold fs-8 me-3">₦' . number_format($top10QtyItem["sale_item_amount"], 2) . '</span>
                                            <!--end::Number-->
                                        </div>
                                        <!--end::Wrapper-->
                                    </div>
                                    <!--end::Container-->
                                </div>';
            }
        } else {
            $bestSaleItemsAmt = '<div class="card-body">
                                    <div class="mt-0 d-flex flex-column align-items-center justify-content-center"><img style="width:100px;" src="' . url('empty.png') . '"><p class="text-center" style="font-weight:900;!important;">No Items!</p>
                                    </div>
                                 </div>';
        }

        if (count($bottom10AmountItems) > 0) {
            foreach ($bottom10AmountItems as $top10QtyItem) {
                $lowSaleItemsAmt .= '<div class="d-flex align-items-center mt-2 mb-2">
                                    <!--begin::Symbol-->
                                    <div class="symbol symbol-30px me-5 d-none">
                                                    <span class="symbol-label">
                                                        <i class="ki-duotone ki-abstract-25 fs-3 text-gray-600"><span class="path1"></span><span
                                                                class="path2"></span></i>
                                                    </span>
                                    </div>
                                    <!--end::Symbol-->

                                    <!--begin::Container-->
                                    <div class="d-flex align-items-center flex-stack flex-wrap d-grid gap-1 flex-row-fluid">
                                        <!--begin::Content-->
                                        <div class="me-5">
                                            <!--begin::Title-->
                                            <a href="#" class="text-gray-800 fw-bold text-hover-primary fs-8">' . $top10QtyItem["sale_item_name"] . ' (' . intval($top10QtyItem["sale_item_quantity"]) . ')</a>
                                            <!--end::Title-->

                                            <!--begin::Desc-->
                                            <span class="text-gray-400 fw-semibold fs-10 d-block text-start ps-0">' . $top10QtyItem["category_name"] . '</span>
                                            <!--end::Desc-->
                                        </div>
                                        <!--end::Content-->

                                        <!--begin::Wrapper-->
                                        <div class="d-flex align-items-center">
                                            <!--begin::Number-->
                                            <span class="text-gray-800 fw-bold fs-8 me-3">₦' . number_format($top10QtyItem["sale_item_amount"], 2) . '</span>
                                            <!--end::Number-->
                                        </div>
                                        <!--end::Wrapper-->
                                    </div>
                                    <!--end::Container-->
                                </div>';
            }
        } else {
            $lowSaleItemsAmt .= '<div class="card-body">
                                    <div class="mt-0 d-flex flex-column align-items-center justify-content-center"><img style="width:100px;" src="' . url("empty.png") . '"><p class="text-center" style="font-weight:900;!important;">No Items!</p>
                                    </div>
                                 </div>';
        }

        return response()->json(["status" => "success", "top10QtyItems" => $top10QtyItems, "top10AmountItems" => $top10AmountItems, "bottom10AmountItems" => $bottom10AmountItems, "highSaleItemsQty" => $highSaleItemsQty, "bestSaleItemsAmt" => $bestSaleItemsAmt, "lowSaleItemsAmt" => $lowSaleItemsAmt]);

    }

    public function yearlyNetProfitAnalysis(Request $request)
    {
        $currentYear = Carbon::now()->year;
        $currentYear = Carbon::parse($request->startDate)->isoFormat('Y');
        $monthsOfYear = [];
        $netProfits = [];
        $months = [];

        for ($month = 1; $month <= 12; $month++) {
            $date = Carbon::createFromDate($currentYear, $month, 1);
            $monthsOfYear[] = [
                'month_number' => $month,
                'month_name' => $date->format('F'),
                'start_date' => $date->copy()->startOfMonth()->toDateString(),
                'end_date' => $date->copy()->endOfMonth()->toDateString(),
            ];
        }

        $totalNetProfits = 0;
        foreach ($monthsOfYear as $monthOfYear) {

            $startDate = $monthOfYear["start_date"];
            $endDate = $monthOfYear["end_date"];

            $orders = Order::orderByDesc("id")->get();
            $orderIds = $orders->whereBetween("order_date", [$startDate, $endDate])->whereIn("order_status", ["Paid", "Settled"])->pluck("id")->toArray();

            $totalIncome = ItemOrder::whereIn("order_id", $orderIds)->sum("order_price");
            $totalPurchase = Purchase::whereBetween("purchase_date", [$startDate, $endDate])
                ->with('itemPurchases')
                ->get()
                ->flatMap(function ($purchase) {
                    return $purchase->itemPurchases;
                })
                ->sum('cost_price');

            $totalWaste = Waste::whereBetween("waste_date", [$startDate, $endDate])
                ->with('itemWastes')
                ->get()
                ->flatMap(function ($waste) {
                    return $waste->itemWastes;
                })
                ->sum(function ($itemWaste) {
                    return $itemWaste->waste_quantity * $itemWaste->waste_price;
                });

            $totalExpense = $totalPurchase + $totalWaste;

            $totalNetProfit = $totalIncome - $totalExpense;

            $totalNetProfits += $totalNetProfit;
            $netProfits[] = $totalNetProfit;
            $months[] = $monthOfYear["month_name"];

        }

        return response()->json(["status" => "success", "labels" => $months, "data" => $netProfits, "totalNetProfit" => number_format($totalNetProfits, 2)]);

    }

}
