<?php

namespace App\Http\Controllers;

use App\Models\DeliveryLocation;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class DeliveryLocationController extends Controller
{
    public function getDeliveryLocations(Request $request)
    {
        $deliveryLocations = DeliveryLocation::all();
        return view("delivery_locations", compact("deliveryLocations"));
    }

    public function ajaxDeliveryLocations(Request $request)
    {
        $deliveryLocations = DeliveryLocation::all();

        $main_json = [];
        $i = 0;

        foreach ($deliveryLocations as $deliveryLocation) {
            if ($deliveryLocation->delivery_location_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $deliveryLocation->delivery_location_name;
            $main_json[$i][$v++] = $deliveryLocation->delivery_location_price;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $deliveryLocation->delivery_location_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        > 
            <div class="menu-item px-3">
                <a href="#" data-bs-toggle="modal" data-bs-target="#deliveryPricesModal"  data-id="' . $deliveryLocation->id . '" class="menu-link px-3 deliveryPrices">
                    Prices
                </a>
            </div>
            <div class="menu-item px-3">
                <a href="#" data-id="' . $deliveryLocation->id . '" class="menu-link px-3 editDeliveryLocation">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $deliveryLocation->id . '"
                    class="menu-link px-3 deleteDeliveryLocation"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function createDeliveryLocation(Request $request)
    {
        $deliveryLocation = new DeliveryLocation();
        $deliveryLocation->delivery_location_name = $request->deliveryLocationName;
        $deliveryLocation->delivery_location_price = $request->deliveryLocationPrice;
        $deliveryLocation->delivery_location_status = "Active";
        $deliveryLocation->save();

        return response()->json(["status" => "success"]);
    }

    public function editDeliveryLocationForm(Request $request)
    {
        $deliveryLocation = DeliveryLocation::find($request->deliveryLocationId);
        $deliveryLocationStatus = $deliveryLocation->delivery_location_status === 'Active' ? 'checked' : '';
        $title = "Edit Delivery Location";
        $body = "";
        $body .= '
                <form id="editDeliveryLocationForm">
                <input value="' . $deliveryLocation->id . '" name="deliveryLocationId" class="d-none">
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter delivery location name" name="deliveryLocationName" value="' . $deliveryLocation->delivery_location_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Delivery Location Price</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter delivery location price" name="deliveryLocationPrice" value="' . $deliveryLocation->delivery_location_price . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="deliveryLocationStatus" name="deliveryLocationStatus" ' . $deliveryLocationStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="deliveryLocationStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
                </form>
                           ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editDeliveryLocation(Request $request)
    {
        $deliveryLocation = DeliveryLocation::where("id", $request->deliveryLocationId)->first();
        $deliveryLocation->delivery_location_name = $request->deliveryLocationName;
        $deliveryLocation->delivery_location_price = $request->deliveryLocationPrice;
        if ($request->deliveryLocationStatus) {
            $deliveryLocation->delivery_location_status = $request->deliveryLocationStatus;
        } else {
            $deliveryLocation->delivery_location_status = "Inactive";
        }
        $deliveryLocation->save();

        return response()->json(["status" => "success"]);
    }

    public function deleteDeliveryLocation(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'delivery_location_id')) {
                $hasDeliveryLocationId = DB::table($table)->where('delivery_location_id', $request->deliveryLocationId)->exists();
                if ($hasDeliveryLocationId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Delivery Location has data!"]);
                }
            }
        }
        DeliveryLocation::where("id", $request->deliveryLocationId)->delete();
        return response()->json(["status" => "success"]);
    }
}
