<?php

namespace App\Http\Controllers;

use App\Models\ItemCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class ItemCategoryController extends Controller
{
    public function getItemCategories(Request $request)
    {
        $itemCategories = ItemCategory::all();

        $main_json = [];
        $i = 0;
        foreach ($itemCategories as $itemCategory) {
            if ($itemCategory->item_category_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $itemCategory->item_category_name;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $itemCategory->item_category_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $itemCategory->id . '" class="menu-link px-3 editItemCategory">
                    Edit
                </a>
            </div>
            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $itemCategory->id . '"
                    class="menu-link px-3 deleteItemCategory"
                    data-kt-contact-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);

    }

    public function createItemCategory(Request $request)
    {
        $itemCategory = new ItemCategory();
        $itemCategory->item_category_name = $request->itemCategoryName;
        $itemCategory->item_category_status = "Active";
        $itemCategory->save();
        return response()->json(["status" => "success"]);
    }

    public function editItemCategoryForm(Request $request)
    {
        $itemCategory = ItemCategory::find($request->itemCategoryId);

        $title = "Edit Item Category";
        $body = "";
        $itemCategoryStatus = $itemCategory->item_category_status === 'Active' ? 'checked' : '';
        $body .= '
                <form id="editItemCategoryForm">
                <input value="' . $itemCategory->id . '" name="itemCategoryId" class="d-none">
                <div class="fv-row mb-5">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter item category name" name="itemCategoryName" value="' . $itemCategory->item_category_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="itemCategoryStatus" name="itemCategoryStatus" ' . $itemCategoryStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="itemCategoryStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
            </form>
        ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editItemCategory(Request $request)
    {
        $itemCategory = ItemCategory::where("id", $request->itemCategoryId)->first();
        $itemCategory->item_category_name = $request->itemCategoryName;
        $itemCategory->item_category_status = $request->itemCategoryStatus;
        $itemCategory->save();
        return response()->json(["status" => "success"]);
    }

    public function deleteItemCategory(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'item_category_id')) {
                $itemCategoryId = DB::table($table)->where('item_category_id', $request->itemCategoryId)->exists();
                if ($itemCategoryId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Item Category has data!"]);
                }
            }
        }

        ItemCategory::where("id", $request->itemCategoryId)->delete();
        $count = ItemCategory::get()->count();
        return response()->json(["status" => "success", "count" => $count]);

    }
}
