<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\ItemCategory;
use App\Models\ItemOrder;
use App\Models\ItemPurchase;
use App\Models\Purchase;
use App\Models\Item;
use App\Models\ItemCheck;
use App\Models\ItemWaste;
use App\Models\Waste;
use App\Models\Order;
use App\Models\Contact;
use App\Models\User;
use App\Models\ItemMeasurement;
use App\Models\Measurement;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Str;
use Carbon\Carbon;
use Illuminate\Http\Request;

class ItemCheckController extends Controller
{
    public function getItemChecks(Request $request)
    {
        return view("item_checks");
    }

    public function ajaxItemChecks(Request $request)
    {
        $items = Item::where("item_status", "Active")->get();

        $main_json = [];
        $i = 0;
        foreach ($items as $item) {
            $itemCheck = ItemCheck::where("item_id", $item->id)->where("start_date", "<=", date("Y-m-d"))->first();

            $opening = isset($itemCheck) ? $itemCheck->opening_quantity : 0;
            $closing = isset($itemCheck) ? $itemCheck->closing_quantity : 0;
            $startDate = isset($itemCheck) ? $itemCheck->start_date : null;
            $endDate = isset($itemCheck) ? $itemCheck->end_date : null;
            $lost = isset($itemCheck) ? $item->itemWastes->map(function ($itemWaste) use ($startDate, $endDate) {
                $waste = $itemWaste->order->whereBetween("waste_date", [$startDate, $endDate])->first();
                return isset($waste) ? $itemWaste->waste_quantity : 0;
            })->sum() : 0;
            $sold = isset($itemCheck) ? $item->itemOrders->map(function ($itemOrder) use ($startDate, $endDate) {
                $order = $itemOrder->order->where("start_date", ">=", $startDate)->where("end_date", ">=", $endDate)->first();
                return isset($order) ? $itemOrder->order_quantity : 0;
            })->sum() : 0;
            $bought = isset($itemCheck) ? $item->itemPurchases->map(function ($itemPurchase) use ($startDate, $endDate) {
                $purchase = $itemPurchase->purchase->whereBetween("purchase_date", [$startDate, $endDate])->first();
                return isset($purchase) ? $itemPurchase->purchase_quantity : 0;
            })->sum() : 0;


            $expected = ($opening + $bought) - ($lost + $closing);


            $from = isset($startDate) ? ' - ' . Carbon::parse($startDate)->isoFormat('ddd, DD/MMM/YYYY') : '';
            $to = isset($endDate) ? ' - ' . Carbon::parse($endDate)->isoFormat('ddd, DD/MMM/YYYY') : '';

            $date = isset($startDate) ? '<a href="#" class="btn btn-sm btn-outline btn-outline-primary">' . $from . '' . $to . '</a>' : '';
            $v = 0;
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $item->item_name . '</a><hr/><span class="fs-8">' . $item->itemCategory->item_category_name . '</span><br/>' . $date;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-dark">' . ($sold - $expected) . ' ' . $item->item_measurement . ' VARIANCE</a>';
            ;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-secondary">' . $sold . ' ' . $item->item_measurement . ' SOLD</a><hr/><a href="#" class="btn btn-sm btn-warning">' . $expected . ' ' . $item->item_measurement . ' EXPECTED</a>';
            ;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-danger">' . $lost . ' ' . $item->item_measurement . ' WASTE</a><hr/><a href="#" class="btn btn-sm btn-info">' . $closing . ' ' . $item->item_measurement . ' CLOSING</a>';
            ;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-primary">' . $opening . ' ' . $item->item_measurement . ' OPENING</a><hr/><a href="#" class="btn btn-sm btn-success">' . $bought . ' ' . $item->item_measurement . ' PURCHASE</a>';
            ;
            $main_json[$i][$v++] = !isset($itemCheck) ? '<a href="#" class="btn btn-sm btn-dark"><i class="bi bi-play-fill fs-4 me-0"></i> START</a>' : '<a href="#" class="btn btn-sm btn-secondary"><i class="bi bi-stop-circle-fill fs-4 me-0"></i> END</a><hr/><a href="#" class="btn btn-sm btn-dark"><i class="bi bi-eye fs-4 me-0"></i> VIEW</a>';

            ;
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }
}
