<?php

namespace App\Http\Controllers;

use App\Models\Item;
use App\Models\ItemCategory;
use App\Models\User;
use App\Models\Station;
use App\Models\ContactGroup;
use Illuminate\Support\Facades\Auth;
use App\Models\PriceReview;
use App\Models\ItemPurchase;
use App\Models\ItemMeasurement;
use App\Models\Measurement;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use Illuminate\Support\Facades\Schema;

class ItemController extends Controller
{
    public function printBarcode(Request $request){
        $barcode = $request->barcode;
        return view('print_barcode', compact('barcode'));
    }
    public function getItems(Request $request)
    {
        $items = Item::all();
        $itemCategories = ItemCategory::all();
        $measurements = Measurement::all();
        $contactGroups = ContactGroup::all();
        $stations = Station::all();
        return view("items", compact("items", "itemCategories", "measurements", "stations"));
    }

    public function ajaxItems(Request $request)
    {
        $itemStatus = null;
        $items = Item::where("id", "!=", null);
        if ($itemStatus) {
            $items = $items->where("item_status", $itemStatus);
        }
        $items = $items->orderByDesc("id")->get();
        $main_json = [];
        $i = 0;

        foreach ($items as $item) {
            $categoryName = isset($item->item_category_id) ? ItemCategory::find($item->item_category_id)->item_category_name : "---";
            $badge_class = $item->item_status === "Active" ? "badge-success" : "badge-danger";
            $v = 0;
            $main_json[$i][$v++] = $item->item_name;
            $main_json[$i][$v++] = $categoryName;
            $main_json[$i][$v++] = $item->item_measurement;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($item->item_price, 2) . '</a>';
            $main_json[$i][$v++] = $item->profit_margin . '%';
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $item->item_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $item->id . '"  data-bs-toggle="modal" data-bs-target="#itemContactGroupsModal"  class="menu-link px-3 itemContactGroups">
                    Groups
                </a>
            </div>
            <div class="menu-item px-3">
                <a href="#" data-id="' . $item->id . '" class="menu-link px-3 editItem">
                    Edit
                </a>
            </div>
            
            <div class="menu-item px-3">
                <a href="#" data-id="' . $item->id . '" data-measurement="' . $item->item_measurement . '" data-bs-toggle="modal" data-bs-target="#itemMeasurementsModal" class="menu-link px-3 itemMeasurements">
                    Measurements
                </a>
            </div>
            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $item->id . '"
                    class="menu-link px-3 deleteItem"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function getPricingItems(Request $request)
    {
        $items = Item::all();
        $itemCategories = ItemCategory::all();
        $measurements = Measurement::all();
        return view("pricing_items", compact("items", "itemCategories", "measurements"));
    }

    public function ajaxPricingItems(Request $request)
    {
        $itemStatus = null;
        $items = Item::where("id", "!=", null);
        if ($itemStatus) {
            $items = $items->where("item_status", $itemStatus);
        }
        $items = $items->orderByDesc("id")->get();
        $main_json = [];
        $i = 0;

        foreach ($items as $item) {
            $costPrice = 0;
            $latestItemPurchase = ItemPurchase::select('item_purchases.*', 'purchases.purchase_date')
                ->join('purchases', 'item_purchases.purchase_id', '=', 'purchases.id')
                ->where('item_purchases.item_id', $item->id)
                ->where('purchases.purchase_date', '<=', now())
                ->orderBy('purchases.purchase_date', 'desc')
                ->first();

            if ($latestItemPurchase) {
                $costPrice = $latestItemPurchase->unit_price;
            }
            $proposedPrice = $costPrice / (1 - ($item->profit_margin / 100));
            $remainder = $proposedPrice % 100;
            if ($remainder <= 50) {
                $proposedPrice = floor($proposedPrice / 100) * 100 + 50;
            } else {
                $proposedPrice = ceil($proposedPrice / 100) * 100;
            }
            $body = '';
            if ($item->item_price !== $proposedPrice) {
                $body = '<span class="badge badge-danger me-2">!</span> ';
            }
            $v = 0;
            $main_json[$i][$v++] = $body . ' ' . $item->item_name;
            $main_json[$i][$v++] = $item->profit_margin . '%';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($item->item_price, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning p-3 z-depth-1">₦' . number_format($costPrice, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-info btn-active-light-info p-3 z-depth-1">₦' . number_format($proposedPrice, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
        <div class="menu-item px-3">
            <a
                href="#"
                data-id="' . $item->id . '"
                data-bs-toggle="modal"
                data-bs-target="#adjustPricingModal"
                class="menu-link px-3 adjustPrice"
            >
                Adjust Price
            </a>
        </div>
        <div class="menu-item px-3">
            <a href="#" 
                data-bs-toggle="modal" 
                data-bs-target="#viewPriceLogModal" 
                data-id="' . $item->id . '" 
                class="menu-link px-3 priceLog">
                Purchase Log</a>
        </div>
        <div class="menu-item px-3">
            <a
                href="#"
                data-id="' . $item->id . '"
                data-bs-toggle="modal"
                data-bs-target="#viewPriceReviewLogModal"
                class="menu-link px-3 priceReviewLog"
            >
            Price Reviews
            </a>
        </div>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function ajaxAdjustPricing(Request $request)
    {

        $branchId = null;
        $itemStatus = null;
        $items = Item::whereNotNull("id");
        if ($branchId) {
            $items = $items->where("branch_id", $branchId);
        }
        if ($itemStatus) {
            $items = $items->where("item_status", $itemStatus);
        }
        $items = $items->orderByDesc("id")->get();
        if (isset($request->itemId)) {
            $items = Item::where("id", $request->itemId)->get();
        }
        $main_json = [];
        $i = 0;

        foreach ($items as $key => $item) {
            $costPrice = 0;
            $latestItemPurchase = ItemPurchase::select('item_purchases.*', 'purchases.purchase_date')
                ->join('purchases', 'item_purchases.purchase_id', '=', 'purchases.id')
                ->where('item_purchases.item_id', $item->id)
                ->where('purchases.purchase_date', '<=', now())
                ->orderBy('purchases.purchase_date', 'desc')
                ->first();

            if ($latestItemPurchase) {
                $costPrice = $latestItemPurchase->unit_price;
            }
            $proposedPrice = $costPrice / (1 - ($item->profit_margin / 100));
            $remainder = $proposedPrice % 100;
            if ($remainder <= 50) {
                $proposedPrice = floor($proposedPrice / 100) * 100 + 50;
            } else {
                $proposedPrice = ceil($proposedPrice / 100) * 100;
            }
            $difference = $proposedPrice - $item->item_price;
            if ($item->item_price !== $proposedPrice || isset($request->itemId)) {
                $v = 0;
                $main_json[$i][$v++] = '<div class="form-check">
                    <input class="form-check-input checkBox" type="checkbox" name="items[' . $key . '][checked]" value="true" id="flexCheckChecked' . $item->id . '" checked />
                    <label class="form-check-label" for="flexCheckChecked' . $item->id . '">
                    </label>
                </div>';
                $main_json[$i][$v++] = $item->item_name;
                $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($costPrice, 2) . '</a>';
                $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-info btn-active-light-info p-3 z-depth-1">₦' . number_format($item->item_price, 2) . '</a>';
                $main_json[$i][$v++] = '<input hidden name="items[' . $key . '][itemPrice]" class="itemPrice" value="' . $item->item_price . '" /><input type="text" name="items[' . $key . '][difference]" value="' . $difference . '" readonly class="difference form-control mb-1 mb-md-0" placeholder="" />';
                $main_json[$i][$v++] = '<input hidden name="items[' . $key . '][itemId]" value="' . $item->id . '" /><input type="text" name="items[' . $key . '][proposedPrice]" value="' . $proposedPrice . '" class="proposedPrice form-control mb-1 mb-md-0" placeholder="Enter proposed price" />';
                $main_json[$i][$v++] = '<input hidden name="items[' . $key . '][costPrice]" class="costPrice" value="' . $costPrice . '" /><input type="text" name="items[' . $key . '][profitMargin]" value="' . $item->profit_margin . '" class="profitMargin form-control mb-1 mb-md-0" placeholder="Enter profit margin" />';
                $i++;
            }
        }


        return response()->json(["returned_data" => $main_json]);
    }

    public function priceReviewLog(Request $request)
    {
        $priceReviews = PriceReview::where('item_id', $request->itemId)->orderBy('review_date', 'desc')->get();

        $main_json = [];
        $i = 0;
        foreach ($priceReviews as $priceReview) {
            $v = 0;
            $user = User::find($priceReview->user_id);
            $main_json[$i][$v++] = Carbon::parse($priceReview->review_date)->isoFormat('ddd, DD/MMM/YYYY');
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($priceReview->cost_price, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning p-3 z-depth-1">₦' . number_format($priceReview->item_price, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-secondary  p-3 z-depth-1">' . $priceReview->profit_margin . '%</a>';
            $main_json[$i][$v++] = $user->name;
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function adjustPrices(Request $request)
    {
        $items = $request->items;
        foreach ($items as $item) {
            if (isset($item["checked"])) {
                $lastPriceReview = PriceReview::where('review_date', function ($query) {
                    $query->selectRaw('MAX(review_date)')
                        ->from('price_reviews');
                })
                    ->orderBy('review_date', 'desc')
                    ->orderBy('created_at', 'desc')
                    ->first();
                if (isset($lastPriceReview)) {
                    if ($lastPriceReview->profit_margin != $item["profitMargin"] || $lastPriceReview->item_price != $item["proposedPrice"]) {
                        $priceReview = new PriceReview();
                        $priceReview->cost_price = $item["costPrice"];
                        $priceReview->item_price = $item["proposedPrice"];
                        $priceReview->profit_margin = $item["profitMargin"];
                        $priceReview->review_date = date("Y-m-d");
                        $priceReview->user_id = Auth::user()->id;
                        $priceReview->item_id = $item["itemId"];
                        $priceReview->save();
                    }
                } else {
                    $priceReview = new PriceReview();
                    $priceReview->cost_price = $item["costPrice"];
                    $priceReview->item_price = $item["proposedPrice"];
                    $priceReview->profit_margin = $item["profitMargin"];
                    $priceReview->review_date = date("Y-m-d");
                    $priceReview->user_id = Auth::user()->id;
                    $priceReview->item_id = $item["itemId"];
                    $priceReview->save();
                }
                $updateItem = Item::find($item["itemId"]);
                $updateItem->item_price = $item["proposedPrice"];
                $updateItem->profit_margin = $item["profitMargin"];
                $updateItem->save();
            }
        }

        return response()->json(["status" => "success", "message" => "Prices adjusted successfully"]);
    }

    public function getPriceLog(Request $request)
    {

        $itemId = $request->itemId;
        $main_json = [];
        $i = 0;

        $itemPurchases = ItemPurchase::where('item_id', $itemId)
            ->join('items', 'item_purchases.item_id', '=', 'items.id')
            ->join('purchases', 'item_purchases.purchase_id', '=', 'purchases.id')
            ->join('contacts', 'purchases.contact_id', '=', 'contacts.id')
            ->orderByDesc('purchases.purchase_date')
            ->select('item_purchases.*', 'purchases.purchase_date', 'item_purchases.unit_price', 'contacts.contact_name', 'items.item_measurement')
            ->get();

        foreach ($itemPurchases as $itemPurchase) {
            $v = 0;
            $main_json[$i][$v++] = $itemPurchase->contact_name;
            $main_json[$i][$v++] = Carbon::parse($itemPurchase->purchase_date)->isoFormat('ddd, DD/MMM/YYYY');
            $main_json[$i][$v++] = $itemPurchase->item_measurement;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning p-3 z-depth-1">₦' . number_format($itemPurchase->unit_price, 2) . '</a>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);

    }

    public function pricingItemsSummary(Request $request)
    {
        $itemIds = [];

        $items = Item::orderByDesc("id")->get();
        foreach ($items as $item) {
            $costPrice = 0;
            $latestItemPurchase = ItemPurchase::select('item_purchases.*', 'purchases.purchase_date')
                ->join('purchases', 'item_purchases.purchase_id', '=', 'purchases.id')
                ->where('item_purchases.item_id', $item->id)
                ->where('purchases.purchase_date', '<=', now())
                ->orderBy('purchases.purchase_date', 'desc')
                ->first();

            if ($latestItemPurchase) {
                $costPrice = $latestItemPurchase->unit_price;
            }
            $proposedPrice = $costPrice / (1 - ($item->profit_margin / 100));
            $remainder = $proposedPrice % 100;
            if ($remainder <= 50) {
                $proposedPrice = floor($proposedPrice / 100) * 100 + 50;
            } else {
                $proposedPrice = ceil($proposedPrice / 100) * 100;
            }
            if ($item->item_price != $proposedPrice) {
                $itemIds[] = $item->id;
            }
        }

        return response()->json(["status" => "success", "adjustPriceItems" => count($itemIds)]);
    }

    public function itemsSummary(Request $request)
    {
        $itemCount = Item::get()->count();
        $itemCategoryCount = ItemCategory::get()->count();

        return response()->json(["status" => "success", "itemCount" => $itemCount, "itemCategoryCount" => $itemCategoryCount]);
    }

    public function createItem(Request $request)
    {
        $item = new Item();
        $item->item_category_id = $request->itemCategoryId;
        $item->station_id = $request->stationId;
        $item->item_type = $request->itemType;
        $item->item_name = $request->itemName;
        $item->item_description = $request->itemDescription;
        $item->stock_alert_below = $request->stockAlertBelow;
        $item->expiry_alert_before = $request->expiryAlertBefore;
        $item->item_price = $request->itemPrice;
        $item->profit_margin = $request->profitMargin;
        $item->item_measurement = $request->itemMeasurement;
        $item->item_status = "Active";
        $item->save();

        return response()->json(["status" => "success"]);
    }

    public function editItemForm(Request $request)
    {
        $item = Item::find($request->itemId);
        $itemStatus = $item->item_status === 'Active' ? 'checked' : '';
        $kg_selected = $item->item_measurement === 'KILOGRAM' ? 'selected' : '';
        $unit_selected = $item->item_measurement === 'UNIT' ? 'selected' : '';
        $item_selected = $item->item_type === 'Item' ? 'selected' : '';
        $service_selected = $item->item_type === 'Service' ? 'selected' : '';
        $pack_selected = $item->item_type === 'Item Pack' ? 'selected' : '';
        $itemCategories = ItemCategory::all();
        $stations = Station::all();

        $title = "Edit Item";
        $body = "";

        $body .= '
                <form id="editItemForm">
                <input value="' . csrf_token() . '" class="d-none">
                <input value="' . $item->id . '" name="itemId" class="d-none">
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Item Name</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="" name="itemName" value="' . $item->item_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Select Item Type</label>
                    <!--end::Label-->

                    <!--begin::Select-->
                    <select class="mb-2 itemType" data-width="100%" data-live-search="true" name="itemType" data-placeholder="Select Item Type" data-dropdown-parent="#emptyModal">
                        <option value="Item" ' . $item_selected . '>ITEM</option>
                        <option value="Service" ' . $service_selected . '>SERVICE</option>
                        <option value="Item Pack" ' . $pack_selected . '>ITEM PACK</option>
                        </select>
                    <!--end::Select-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Select Station</label>
                    <!--end::Label-->

                    <!--begin::Select-->
                    <select class="mb-2 stationId" data-width="100%" data-live-search="true" name="stationId" data-placeholder="Select Station" data-dropdown-parent="#emptyModal">';
        foreach ($stations as $station) {
            $selected = "";
            if ($station->id === $item->station_id) {
                $selected = "selected";
            }
            $body .= '<option value="' . $station->id . '" ' . $selected . '>' . $station->station_name . '</option>';
        }
        $body .= '</select>
                    <!--end::Select-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Select Item Category</label>
                    <!--end::Label-->

                    <!--begin::Select-->
                    <select class="mb-2 itemCategoryId" data-width="100%" data-live-search="true" name="itemCategoryId" data-placeholder="Select Item Category" data-dropdown-parent="#emptyModal">';
        foreach ($itemCategories as $itemCategory) {
            $selected = "";
            if ($itemCategory->id === $item->item_category_id) {
                $selected = "selected";
            }
            $body .= '<option value="' . $itemCategory->id . '" ' . $selected . '>' . $itemCategory->item_category_name . '</option>';
        }
        $body .= '</select>
                    <!--end::Select-->
                </div>
                <!--end::Input group-->


                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Profit Margin (in percentage)</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="number" class="form-control form-control-solid" placeholder="" name="profitMargin" value="' . $item->profit_margin . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Item Description</label>
                    <!--end::Label-->

                    <!--begin::Text Area-->
                    <textarea name="itemDescription" placeholder="Enter Item Description" class="form-control form-control-solid h-100px">' . $item->item_description . '</textarea>
                    <!--end::Text Area-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Select Item Measurement</label>
                    <!--end::Label-->

                    <!--begin::Select-->
                    <select class="mb-2 itemMeasurement" data-width="100%" data-live-search="true" name="itemMeasurement" data-placeholder="Select Item Measurement" data-dropdown-parent="#emptyModal">
                        <option value="KILOGRAM" ' . $kg_selected . '>KILOGRAM (KG)</option>
                        <option value="UNIT" ' . $unit_selected . '>UNIT</option>
                        </select>
                    <!--end::Select-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Item Price (per item measurement)</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="number" class="form-control form-control-solid" placeholder="" name="itemPrice" value="' . $item->item_price . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->


                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Stock Alert Below (in item measurement)</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <input type="number" class="form-control form-control-solid" placeholder="" name="stockAlertBelow" value="' . $item->stock_alert_below . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Expiry Alert Before (in days)</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="number" class="form-control form-control-solid" placeholder="" name="expiryAlertBefore" value="' . $item->expiry_alert_before . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->

                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Item Status</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="itemStatus" name="itemStatus" ' . $itemStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="itemStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>
                <!--end::Input group-->


                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
            </form>

        ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editItem(Request $request)
    {
        $item = Item::find($request->itemId);
        $item->item_category_id = $request->itemCategoryId;
        $item->station_id = $request->stationId;
        $item->item_type = $request->itemType;
        $item->item_name = $request->itemName;
        $item->item_description = $request->itemDescription;
        $item->item_status = $request->has('itemStatus') ? $request->itemStatus : "Inactive";
        $item->stock_alert_below = $request->stockAlertBelow;
        $item->expiry_alert_before = $request->expireyAlertBefore;
        $item->item_price = $request->itemPrice;
        $item->profit_margin = $request->profitMargin;
        $item->item_measurement = $request->itemMeasurement;
        $item->save();
        return response()->json(["status" => "success"]);
    }

    public function deleteItem(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if ($table != "item_measurements") {
                if (Schema::hasColumn($table, 'item_id')) {
                    $itemId = DB::table($table)->where('item_id', $request->itemId)->exists();
                    if ($itemId) {
                        return response()->json(["status" => "failed", "message" => "Cannot delete, Item has data!", "table" => $table]);
                    }
                }
            }
        }
        Item::where("id", $request->itemId)->delete();
        ItemMeasurement::where("item_id", $request->itemId)->delete();

        return response()->json(["status" => "success"]);
    }

}
