<?php

namespace App\Http\Controllers;

use App\Models\Measurement;
use App\Models\ItemMeasurement;
use App\Models\Item;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;


class ItemMeasurementController extends Controller
{
    public function getItemMeasurements(Request $request)
    {
        $itemMeasurements = ItemMeasurement::where("item_id", $request->itemId)->get();
        $measurements = ItemMeasurement::select([
            "item_measurements.*",
            "measurements.measurement_name"
        ])->join("measurements", "measurements.id", "=", "item_measurements.measurement_id")->where("item_measurements.item_id", $request->itemId)->get();
        $main_json = [];
        $i = 0;
        foreach ($itemMeasurements as $itemMeasurement) {
            $measurement = Measurement::find($itemMeasurement->measurement_id);
            $item = Item::find($request->itemId);
            $v = 0;
            $main_json[$i][$v++] = $measurement->measurement_name;
            $main_json[$i][$v++] = $itemMeasurement->quantity . ' ' . $item->item_measurement;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
                    Actions
                    <i class="ki-duotone ki-down fs-5 ms-1"></i>
                </a>
                <div
                    class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
                    data-kt-menu="true"
                >
                    <div class="menu-item px-3">
                        <a href="#" data-id="' . $itemMeasurement->id . '" class="menu-link px-3 editItemMeasurement">
                            Edit
                        </a>
                    </div>
                    <div class="menu-item px-3">
                        <a
                            href="#"
                            data-id="' . $itemMeasurement->id . '"
                            class="menu-link px-3 deleteItemMeasurement"
                            data-kt-contact-table-filter="delete_row"
                        >
                            Delete
                        </a>
                    </div>
                </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json, "itemMeasurements" => $measurements]);

    }

    public function createItemMeasurement(Request $request)
    {
        $itemMeasurement = new ItemMeasurement();
        $itemMeasurement->item_id = $request->itemId;
        $itemMeasurement->measurement_id = $request->measurementId;
        $itemMeasurement->quantity = $request->quantity;
        $itemMeasurement->save();
        return response()->json(["status" => "success"]);
    }

    public function editItemMeasurementForm(Request $request)
    {
        $itemMeasurement = ItemMeasurement::find($request->itemMeasurementId);

        $title = "Edit Item Measurement";
        $body = "";
        $body .= '
                <form id="editItemMeasurementForm">
                <input value="' . $itemMeasurement->id . '" name="itemMeasurementId" class="d-none">
                <div class="fv-row mb-5">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Quantity</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter quantity" name="quantity" value="' . $itemMeasurement->quantity . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
            </form>
        ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editItemMeasurement(Request $request)
    {
        $itemMeasurement = ItemMeasurement::where("id", $request->itemMeasurementId)->first();
        $itemMeasurement->quantity = $request->quantity;
        $itemMeasurement->save();
        return response()->json(["status" => "success"]);
    }

    public function deleteItemMeasurement(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'item_measurement_id')) {
                $itemMeasurementId = DB::table($table)->where('item_measurement_id', $request->itemMeasurementId)->exists();
                if ($itemMeasurementId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Item Measurement has data!"]);
                }
            }
        }

        ItemMeasurement::where("id", $request->itemMeasurementId)->delete();
        return response()->json(["status" => "success"]);

    }
}
