<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\ItemCategory;
use App\Models\ItemOrder;
use App\Models\ItemPurchase;
use App\Models\Purchase;
use App\Models\Item;
use App\Models\ItemCheck;
use App\Models\Waste;
use App\Models\ItemWaste;
use App\Models\Order;
use App\Models\Contact;
use App\Models\User;
use App\Models\ItemMeasurement;
use App\Models\Measurement;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Str;
use Carbon\Carbon;
use Illuminate\Http\Request;

class ItemWasteController extends Controller
{
    public function getItemWastes(Request $request)
    {
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemCategories = ItemCategory::all();

        $itemCategoryId = isset($request->itemCategoryId) ? $request->itemCategoryId : null;

        $items = Item::with("itemMeasurements")->where("item_status", "Active")->get();
        return view("item_wastes", compact("items", "itemCategories", 'date', 'startDate', 'endDate', 'itemCategoryId'));
    }

    public function ajaxItemWastes(Request $request)
    {
        $startDate = $request->startDate;
        $endDate = $request->endDate;

        $wastes = Waste::whereBetween("waste_date", [$startDate, $endDate])->get();
        $items = $wastes->flatMap(function ($waste) {
            return $waste->itemWastes->map(function ($itemWaste) {
                return $itemWaste->itemPurchase->item;
            });
        })->unique();

        $main_json = [];
        $i = 0;
        $wasteAmount = 0;
        foreach ($items as $item) {
            $totalWaste = $wastes->flatMap(function ($waste) use ($item) {
                return $waste->itemWastes->map(function ($itemWaste) use ($item) {
                    if ($itemWaste->itemPurchase->item->id === $item->id) {
                        return $itemWaste->waste_quantity;
                    }
                    return 0;
                });
            })->sum();
            $body = "";
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemMeasurementQuantity = intval($totalWaste / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalWaste - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $totalAmount = $wastes->flatMap(function ($waste) use ($item) {
                return $waste->itemWastes->map(function ($itemWaste) use ($item) {
                    if ($itemWaste->itemPurchase->item->id === $item->id) {
                        return $itemWaste->waste_quantity * $itemWaste->waste_price;
                    }
                    return 0;
                });
            })->sum();

            $wasteAmount += $totalAmount;

            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->itemCategory->item_category_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-secondary">' . $totalWaste . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-outline btn-outline-info btn-flex btn-center" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                MEASUREMENTS
                <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
            </a>
            <div
                class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                data-kt-menu="true"
            >
                ' . $body . '
            </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-danger btn-active-light-danger p-3 z-depth-1">₦' . number_format($totalAmount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" data-bs-toggle="modal" data-bs-target="#viewItemWastesModal" data-id="'.$item->id.'" data-start_date="'.$startDate.'" data-end_date="'.$endDate.'" class="btn btn-sm btn-dark viewItemWaste"><i class="bi bi-eye-fill fs-4 me-0"></i> VIEW</a>';
            ;
            $i++;
        }

        $wasteAmount = "₦".number_format($wasteAmount, decimals:2);
        return response()->json(["returned_data" => $main_json, "wasteAmount" => $wasteAmount]);
    }
    public function viewItemWastes(Request $request)
    {
        $startDate = $request->startDate;
        $endDate = $request->endDate;
        $itemId = $request->itemId;

        $wastes = Waste::whereBetween("waste_date", [$startDate, $endDate])->get();
        $itemWastes = $wastes->flatMap(function ($waste) use ($itemId) {
            return $waste->itemWastes->map(function ($itemWaste) use ($itemId) {
                if ($itemWaste->itemPurchase->item->id === intval($itemId)) {
                    return $itemWaste;
                }
            })->filter();
        });
    
        $main_json = [];
        $i = 0;
        foreach($itemWastes as $itemWaste) {
            $itemPurchase = $itemWaste->itemPurchase;
            $item = $itemPurchase->item;
            $waste = $itemWaste->waste;

            $from = isset($waste->waste_date) ? Carbon::parse($waste->waste_date)->isoFormat('ddd, DD/MMM/YYYY') : '';
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $itemPurchase->barcode . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-secondary">' . $itemWaste->waste_quantity . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-danger btn-active-light-danger p-3 z-depth-1">₦' . number_format(($itemWaste->waste_price * $itemWaste->waste_quantity) , decimals: 2) . '</a>';
            $main_json[$i][$v++] = $from;
            ;
            $i++;

        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function editItemWasteForm(Request $request)
    {

    }

    public function editItemWaste(Request $request)
    {

    }

    public function deleteItemWaste(Request $request)
    {

    }
}
