<?php

namespace App\Http\Controllers;

use App\Models\Measurement;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class MeasurementController extends Controller
{
    public function getMeasurements(Request $request)
    {
        $measurements = Measurement::all();
        return view("measurements", compact("measurements"));
    }

    public function ajaxMeasurements(Request $request)
    {
        $measurements = Measurement::all();

        $main_json = [];
        $i = 0;

        foreach ($measurements as $measurement) {
            if ($measurement->measurement_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $measurement->measurement_name;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $measurement->measurement_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $measurement->id . '" class="menu-link px-3 editMeasurement">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $measurement->id . '"
                    class="menu-link px-3 deleteMeasurement"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }
    public function createMeasurements(Request $request)
    {
        $measurements = $request->measurements;
        foreach ($measurements as $measurement) {
            $newMeasurement = new Measurement();
            $newMeasurement->measurement_name = $measurement["measurementName"];
            $newMeasurement->measurement_status = "Active";
            $newMeasurement->save();
        }

        return response()->json(["status" => "success"]);
    }

    public function editMeasurementForm(Request $request)
    {
        $measurement = Measurement::find($request->measurementId);
        $measurementStatus = $measurement->measurement_status === 'Active' ? 'checked' : '';

        $title = "Edit Measurement";
        $body = "";
        $body .= '
                <form id="editMeasurementForm">
                <input value="' . $measurement->id . '" name="measurementId" class="d-none">
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter measurement name" name="measurementName" value="' . $measurement->measurement_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
            <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="measurementStatus" name="measurementStatus" ' . $measurementStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="measurementStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
           </form>
        ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);

    }

    public function editMeasurement(Request $request)
    {
        $measurement = Measurement::where("id", $request->measurementId)->first();
        $measurement->measurement_name = $request->measurementName;
        if ($request->measurementStatus) {
            $measurement->measurement_status = $request->measurementStatus;
        } else {
            $measurement->measurement_status = "Inactive";
        }
        $measurement->save();

        return response()->json(["status" => "success"]);
    }

    public function deleteMeasurement(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'measurement_id')) {
                $hasMeasurementId = DB::table($table)->where('measurement_id', $request->measurementId)->exists();
                if ($hasMeasurementId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Measurement has data!"]);
                }
            }
        }
        Measurement::where("id", $request->measurementId)->delete();
        return response()->json(["status" => "success"]);
    }
}
