<?php

namespace App\Http\Controllers;

use App\Models\Medication;
use App\Models\MedicationPlan;
use App\Models\DeliveryLocation;
use App\Models\Contact;
use App\Models\Item;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class MedicationPlanController extends Controller
{
    public function getMedicationPlans(Request $request)
    {
        $items = Item::all();
        $medicationPlans = MedicationPlan::all();
        $deliveryLocations = DeliveryLocation::all();
        $contacts = Contact::all();
        return view("medication_plans", compact("medicationPlans", "deliveryLocations", "contacts", "items"));
    }

    public function ajaxMedicationPlans(Request $request)
    {
        $medicationPlans = MedicationPlan::all();

        $main_json = [];
        $i = 0;

        foreach ($medicationPlans as $medicationPlan) {
            if ($medicationPlan->medication_planstatus === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $medicationPlan->medication_planname;
            $main_json[$i][$v++] = $medicationPlan->medication_planphone_number;
            $main_json[$i][$v++] = $medicationPlan->medication_planemail;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $medicationPlan->medication_planstatus . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $medicationPlan->id . '" class="menu-link px-3 editMedicationPlan">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $medicationPlan->id . '"
                    class="menu-link px-3 deleteMedicationPlan"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function createMedicationPlan(Request $request)
    {
        $medicationPlan = new MedicationPlan();
        $medicationPlan->medication_plan_name = $request->medicationPlanName;
        $medicationPlan->contact_id = $request->contactId;
        $medicationPlan->delivery_location_id = $request->deliveryLocationId;
        $medicationPlan->interval_value = $request->intervalValue;
        $medicationPlan->interval_type = $request->intervalType;
        $medicationPlan->start_date = $request->startDate;
        $medicationPlan->end_date = $request->endDate;
        $medicationPlan->medication_plan_status = $request->medicationPlanStatus;
        $medicationPlan->save();

        $medications = $request->medications;
        if(count($medications) > 0){
            foreach ($medications as $medication) {
                $newMedication = new Medication();
                $newMedication->medication_plan_id = $medicationPlan->id;
                $newMedication->item_id = $medication["itemId"];
                $newMedication->item_quantity = $medication["itemQuantity"];
                $newMedication->save();
            }
        }

        return response()->json(["status" => "success"]);
    }

    public function editMedicationPlanForm(Request $request)
    {
        $medicationPlan = MedicationPlan::find($request->medicationPlanId);
        $medicationPlanStatus = $medicationPlan->medication_plan_status === 'Active' ? 'checked' : '';
        $title = "Edit Medication Plan";
        $body = "";
        $body .= '
                <form id="editMedicationPlanForm">
                <input value="' . $medicationPlan->id . '" name="medicationPlanId" class="d-none">
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter medication plan name" name="medicationPlanName" value="' . $medicationPlan->medication_plan_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Phone Number</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter medication plan phone number" name="medicationPlanPhoneNumber" value="' . $medicationPlan->medication_plan_phone_number . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Email</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="email" class="form-control form-control-solid" placeholder="Enter medication plan email" name="medicationPlanEmail" value="' . $medicationPlan->medication_plan_email . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Website</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter medication plan website" name="medicationPlanWebsite" value="' . $medicationPlan->medication_plan_website . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Address</label>
                    <!--end::Label-->
                    <!--begin::Text Area-->
                    <textarea name="medicationPlanAddress" placeholder="Enter medication plan address" class="form-control form-control-solid h-100px">' . $medicationPlan->medication_plan_address . '</textarea>
                    <!--end::Text Area-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->

                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="medicationPlanStatus" name="medicationPlanStatus" ' . $medicationPlanStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="medicationPlanStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
                </form>
                           ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editMedicationPlan(Request $request)
    {
        $medicationPlan = MedicationPlan::where("id", $request->medicationPlanId)->first();
        $medicationPlan->medication_plan_name = $request->medicationPlanName;
        $medicationPlan->medication_plan_address = $request->medicationPlanAddress;
        $medicationPlan->medication_plan_website = $request->medicationPlanWebsite;
        $medicationPlan->medication_plan_phone_number = $request->medicationPlanPhoneNumber;
        $medicationPlan->medication_plan_email = $request->medicationPlanEmail;
        if ($request->medicationPlanStatus) {
            $medicationPlan->medication_plan_status = $request->medicationPlanStatus;
        } else {
            $medicationPlan->medication_plan_status = "Inactive";
        }
        $medicationPlan->save();

        return response()->json(["status" => "success"]);
    }

    public function deleteMedicationPlan(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'medication_plan_id')) {
                $hasMedicationPlanId = DB::table($table)->where('medication_plan_id', $request->medicationPlanId)->exists();
                if ($hasMedicationPlanId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Medication Plan has data!"]);
                }
            }
        }
        MedicationPlan::where("id", $request->medicationPlanId)->delete();
        return response()->json(["status" => "success"]);
    }
}
