<?php

namespace App\Http\Controllers;

use App\Models\Contact;
use Illuminate\Http\Request;
use App\Models\Order;
use App\Models\OrderPayment;
use App\Models\ItemOrder;
use App\Models\Item;
use App\Models\ItemMeasurement;
use App\Models\ComputerOrder;
use App\Models\User;
use App\Models\ItemPurchase;
use App\Models\PaymentMethod;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Crypt;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

class OrderController extends Controller
{

    public function orders(Request $request)
    {
        $paymentMethods = PaymentMethod::where('payment_method_status', "Active")->get();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        return view("orders", compact('paymentMethods', 'date', 'startDate', 'endDate'));
    }

    public function ordersSummary(Request $request)
    {
        $startDate = $request->startDate;
        $endDate = $request->endDate;

        if (Auth::user()->role === "Admin") {
            $staffIds = User::pluck("id")->toArray();
        } else {
            $staffIds = [Auth::user()->id];
        }

        $orders = Order::whereBetween(DB::raw("DATE(order_date)"), [$startDate, $endDate])->whereIn("user_id", $staffIds)->get();
        $totalAmount = $orders->sum(function ($order) {
            return $order->itemOrders->sum('order_price');
        });
        $totalPaid = $orders->sum(function ($order) {
            return $order->orderPayments->sum('payment_amount');
        });
        $totalDiscount = $orders->sum("discount_amount");
        $totalPayment = $totalPaid - $orders->sum("change_amount");
        $totalBalance = $totalAmount - ($totalDiscount + $totalPayment);

        return response()->json(["status" => "success", "ordersCount" => $orders->count(), "totalDiscount" => number_format($totalDiscount, 2), "totalAmount" => number_format($totalAmount, 2), "totalBalance" => number_format($totalBalance, 2), "totalPayment" => number_format($totalPayment, 2)]);
    }

    public function ajaxOrders(Request $request)
    {
        $orders = Order::with('contact', 'user')->orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $orders->whereBetween('order_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $orders->whereDate('order_date', $request->startDate);
        } else {
            $orders->whereDate('order_date', now()->toDateString());
        }

        $orders = $orders->orderByDesc("id")->get();

        $main_json = [];
        $i = 0;
        foreach ($orders as $order) {
            $badge_class = $order->order_status === "Pending" ? "badge-secondary" : ($order->order_status === "Settled" ? "badge-warning" : "badge-success");
            $v = 0;
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $order->order_number . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $order->user->name . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . Carbon::parse($order->order_date)->isoFormat('ddd, DD/MMM/YYYY') . '</a>';
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $order->order_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $order->contact->contact_name . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-success btn-active-light-success p-3 z-depth-1">₦' . number_format($order->itemOrders->sum("order_price"), decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning p-3 z-depth-1">₦' . number_format($order->discount_amount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($order->orderPayments->sum("payment_amount"), decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-info btn-active-light-info p-3 z-depth-1">₦' . number_format(($order->orderPayments->sum("payment_amount") - ($order->itemOrders->sum("order_price") + $order->discount_amount)), decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
                    <div class="menu-item px-3">
                        <a href="#" data-bs-toggle="modal"
                            data-bs-target="#viewOrderItemsModal" data-i_d="' . Crypt::encrypt($order->id) . '" data-id="' . $order->id . '" class="menu-link px-3 viewOrder">
                            View
                        </a>
                    </div>
                    <div class="menu-item px-3">
                        <a href="#" data-id="' . $order->id . '" class="menu-link px-3 editOrder">
                            Edit
                        </a>
                    </div>
                    <div class="menu-item px-3">
                        <a href="#" data-id="' . $order->id . '"
                            class="menu-link px-3 deleteOrder"
                            data-kt-customer-table-filter="delete_row">
                            Delete
                        </a>
                    </div>
                </div>';
            $main_json[$i][$v++] = "";
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function pointOfSale(Request $request)
    {
        $computerId = isset($request->computerId) ? $request->computerId : null;
        Session::put("computerId", $computerId);
        $paymentMethods = PaymentMethod::where('payment_method_status', "Active")->get();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        return view("point_of_sale", compact('paymentMethods', 'date', 'startDate', 'endDate', 'computerId'));
    }

    public function getCustomerView(Request $request){
        $orderId = Session::get("orderId");
        $order = Order::find($orderId);
        $computerId = isset($request->computerId) ? $request->computerId : null;
        if($orderId && $order && $order->order_status !== "Paid"){
            $itemOrderIds = ItemOrder::where("order_id", $orderId)->pluck("id")->toArray();
            $itemOrders = ItemOrder::where('order_id', $orderId)->get();
            $total = $itemOrders->sum("order_amount");
        }
        else{
            $order = null;
            $total = 0;
        }

        $date = date("Y-m-d");

        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;

        return view("customer_view", compact("order",  "total", "startDate", "endDate", "computerId"));
    }

    public function customerCurrentOrderDiv(Request $request){

        $computerId = $request->computerId;
        if (isset($computerId)) {
        $orderId = ComputerOrder::where("computer_id", $computerId)->value("order_id");
        }
        else{
            $orderId = null;
        }

        $order = Order::find($orderId);
        
        $body = '';
        $body .= '
        <div class="card-header pt-5">
            <h3 class="card-title fw-bold text-gray-800 fs-2qx">Current Order</h3>
            <div class="card-toolbar">
            </div>
        </div>';

        if ($order !== null) {
            $itemOrders = ItemOrder::where("order_id", $order->id)->orderByDesc("id")->get();

            $body .= '<div class="card-body ';
            if ($itemOrders->count() === 0) {
                $body .= 'pt-15';
            } else {
                $body .= 'pt-0';
            }

            $body .= '">';
            if ($itemOrders->count() > 0) {
                if($itemOrders->count() > 14){
                        $totalItems = $itemOrders->count();
                        $chunkSize = 14;

                        $firstItemOrders = $itemOrders->take($chunkSize);
                        $secondOrderItems = $itemOrders->slice($chunkSize);

                        $body.='<div class="row">';
                            $body.='<div class="col-6">';
                            $body .= '<div class="table-responsive mb-8">
                            <table class="table align-middle gs-0 gy-1 my-0">
                                <thead>
                                    <tr>
                                        <th class="min-w-175px"></th>
                                        <th class="w-125px"></th>
                                    </tr>
                                </thead>
                                <tbody>';
                
                                foreach ($firstItemOrders as $itemOrder) {
                                    $item = Item::find($itemOrder->itemPurchase->item_id);
                                    
                                    $body .= '<tr class="z-depth-1" data-kt-pos-element="item" data-kt-pos-item-price="33">
                        <td class="pe-0 ';
                                    if ($order !== null && $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    } else {
                                        $body .= 'itemOrder';
                                    }
                                    $src = "setup/menu.jpg?2";
                                    $body .= '" data-item_type="' . $item->item_type . '"  data-id="' . $itemOrder->id . '">
                        <div class="d-flex align-items-center mb-0">
                            <div class="symbol symbol-20px me-5 z-depth-1" style="padding: 5px;border-radius: 15px;border: 1px solid #aaa;">
                                <img src="' . url($src) . '" class="" alt="">
                            </div>
                            <div class="flex-grow-1">
                                <a href="#" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>
                                <span class="text-muted d-block">₦' . number_format($itemOrder->order_price, 2) . '</span>';
                
                                    $body .= '</div></div></td>
                        <td class="pe-0">
                            <div class="position-relative d-flex align-items-center" data-kt-dialer="true" data-kt-dialer-min="1" data-kt-dialer-max="100000" data-kt-dialer-step="1" data-kt-dialer-decimals="0">
                                <button type="button" data-id="' . $itemOrder->id . '" class="decreaseOrderItem btn btn-icon btn-sm btn-danger d-none btn-icon-white-400 ';
                
                                    if ($order === null || $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    }
                
                                    $body .= '" data-kt-dialer-control="decrease">
                                    <i class="ki-duotone ki-minus fs-3x"></i>
                                </button>
                
                                <input type="text" style="background:none;" class="form-control border-0 text-center px-0 fs-3 fw-bold text-gray-800 w-30px myInput" data-kt-dialer-control="input" placeholder="Amount" name="manageBudget" readonly value="' . $itemOrder->order_quantity . '" />
                
                                <button type="button" data-id="' . $itemOrder->id . '" class="btn btn-icon btn-sm btn-primary btn-icon-white-400 d-none increaseOrderItem ';
                
                                    if ($order === null || $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    }
                
                                    $body .= '" data-kt-dialer-control="increase">
                                    <i class="ki-duotone ki-plus fs-3x"></i>
                                </button>
                            </div>
                        </td>
                    </tr>';
                                }
                
                
                                $body .= '</tbody></table></div>';
                            $body.='</div>';
                            $body.='<div class="col-6">';
                            $body .= '<div class="table-responsive mb-8">
                            <table class="table align-middle gs-0 gy-1 my-0">
                                <thead>
                                    <tr>
                                        <th class="min-w-175px"></th>
                                        <th class="w-125px"></th>
                                    </tr>
                                </thead>
                                <tbody>';
                
                                foreach ($secondOrderItems as $itemOrder) {
                                    $item = Item::find($itemOrder->itemPurchase->item_id);
                                    
                                    $body .= '<tr class="z-depth-1" data-kt-pos-element="item" data-kt-pos-item-price="33">
                        <td class="pe-0 ';
                                    if ($order !== null && $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    } else {
                                        $body .= 'itemOrder';
                                    }
                                    $src = "setup/menu.jpg?2";
                                    $body .= '" data-item_type="' . $item->item_type . '"  data-id="' . $itemOrder->id . '">
                        <div class="d-flex align-items-center mb-0">
                            <div class="symbol symbol-20px me-5 z-depth-1" style="padding: 5px;border-radius: 15px;border: 1px solid #aaa;">
                                <img src="' . url($src) . '" class="" alt="">
                            </div>
                            <div class="flex-grow-1">
                                <a href="#" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>
                                <span class="text-muted d-block">₦' . number_format($itemOrder->order_price, 2) . '</span>';
                
                                    $body .= '</div></div></td>
                        <td class="pe-0">
                            <div class="position-relative d-flex align-items-center" data-kt-dialer="true" data-kt-dialer-min="1" data-kt-dialer-max="100000" data-kt-dialer-step="1" data-kt-dialer-decimals="0">
                                <button type="button" data-id="' . $itemOrder->id . '" class="decreaseOrderItem btn btn-icon btn-sm btn-danger d-none btn-icon-white-400 ';
                
                                    if ($order === null || $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    }
                
                                    $body .= '" data-kt-dialer-control="decrease">
                                    <i class="ki-duotone ki-minus fs-3x"></i>
                                </button>
                
                                <input type="text" style="background:none;" class="form-control border-0 text-center px-0 fs-3 fw-bold text-gray-800 w-30px myInput" data-kt-dialer-control="input" placeholder="Amount" name="manageBudget" readonly value="' . $itemOrder->order_quantity . '" />
                
                                <button type="button" data-id="' . $itemOrder->id . '" class="btn btn-icon btn-sm btn-primary btn-icon-white-400 d-none increaseOrderItem ';
                
                                    if ($order === null || $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    }
                
                                    $body .= '" data-kt-dialer-control="increase">
                                    <i class="ki-duotone ki-plus fs-3x"></i>
                                </button>
                            </div>
                        </td>
                    </tr>';
                                }
                
                
                                $body .= '</tbody></table></div>';
                            $body.='</div>';
                        $body.='</div>';
                }
                else{
                $body .= '<div class="table-responsive mb-8">
            <table class="table align-middle gs-0 gy-1 my-0">
                <thead>
                    <tr>
                        <th class="min-w-175px"></th>
                        <th class="w-125px"></th>
                    </tr>
                </thead>
                <tbody>';

                foreach ($itemOrders as $itemOrder) {
                    $item = Item::find($itemOrder->itemPurchase->item_id);
                                    
                                    $body .= '<tr class="z-depth-1" data-kt-pos-element="item" data-kt-pos-item-price="33">
                        <td class="pe-0 ';
                                    if ($order !== null && $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    } else {
                                        $body .= 'itemOrder';
                                    }
                                    $src = "setup/menu.jpg?2";
                                    $body .= '" data-item_type="' . $item->item_type . '"  data-id="' . $itemOrder->id . '">
                        <div class="d-flex align-items-center mb-0">
                            <div class="symbol symbol-20px me-5 z-depth-1" style="padding: 5px;border-radius: 15px;border: 1px solid #aaa;">
                                <img src="' . url($src) . '" class="" alt="">
                            </div>
                            <div class="flex-grow-1">
                                <a href="#" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>
                                <span class="text-muted d-block">₦' . number_format($itemOrder->order_price, 2) . '</span>';
                
                                    $body .= '</div></div></td>
                        <td class="pe-0">
                            <div class="position-relative d-flex align-items-center" data-kt-dialer="true" data-kt-dialer-min="1" data-kt-dialer-max="100000" data-kt-dialer-step="1" data-kt-dialer-decimals="0">
                                <button type="button" data-id="' . $itemOrder->id . '" class="decreaseOrderItem btn btn-icon btn-sm btn-danger d-none btn-icon-white-400 ';
                
                                    if ($order === null || $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    }
                
                                    $body .= '" data-kt-dialer-control="decrease">
                                    <i class="ki-duotone ki-minus fs-3x"></i>
                                </button>
                
                                <input type="text" style="background:none;" class="form-control border-0 text-center px-0 fs-3 fw-bold text-gray-800 w-30px myInput" data-kt-dialer-control="input" placeholder="Amount" name="manageBudget" readonly value="' . $itemOrder->order_quantity . '" />
                
                                <button type="button" data-id="' . $itemOrder->id . '" class="btn btn-icon btn-sm btn-primary btn-icon-white-400 d-none increaseOrderItem ';
                
                                    if ($order === null || $order->order_status === "Settled") {
                                        $body .= 'disabled';
                                    }
                
                                    $body .= '" data-kt-dialer-control="increase">
                                    <i class="ki-duotone ki-plus fs-3x"></i>
                                </button>
                            </div>
                        </td>
                    </tr>';
                }


                $body .= '</tbody></table></div>';
            } } else {
                $body .= '<div class="mt-7 d-flex flex-column align-items-center justify-content-center">
            <h5 class="text-center d-none p-3 text-white bg-danger">Cart is Empty!</h5>
            <img style="width:250px;" src="' . url("empty.png") . '"/>
            <p class="text-center" style="font-weight:900;!important;">Add Items to Cart!</p>
        </div>';
            }

            $body .= '</div>';
        } else {
            $body .= '<div class="card-body pt-15">
        <div class="mt-7 d-flex flex-column align-items-center justify-content-center">
            <h5 class="text-center d-none p-3 text-white bg-danger">Cart is Empty!</h5>
            <img style="width:250px;" src="' . url("empty.png") . '"/>
            <p class="text-center" style="font-weight:900;!important;">Add Items to Cart!</p>
        </div>
    </div>';
        }

        $body .= '';

        return response()->json(["status" => "success", "body" => $body]);

    }

    public function customerOrderSummaryDiv(Request $request){

        $computerId = $request->computerId;
        if (isset($computerId)) {
            $orderId = ComputerOrder::where("computer_id", $computerId)->value("order_id");
        }
        else{
            $orderId = null;
        }
        $taxPercentage = 0;
        // $orderId = Session::get("orderId");
        $order = Order::find($orderId);
        if ($orderId && $order && $order->order_status !== "Paid") {
            $itemOrders = ItemOrder::where('order_id', $orderId)->get();
            $subTotal = $itemOrders->sum("order_price");
            $taxRate = ($taxPercentage * $subTotal) / 100;
            $total = $subTotal + $taxRate;
            $discounts = $order->discount_amount;

        } else {
            $order = Order::find($orderId);
            $discounts = 0;
            $subTotal = 0;
            $taxRate = 0;
            $total = 0;
        }

        $contacts = Contact::all();


        $body = '';

        
        $body.='<form id="completeOrderForm">
                <!--begin::Pos order-->
                <div class="card card-flush bg-body pt-10" id="kt_pos_form">
                    <!--begin::Body-->
                    <div class="card-body pt-0">
                        <div class="separator d-flex flex-center m-6"><span class="text-uppercase bg-body fs-7 fw-semibold text-muted px-3"> SUMMARY</span></div>
                <div class="d-flex flex-stack bg-danger rounded-3 p-6 mb-3 z-depth-1">
                    <!--begin::Content-->
                    <div class="fs-6 fw-bold text-white">
                        <span class="d-block lh-1 mb-2">Subtotal</span>
                        <span class="d-block mb-2">Discounts</span>
                        <span class="d-block mt-5 pt-5 fs-2qx lh-1">Total</span>
                    </div>
                    <!--end::Content-->
                    <!--begin::Content-->
                    <div class="fs-6 fw-bold text-white text-end">
                        <span class="d-block lh-1 mb-2" data-value="" data-kt-pos-element="total">₦'.number_format($subTotal, 2).'</span>
                        <span class="d-block mb-2" data-kt-pos-element="discount">₦' . number_format($discounts, 2) . '</span>
                        <span class="d-block mt-5 pt-5 fs-2qx lh-1 grandTotal" data-value="'.$total . '" data-kt-pos-element="grant-total">₦' . number_format($total, 2) . '</span>
                    </div>
                    <!--end::Content-->
                </div>
                <input id="orderId" class="d-none" data-id="' . ($order !== null ? $order->id : '') . '" value="' . ($order !== null ? $order->id : '') . '">
                </div>
                            </div>
                            </form>';

        $body .= '';

        return response()->json(["status" => "success", "body" => $body]);
    }

    public function ajaxPOSOrders(Request $request)
    {
        $orders = Order::with('contact', 'user')->orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $orders->whereBetween('order_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $orders->whereDate('order_date', $request->startDate);
        } else {
            $orders->whereDate('order_date', now()->toDateString());
        }

        $completed = $saved = "d-none";
        if (isset($request->orderStatus) && $request->orderStatus === "Completed") {
            $orders = $orders->where("order_status", "Paid")->get();
            $completed = "";
        } elseif (isset($request->orderStatus) && $request->orderStatus === "Saved") {
            $saved = "";
            $orders = $orders->whereIn("order_status", ["Pending", "Settled"])->get();
        } else {
            $orders = $orders->get();
        }

        $main_json = [];
        $i = 0;
        foreach ($orders as $order) {
            $v = 0;
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $order->order_number . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $order->user->name . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="text-dark fw-bold fs-6">' . $order->contact->contact_name . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-success btn-active-light-success p-3 z-depth-1">₦' . number_format($order->itemOrders->sum("order_price"), decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning p-3 z-depth-1">₦' . number_format($order->discount_amount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($order->orderPayments->sum("payment_amount"), decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-info btn-active-light-info p-3 z-depth-1">₦' . number_format(($order->orderPayments->sum("payment_amount") - ($order->itemOrders->sum("order_price") + $order->discount_amount)), decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<div class="d-flex float-end"><a href="#" data-id="' . $order->id . '"  data-url="'.Crypt::encrypt($order->id).'"  class="btn fw-bold ' . $completed . '  btn-sm me-2 btn-dark btn-flex btn-center printOrder">
                        <i class="ki-duotone ki-copy fs-5 fw-bold px-0 me-2"></i> PRINT
                    </a>
                    <a href="#" data-id="' . $order->id . '" data-url="'.Crypt::encrypt($order->id).'" class="btn fw-bold  btn-sm btn-secondary btn-flex btn-center ' . $saved . ' recallOrder">
                        <i class="ki-duotone ki-plus fs-5 fw-bold px-0"></i> RECALL
                    </a></div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function saveOrder(Request $request)
    {
        $computerId = isset($request->computerId) ? $request->computerId : null;
        $computerId = Session::get("computerId");
        if (isset($computerId)) {
            ComputerOrder::where("computer_id", $computerId)->update(["order_id" => null]);
        }
        Session::put("orderId", null);
        return response()->json(["status" => "success"]);
    }

    public function revertOrder(Request $request)
    {
        $orderId = Session::get("orderId");
        Order::where("id", $orderId)->update(["order_status" => "Pending"]);
        return response()->json(["status" => "success"]);
    }

    public function settleOrder(Request $request)
    {
        $order = Order::find($request->orderId);
        if ($order && $order->order_status === "Paid") {
            return response()->json(["status" => "failed", "message" => "Order has already been paid for!"]);
        }
        Order::where("id", $request->orderId)->update(["order_status" => "Settled"]);
        return response()->json(["status" => "success"]);
    }

    public function deleteOrder(Request $request)
    {
        $orderId = $request->orderId;
        $order = Order::find($orderId);
        if ($order && $order->order_status !== "Paid") {
            $itemOrders = ItemOrder::where("order_id", $orderId)->get();
            if ($order && $order->order_status === "Settled") {
                if ($itemOrders->count() > 0) {
                    return response()->json(["status" => "failed", "message" => "Sorry Order cannot be deleted, Order has Items!"]);
                }
            }
        }

        if ($order && $order->order_status === "Paid") {
            return response()->json(["status" => "failed", "message" => "Sorry Order cannot be deleted, Order has been Paid for!"]);
        }

        ItemOrder::where("order_id", $request->orderId)->delete();
        Order::where("id", $request->orderId)->delete();
        Session::put("orderId", null);
        $computerOrderIds = ComputerOrder::where("order_id", $orderId)->pluck("id")->toArray();
        ComputerOrder::whereIn("id", $computerOrderIds)->update(["order_id" => null]);
        return response()->json(["status" => "success"]);

    }

    public function recallOrder(Request $request)
    {
        $computerId = isset($request->computerId) ? $request->computerId : null;
        Session::put("orderId", $request->orderId);
        $computerId = Session::get("computerId");
        if (isset($computerId)) {
            ComputerOrder::where("computer_id", $computerId)->update(["order_id" => $request->orderId]);
        }
        return response()->json(["status" => "success"]);
    }

    public function clearOrder(Request $request)
    {
        $orderId = $request->orderId;
        $order = Order::find($orderId);
        if ($order && ($order->order_status == "Paid" || $order->order_status == "Settled")) {
            return response()->json(["status" => "failed", "message" => "Sorry Order Items cannot be cleared, Order has been Paid/Settled!"]);
        }
        ItemOrder::where("order_id", $orderId)->delete();
        return response()->json(["status" => "success"]);
    }

    public function printOrder(Request $request)
    {
        $orderId = Crypt::decrypt($request->orderId);
        $order = Order::find($orderId);

        $contact = Contact::find($order->contact_id);
        $staff = User::find($order->user_id);
        $payments = OrderPayment::where("order_id", $order->id)->get();
        $orderId = Crypt::decrypt($request->orderId);
        $orderItemsCount = ItemOrder::where("order_id", $order->id)->count();
        return view("print_order", compact("order", "orderId", "contact", "staff", "payments", "orderItemsCount"));
    }

    public function printCustomerBill(Request $request)
    {
        $orderId = Crypt::decrypt($request->orderId);
        $order = Order::find($orderId);

        $contact = Contact::find($order->contact_id);
        $staff = User::find($order->user_id);
        $payments = OrderPayment::where("order_id", $order->id)->get();
        $orderId = Crypt::decrypt($request->orderId);
        $orderItemsCount = ItemOrder::where("order_id", $order->id)->count();
        return view("print_customer_bill", compact("order", "orderId", "contact", "staff", "payments", "orderItemsCount"));
    }
    public function generateOrderNumber()
    {
        $characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789';
        $orderNumber = substr(str_shuffle($characters), 0, 5);
        $order = Order::where("order_number", $orderNumber)->first();
        if ($order !== null) {
            $this->generateOrderNumber();
        } else {
            return $orderNumber;
        }
    }

    public function addItemPurchaseToOrder(Request $request)
    {
        $itemPurchaseId = $request->itemPurchaseId;
        $itemPurchase = ItemPurchase::where("id", $itemPurchaseId)->where("status", "Open")->first();
        if ($itemPurchase === null) {
            return response()->json(["status" => "failed", "message" => "Item not found in the Inventory!"]);
        }

        $orderId = Session::get("orderId");
        if ($orderId) {
            $order = Order::find($orderId);
            if ($order->order_status === "Settled" || $order->order_status === "Paid") {
                return response()->json(["status" => "failed", "message" => "This Order has been settled, Kindly create new order or revert!"]);
            }
        } else {
            $order = new Order();
            $order->contact_id = 1;
            $order->order_status = "Pending";
            $order->order_number = $this->generateOrderNumber();
            $order->order_date = date("Y-m-d");
            $order->user_id = Auth::user()->id;
            $order->save();
            Session::put("orderId", $order->id);
            $computerId = Session::get("computerId");
            if (isset($computerId)) {
                ComputerOrder::where("computer_id", $computerId)->update(["order_id" => $order->id]);
            }
        }

        $itemPurchase = ItemPurchase::where("id", $itemPurchaseId)->where("status", "Open")->first();
        if ($itemPurchase === null) {
            return response()->json(["status" => "failed", "message" => "Item not found in the inventory!"]);
        }

        $itemOrder = new ItemOrder();
        $itemOrder->order_id = $order->id;
        $itemOrder->item_purchase_id = $itemPurchase->id;
        $itemOrder->item_measurement_id = null;
        $itemOrder->item_measurement_quantity = 1;
        $itemOrder->order_quantity = 1;
        $itemOrder->order_price = $itemPurchase->item->item_price;
        $itemOrder->save();

        if (Auth::user()->role === "Admin") {
            $staffIds = User::pluck("id")->toArray();
        } else {
            $staffIds = [Auth::user()->id];
        }

        $savedOrders = Order::whereIn("order_status", ["Pending", "Settled"])->whereIn("user_id", $staffIds)->count();
        $todayOrders = Order::where("order_status", "Paid")->where(DB::raw("DATE(created_at)"), date("Y-m-d"))->whereIn("user_id", $staffIds)->count();

        return response()->json(["status" => "success", "savedOrdersCount" => $savedOrders, "todayOrdersCount" => $todayOrders]);

    }

    public function addItemToOrder(Request $request)
    {
        $itemPurchase = ItemPurchase::where("barcode", $request->barcode)->where("status", "Open")->first();
        if ($itemPurchase === null) {
            return response()->json(["status" => "failed", "message" => "Item not found in the Inventory!"]);
        }

        $orderId = Session::get("orderId");
        if ($orderId) {
            $order = Order::find($orderId);
            if ($order->order_status === "Settled" || $order->order_status === "Paid") {
                return response()->json(["status" => "failed", "message" => "This Order has been settled, Kindly create new order or revert!"]);
            }
        } else {
            $order = new Order();
            $order->contact_id = 1;
            $order->order_status = "Pending";
            $order->order_number = $this->generateOrderNumber();
            $order->order_date = date("Y-m-d");
            $order->user_id = Auth::user()->id;
            $order->save();
            Session::put("orderId", $order->id);
            $computerId = Session::get("computerId");
            if (isset($computerId)) {
                ComputerOrder::where("computer_id", $computerId)->update(["order_id" => $order->id]);
            }
        }

        $itemPurchase = ItemPurchase::where("barcode", $request->barcode)->where("status", "Open")->first();
        if ($itemPurchase === null) {
            return response()->json(["status" => "failed", "message" => "Item not found in the inventory!"]);
        }

        $itemOrder = new ItemOrder();
        $itemOrder->order_id = $order->id;
        $itemOrder->item_purchase_id = $itemPurchase->id;
        $itemOrder->item_measurement_id = null;
        $itemOrder->item_measurement_quantity = 1;
        $itemOrder->order_quantity = 1;
        $itemOrder->order_price = $itemPurchase->item->item_price;
        $itemOrder->save();

        if (Auth::user()->role === "Admin") {
            $staffIds = User::pluck("id")->toArray();
        } else {
            $staffIds = [Auth::user()->id];
        }

        $savedOrders = Order::whereIn("order_status", ["Pending", "Settled"])->whereIn("user_id", $staffIds)->count();
        $todayOrders = Order::where("order_status", "Paid")->where(DB::raw("DATE(created_at)"), date("Y-m-d"))->whereIn("user_id", $staffIds)->count();

        return response()->json(["status" => "success", "savedOrdersCount" => $savedOrders, "todayOrdersCount" => $todayOrders]);

    }

    public function addItemToPurchase(Request $request)
    {
        $itemPurchase = ItemPurchase::find($request->itemPurchaseId);
        $orderId = Session::get("orderId");
        if ($orderId) {
            $order = Order::find($orderId);
            if ($order->order_status === "Settled" || $order->order_status === "Paid") {
                return response()->json(["status" => "failed", "message" => "This Order has been settled, Kindly create new order or revert!"]);
            }
        } else {
            $order = new Order();
            $order->contact_id = 1;
            $order->order_status = "Pending";
            $order->order_number = $this->generateOrderNumber();
            $order->order_date = date("Y-m-d");
            $order->user_id = Auth::user()->id;
            $order->save();
            Session::put("orderId", $order->id);
            $computerId = Session::get("computerId");
            if (isset($computerId)) {
                ComputerOrder::where("computer_id", $computerId)->update(["order_id" => $order->id]);
            }
        }

        $itemOrder = new ItemOrder();
        $itemOrder->order_id = $order->id;
        $itemOrder->item_purchase_id = $itemPurchase->id;
        $itemOrder->item_measurement_id = null;
        $itemOrder->item_measurement_quantity = 1;
        $itemOrder->order_quantity = 1;
        $itemOrder->order_price = $itemPurchase->item->item_price;
        $itemOrder->save();

        return response()->json(["status" => "success"]);

    }

    public function currentOrderDiv(Request $request)
    {
        $orderId = Session::get("orderId");
        $order = Order::find($orderId);
        $body = '';

        $body .= '
        <div class="card-header pt-5">
            <h3 class="card-title fw-bold text-gray-800 fs-2qx">Current Order</h3>
            <div class="card-toolbar">
                <a href="#" ';

        if ($order !== null) {
            $body .= 'data-id="' . $order->id . '"';
        } else {
            $body .= 'data-id="" disabled';
        }

        $body .= ' class="btn btn-dark fs-4 me-2 clearOrder ';

        if ($order === null || $order->order_status === "Settled" || $order->order_status === "Paid") {
            $body .= 'disabled';
        }

        $body .= '"><i class="bi bi-bag-x-fill fs-4 me-0"></i> Clear All</a>';

        $body .= '<a href="#" ';

        if ($order !== null) {
            $body .= 'data-id="' . $order->id . '"';
        } else {
            $body .= 'data-id="" disabled';
        }

        $body .= ' class="btn btn-danger fs-4 deleteOrder ';

        if ($order === null || $order->order_status === "Settled" || $order->order_status === "Paid") {
            $body .= 'disabled';
        }

        $body .= '"><i class="bi bi-trash fs-4 me-0"></i> Delete </a>
            </div>
        </div>';

        if ($order !== null) {
            $itemOrders = ItemOrder::where("order_id", $order->id)->orderByDesc("id")->get();

            $body .= '<div class="card-body ';

            if ($itemOrders->count() === 0) {
                $body .= 'pt-15';
            } else {
                $body .= 'pt-0';
            }

            $body .= '">';

            if ($itemOrders->count() > 0) {
                $body .= '<div class="table-responsive overflow-y-auto mb-8" style="
                min-height: 450px;
            ">
            <table class="table align-middle gs-0 gy-4 my-0">
                <thead>
                    <tr>
                        <th class="min-w-175px"></th>
                        <th class="w-125px"></th>
                    </tr>
                </thead>
                <tbody>';

                foreach ($itemOrders as $itemOrder) {
                    $item = $itemOrder->itemPurchase->item;
                    $itemMeasurements = $item->itemMeasurements;
                    $itemMeasurementSelected = $itemOrder->item_measurement_id === null ? "selected" : "";
                    $body .= '<tr class="z-depth-1" data-kt-pos-element="item" data-kt-pos-item-price="33">
        <td class="pe-0 ';

                    if ($order !== null && $order->order_status === "Settled") {
                        $body .= 'disabled';
                    } else {
                        $body .= 'itemOrder';
                    }
                    $src = "setup/menu.jpg?2";
                    $body .= '" data-id="' . $itemOrder->id . '">
        <div class="d-flex align-items-center mb-0">
            <div class="symbol symbol-60px me-5 z-depth-1" style="padding: 5px;border-radius: 15px;border: 1px solid #aaa;">
                <img src="' . url($src) . '" class="" alt="">
            </div>
            <div class="flex-grow-1">
                <a href="#" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>
                <hr class="border-1 p-0 mt-0 mb-0 w-300px"/>
                <div class="">
                    <select class="itemMeasurement" id="" data-live-search="true" data-width="50%" name="itemMeasurementId" data-placeholder="Select Measurement">
                        <option value="0" data-item_order_id="' . $itemOrder->id . '" ' . $itemMeasurementSelected . '>' . $item->item_measurement . '</option>';
                    foreach ($itemMeasurements as $itemMeasurement) {
                        $selected = "";
                        if ($itemMeasurement->id === $itemOrder->item_measurement_id) {
                            $selected = " selected";
                        }
                        $body .= '<option value="' . $itemMeasurement->id . '" data-item_order_id="' . $itemOrder->id . '"  ' . $selected . '>' . $itemMeasurement->measurement->measurement_name . '</option>';
                    }
                    $body .= '</select>
                </div>
                <hr class="border-1 p-0 mt-0 mb-0 w-300px"/>
                <input hidden class="barcode" value="' . $itemOrder->itemPurchase->barcode . '"/>
                <span class="text-muted d-block">₦' . number_format(($itemOrder->order_price), 2) . '</span>';

                    $body .= '</div></div></td>
        <td class="pe-0">
            <div class="position-relative d-flex align-items-center" data-kt-dialer="true" data-kt-dialer-min="1" data-kt-dialer-max="100000" data-kt-dialer-step="1" data-kt-dialer-decimals="0">
                <button type="button" data-id="' . $itemOrder->id . '" class="decreaseItemOrder btn btn-icon btn-sm btn-danger btn-icon-white-400 ';

                    if ($order === null || $order->order_status === "Settled" || $order->order_status === "Paid") {
                        $body .= 'disabled';
                    }

                    $body .= '" data-kt-dialer-control="decrease">
                    <i class="ki-duotone ki-minus fs-3x"></i>
                </button>

                <input type="text" class="form-control border-0 text-center px-0 fs-3 fw-bold text-gray-800 w-30px myInput" data-kt-dialer-control="input" placeholder="Amount" name="" readonly value="' . $itemOrder->item_measurement_quantity . '" />

                <button type="button" data-id="' . $itemOrder->id . '" class="btn btn-icon btn-sm btn-primary btn-icon-white-400 increaseItemOrder ';

                    if ($order === null || $order->order_status === "Settled" || $order->order_status === "Paid") {
                        $body .= 'disabled';
                    }

                    $body .= '" data-kt-dialer-control="increase">
                    <i class="ki-duotone ki-plus fs-3x"></i>
                </button>
            </div>
        </td>
    </tr>';
                }


                $body .= '</tbody></table></div>';
            } else {
                $body .= '<div class="mt-7 d-flex flex-column align-items-center justify-content-center">
            <h5 class="text-center d-none p-3 text-white bg-danger">Cart is Empty!</h5>
            <img style="width:250px;" src="' . url("empty.png") . '"/>
            <p class="text-center" style="font-weight:900;!important;">Add Items to Cart!</p>
        </div>';
            }

            $body .= '</div>';
        } else {
            $body .= '<div class="card-body pt-15">
        <div class="mt-7 d-flex flex-column align-items-center justify-content-center">
            <h5 class="text-center d-none p-3 text-white bg-danger">Cart is Empty!</h5>
            <img style="width:250px;" src="' . url("empty.png") . '"/>
            <p class="text-center" style="font-weight:900;!important;">Add Items to Cart!</p>
        </div>
    </div>';
        }

        $body .= '';

        return response()->json(["status" => "success", "body" => $body]);

    }

    public function orderSummaryDiv(Request $request)
    {
        $taxPercentage = 0;
        $orderId = Session::get("orderId");
        
        $order = Order::find($orderId);
        if ($orderId && $order && $order->order_status !== "Paid") {
            $itemOrders = ItemOrder::where('order_id', $orderId)->get();
            $subTotal = $itemOrders->sum("order_price");
            $taxRate = ($taxPercentage * $subTotal) / 100;
            $total = $subTotal + $taxRate;
            $discounts = $order->discount_amount;

        } else {
            $order = Order::find($orderId);
            $discounts = 0;
            $subTotal = 0;
            $taxRate = 0;
            $total = 0;
        }

        $contacts = Contact::all();

        $body = '';
        $body .= '<form id="completeOrderForm">
                <!--begin::Pos order-->
                <div class="card card-flush bg-body pt-10" id="kt_pos_form">
                    <!--begin::Body-->
                    <div class="card-body pt-0">
                        <div class="mb-2 d-flex" style="justify-content: space-between;" id="orderButtons">';
        if ($order !== null && ($order->order_status === "Settled")) {
            $body .= '<a href="#" class="btn btn-info btn-sm saveOrder"><i class="bi bi-plus fs-4 me-2"></i> New </a>
                                <a href="#" data-id="' . ($order !== null ? $order->id : '') . '" class="btn btn-danger btn-sm revertSettledOrder d-none"><i class="bi bi-backspace-reverse fs-4 me-2"></i> Revert Order</a>';
        } else {
            $body .= '<a href="#" class="btn btn-info btn-sm saveOrder"><i class="bi bi-cloud-upload-fill fs-4 me-2"></i> Save Order</a>
                                <a href="#" data-id="' . ($order !== null ? $order->id : '') . '" class="btn btn-dark btn-sm settleOrder"><i class="bi bi-bell-fill fs-4 me-2"></i> Settle Order </a>';
        }
        if ($order !== null && ($order->order_status === "Settled" || $order->order_status === "Paid")) {
            $body .= '<a href="#" data-url="' . ($order !== null ? Crypt::encrypt($order->id) : '') . '" class="btn btn-success printOrder btn-sm"><i class="bi bi-printer-fill fs-4 me-2"></i> Print </a>';
        }
        $body .= '</div>
                        <div class="separator d-flex flex-center m-6"><span class="text-uppercase bg-body fs-7 fw-semibold text-muted px-3"> SUMMARY</span></div>
                        
                        <div class=" border p-1 mb-1">
                        <div class="d-flex align-items-center">
                            <!--begin::Avatar-->
                            <div class="symbol symbol-50px me-1">
                                <a href="#" data-bs-target="#addCustomerModal" data-bs-toggle="modal" class="btn btn-icon btn-secondary addCustomer ' . ($order !== null && $order->order_status === "Settled" ? "disabled" : "") . '">
                                    <i class="bi bi-person-add fs-1"></i>
                                </a>
                            </div>
                            <!--end::Avatar-->
                            <!--begin::Text-->
                            <div class="flex-grow-1">
                                <select class="customerId" data-live-search="true" data-width="100%" ' . ($order !== null && $order->order_status === "Settled" ? "disabled" : "") . ' name="customerId" data-placeholder="Select Customer" id="customerId">
                                ';
        foreach ($contacts as $contact) {
            $body .= '<option value="' . $contact->id . '" ' . ($order !== null && $order->contact_id === $contact->id ? "selected" : "") . '>
                                                                        ' . $contact->contact_name . ' (' . $contact->contact_phone_number . ')</option>';
        }
        $body .= '</select>
                            </div>
                            <!--end::Text-->
                        </div>
                        </div>
            

                    </div>


                <div class="px-5">
                    <div class="d-flex flex-stack bg-danger rounded-3 p-6 mb-3 z-depth-1">
                    <!--begin::Content-->
                    <div class="fs-6 fw-bold text-white">
                        <span class="d-block lh-1 mb-2">Subtotal</span>
                        <span class="d-block mb-2">Discounts</span>
                        <span class="d-block mb-9">Tax(' . $taxPercentage . '%)</span>
                        <span class="d-block fs-2qx lh-1">Total</span>
                    </div>
                    <!--end::Content-->
                    <!--begin::Content-->
                    <div class="fs-6 fw-bold text-white text-end">
                        <span class="d-block lh-1 mb-2" data-value="" data-kt-pos-element="total">₦' . number_format($subTotal, 2) . '</span>
                        <span class="d-block mb-2" data-kt-pos-element="discount">₦' . number_format($discounts, 2) . '</span>
                        <span class="d-block mb-9" data-kt-pos-element="tax">₦' . number_format($taxRate, 2) . '</span>
                        <span class="d-block fs-2qx lh-1 grandTotal" data-value="' . $total . '" data-kt-pos-element="grant-total">₦' . number_format($total, 2) . '</span>
                    </div>
                    <!--end::Content-->
                    </div>
                </div>
                <div class="separator d-flex flex-center m-6"><span class="text-uppercase bg-body fs-7 fw-semibold text-muted px-3">MAKE PAYMENT</span></div>
                <div class="border d-none p-1 mb-3">
                    <div class="d-flex align-items-center">
                        <!--begin::Avatar-->
                        <div class="symbol symbol-50px me-1">
                            <a href="#" data-id="' . ($order !== null ? $order->id : '') . '" class="btn btn-icon btn-danger orderDiscount"><i class="bi bi-plus-slash-minus fs-1"></i></a>
                        </div>
                        <!--end::Avatar-->
                        <!--begin::Text-->
                        <div class="flex-grow-1">
                            <input type="text" data-id="' . ($order !== null ? $order->id : '') . '" disabled class="myInput form-control form-control-lg form-control-solid" name="discount" placeholder="Discount (₦' . number_format($discounts, 2) . ')" value="">
                        </div>
                        <!--end::Text-->
                    </div>
                </div>
                <input id="orderId" class="d-none" data-id="' . ($order !== null ? $order->id : '') . '" value="' . ($order !== null ? $order->id : '') . '">
                <!--begin::Payment Method-->
                <div class="p-5 z-depth-1" style="border-radius:6px;">
                    <!--end::Repeater-->
                    <!--begin::Actions-->
                    <button type="button" data-bs-target="#makePaymentModal" data-bs-toggle="modal" style="background: seagreen;" class="' . ($order !== null ? '' : 'disabled') . ' btn btn-primary fs-1 w-100 py-4 completePayment">Complete Payment</button>
                    <!--end::Actions-->
                </div>
                </div>
                            </div>
                            </form>';

        $body .= '';

        return response()->json(["status" => "success", "body" => $body]);
    }

    public function pointOfSaleSummary(Request $request)
    {
        if (Auth::user()->role === "Admin") {
            $staffIds = User::pluck("id")->toArray();
        } else {
            $staffIds = [Auth::user()->id];
        }

        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;

        $savedOrders = Order::whereIn("order_status", ["Pending", "Settled"])->whereBetween(DB::raw("DATE(created_at)"), [$startDate, $endDate])->whereIn("user_id", $staffIds)->get();
        $completedOrders = Order::where("order_status", "Paid")->whereBetween(DB::raw("DATE(created_at)"), [$startDate, $endDate])->whereIn("user_id", $staffIds)->get();

        return response()->json(["status" => "success", "savedOrders" => $savedOrders->count(), "completedOrders" => $completedOrders->count()]);
    }

    public function updateOrderCustomer(Request $request)
    {
        Order::where("id", $request->orderId)->update(["contact_id" => $request->contactId]);
        return response()->json(["status" => "success"]);
    }

    public function updateItemOrderMeasurement(Request $request)
    {
        $itemOrder = ItemOrder::find($request->itemOrderId);
        if ($request->itemMeasurementId === "0") {
            $orderQuantity = $itemOrder->item_measurement_quantity;
            $itemOrder->item_measurement_id = null;
            $itemOrder->item_measurement_quantity = $orderQuantity;
            $itemOrder->order_quantity = $orderQuantity;
            $itemOrder->order_price = $orderQuantity * $itemOrder->itemPurchase->item->item_price;
        } else {
            $itemMeasurement = ItemMeasurement::find($request->itemMeasurementId);
            $orderQuantity = $itemMeasurement->quantity * $itemOrder->item_measurement_quantity;
            $itemOrder->item_measurement_id = $request->itemMeasurementId;
            $itemOrder->order_quantity = $orderQuantity;
            $itemOrder->order_price = $orderQuantity * $itemMeasurement->item->item_price;
        }
        $itemOrder->save();
        return response()->json(["status" => "success"]);
    }

    public function increaseItemOrder(Request $request)
    {
        $itemOrder = ItemOrder::find($request->itemOrderId);
        if ($itemOrder->item_measurement_id === null) {
            $orderQuantity = $itemOrder->item_measurement_quantity + 1;
            $itemOrder->item_measurement_id = null;
            $itemOrder->item_measurement_quantity = $orderQuantity;
            $itemOrder->order_quantity = $orderQuantity;
            $itemOrder->order_price = $orderQuantity * $itemOrder->itemPurchase->item->item_price;
        } else {
            $itemMeasurement = ItemMeasurement::find($itemOrder->item_measurement_id);
            $orderQuantity = $itemMeasurement->quantity * ($itemOrder->item_measurement_quantity + 1);
            $itemOrder->item_measurement_quantity = ($itemOrder->item_measurement_quantity + 1);
            $itemOrder->order_quantity = $orderQuantity;
            $itemOrder->order_price = $orderQuantity * $itemMeasurement->item->item_price;
        }
        $itemOrder->save();
        return response()->json(["status" => "success"]);
    }

    public function decreaseItemOrder(Request $request)
    {
        $itemQuantity = ItemOrder::where("id", $request->itemOrderId)->value("item_measurement_quantity");
        if ($itemQuantity > 1) {
            $itemOrder = ItemOrder::find($request->itemOrderId);
            if ($itemOrder->item_measurement_id === null) {
                $orderQuantity = $itemOrder->item_measurement_quantity - 1;
                $itemOrder->item_measurement_id = null;
                $itemOrder->item_measurement_quantity = $orderQuantity;
                $itemOrder->order_quantity = $orderQuantity;
                $itemOrder->order_price = $orderQuantity * $itemOrder->itemPurchase->item->item_price;
            } else {
                $itemMeasurement = ItemMeasurement::find($itemOrder->item_measurement_id);
                $orderQuantity = $itemMeasurement->quantity * ($itemOrder->item_measurement_quantity - 1);
                $itemOrder->item_measurement_quantity = ($itemOrder->item_measurement_quantity - 1);
                $itemOrder->order_quantity = $orderQuantity;
                $itemOrder->order_price = $orderQuantity * $itemMeasurement->item->item_price;
            }
            $itemOrder->save();
        } else {
            ItemOrder::where("id", $request->itemOrderId)->delete();
        }
        return response()->json(["status" => "success"]);
    }

}
