<?php

namespace App\Http\Controllers;

use App\Models\Contact;
use Illuminate\Http\Request;
use App\Models\Order;
use App\Models\OrderPayment;
use App\Models\ItemOrder;
use App\Models\Item;
use App\Models\ItemMeasurement;
use App\Models\ComputerOrder;
use App\Models\User;
use App\Models\ItemPurchase;
use App\Models\Purchase;
use App\Models\Payment;
use App\Models\PaymentMethod;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

class OrderPaymentController extends Controller
{
    public function makeOrderPayments(Request $request)
    {
        $orderId = Session::get("orderId");
        $payments = $request->payments;

        $validPayments = array_filter($payments, function ($payment) {
            return isset($payment['paymentMode'], $payment['amountPaid'], $payment['paymentDate']);
        });

        $paymentIdentifiers = array_map(function ($payment) {
            return $payment['paymentMode'] . '_' . $payment['paymentDate'];
        }, $validPayments);

        $uniquePaymentIdentifiers = array_unique($paymentIdentifiers);

        if (count($paymentIdentifiers) !== count($uniquePaymentIdentifiers)) {
            return response()->json(["status" => "failed", "message" => "Duplicate Payment Modes with Same Dates!"]);
        }

        if (count($validPayments) === 0) {
            return response()->json(["status" => "failed", "message" => "Please fill all payment details!"]);
        }

        $amounts = array_column($validPayments, 'amountPaid');
        $totalAmountPaid = array_sum($amounts);
        $taxPercentage = 0;
        if ($orderId) {
            $order = Order::find($orderId);
            if ($order->order_status === "Paid") {
                return response()->json(["status" => "failed", "message" => "Order has already been Paid for!"]);
            }

            if (($order->order_amount > 0) || ($order->itemOrders->sum("order_price") > 0)) {
                if (!($order->itemOrders->sum("order_price") > 0)) {
                    return response()->json(["status" => "failed", "message" => "Please add items to cart, There is nothing to pay for!"]);
                } else {

                    if (isset($payments) && count($payments) > 0) {

                        $subTotal = $order->itemOrders->sum("order_price");
                        $discountRate = 0.00;
                        $discounts = $subTotal * $discountRate;
                        $taxRate = ($taxPercentage * $subTotal) / 100;
                        $orderDiscount = $discounts;

                        $total = $subTotal + $taxRate - $orderDiscount;
                        $balanceAmount = $totalAmountPaid - $total;

                        if (!($order->itemOrders->count() > 0)) {
                            return response()->json(["status" => "failed", "message" => "Please add items to cart, There is nothing to pay for!"]);
                        }

                        if ($total > $totalAmountPaid) {
                            return response()->json(["status" => "failed", "message" => "Total to Pay <b>₦" . number_format($total, 2) . "</b> is greater than Amount Paid <b>₦" . number_format($totalAmountPaid, 2) . "</b>"]);
                        }

                        foreach ($payments as $payment) {
                            if (isset($payment["paymentMode"]) && isset($payment["amountPaid"])) {
                                $newPayment = new OrderPayment();
                                $newPayment->order_id = $orderId;
                                $newPayment->payment_method_id = $payment["paymentMode"];
                                $newPayment->payment_date = $payment["paymentDate"];
                                $newPayment->payment_amount = $payment["amountPaid"];
                                $newPayment->payment_status = "Approved";
                                $newPayment->user_id = Auth::user()->id;
                                if ($order->order_date != $payment["paymentDate"]) {
                                    $newPayment->late_payment = "Yes";
                                }
                                $newPayment->save();
                            }
                        }

                        Order::where("id", $orderId)->update(["order_status" => "Paid", "order_amount" => $total, "discount_amount" => $orderDiscount, "change_amount" => $balanceAmount]);
                        Session::put("orderId", null);
                        $computerId = Session::get("computerId");
                        if (isset($computerId)) {
                            ComputerOrder::where("computer_id", $computerId)->update(["order_id" => null]);
                        }

                        return response()->json(["status" => "success", "url" => url("print_order?orderId=" . Crypt::encrypt($orderId))]);
                    } else {
                        return response()->json(["status" => "failed", "message" => "Please add payments for Order!"]);
                    }
                }
            } else {
                return response()->json(["status" => "failed", "message" => "Please add items to cart, There is nothing to pay for!"]);
            }
        } else {
            return response()->json(["status" => "failed", "message" => "There is no active Order!"]);
        }
    }

    public function orderPayments(Request $request){
        $orderPayments = OrderPayment::where("order_id", $request->orderId)->get();
        $main_json = [];
        $i = 0;
        foreach($orderPayments as $orderPayment){
            $paymentMethod = PaymentMethod::find($orderPayment->payment_method_id);
            $user = User::find($orderPayment->user_id);
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning p-3 z-depth-1">₦' . number_format($orderPayment->payment_amount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $paymentMethod->payment_method_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . Carbon::parse($orderPayment->payment_date)->isoFormat('ddd, DD/MMM/YYYY') . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $user->name . '</a>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }
}
