<?php

namespace App\Http\Controllers;

use App\Models\PaymentMethod;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Str;

class PaymentMethodController extends Controller
{

    public function getPaymentMethods(Request $request)
    {
        $paymentMethods = PaymentMethod::all();
        return view("payment_methods", compact("paymentMethods"));
    }

    public function ajaxPaymentMethods(Request $request)
    {
        $paymentMethods = PaymentMethod::all();
        $main_json = [];
        $i = 0;
        foreach ($paymentMethods as $paymentMethod) {
            if ($paymentMethod->payment_method_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $paymentMethod->payment_method_name;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $paymentMethod->payment_method_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
                    Actions
                    <i class="ki-duotone ki-down fs-5 ms-1"></i>
                </a>
                <div
                    class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
                    data-kt-menu="true"
                >
                    <div class="menu-item px-3">
                        <a href="#" data-id="' . $paymentMethod->id . '" class="menu-link px-3 editPaymentMethod">
                            Edit
                        </a>
                    </div>
                    <div class="menu-item px-3">
                        <a
                            href="#"
                            data-id="' . $paymentMethod->id . '"
                            class="menu-link px-3 deletePaymentMethod"
                            data-kt-customer-table-filter="delete_row"
                        >
                            Delete
                        </a>
                    </div>
                </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function createPaymentMethod(Request $request)
    {
        $paymentMethod = new PaymentMethod();
        $paymentMethod->payment_method_name = $request->paymentMethodName;
        if (isset($request->paymentMethodStatus)) {
            $paymentMethod->payment_method_status = $request->paymentMethodStatus;
        } else {
            $paymentMethod->payment_method_status = "Inactive";
        }
        $paymentMethod->save();
        return response()->json(["status" => "success"]);
    }

    public function editPaymentMethodForm(Request $request)
    {
        $paymentMethod = PaymentMethod::where("id", $request->paymentMethodId)->first();
        $paymentMethodStatus = $paymentMethod->payment_method_status === 'Active' ? 'checked' : '';

        $title = "Edit Payment Method";
        $body = "";
        $body .= '
            <form id="editPaymentMethodForm">
            <input value="' . csrf_token() . '" class="d-none">
            <input value="' . $paymentMethod->id . '" name="paymentMethodId" class="d-none">

            <!--begin::Input group-->
            <div class="fv-row mb-7">
                <!--begin::Label-->
                <label class="required fs-6 fw-semibold mb-2">Name</label>
                <!--end::Label-->
                <!--begin::Input-->
                <input type="text" class="form-control form-control-solid" placeholder="Enter payment method name" name="paymentMethodName" value="' . $paymentMethod->payment_method_name . '" />
                <!--end::Input-->
            </div>
            <!--end::Input group-->

            <!--begin::Input group-->
            <div class="fv-row mb-7">
                <!--begin::Label-->
                <label class="required fs-6 fw-semibold mb-2">Status</label>
                <!--end::Label-->

                <!--begin::Input-->
                <div class="form-check form-switch form-check-custom form-check-solid">
                    <input class="form-check-input" type="checkbox" value="Active" id="paymentMethodStatus" name="paymentMethodStatus" ' . $paymentMethodStatus . '>
                    <label class="form-check-label fw-semibold text-gray-400 ms-3" for="paymentMethodStatus">
                        Active
                    </label>
                </div>
                <!--end::Input-->
            </div>
            <!--end::Input group-->
            <div class="modal-footer">
                <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary">Submit</button>
            </div>
        </form>';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editPaymentMethod(Request $request)
    {

        $paymentMethod = PaymentMethod::where("id", $request->paymentMethodId)->first();
        $paymentMethod->payment_method_name = $request->paymentMethodName;
        if (isset($request->paymentMethodStatus)) {
            $paymentMethod->payment_method_status = $request->paymentMethodStatus;
        } else {
            $paymentMethod->payment_method_status = "Inactive";
        }
        $paymentMethod->save();
        return response()->json(["status" => "success"]);
    }

    public function deletePaymentMethod(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'payment_method_id')) {
                $paymentMethodId = DB::table($table)->where('payment_method_id', $request->paymentMethodId)->exists();
                if ($paymentMethodId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Payment Method has data!"]);
                }
            }
        }
        PaymentMethod::where("id", $request->paymentMethodId)->delete();
        return response()->json(["status" => "success"]);
    }
}
