<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Contact;
use App\Models\Item;
use App\Models\Station;
use App\Models\Purchase;
use App\Models\ItemCategory;
use App\Models\ItemMeasurement;
use App\Models\ItemPurchase;
use App\Models\PaymentMethod;
use App\Models\PurchasePayment;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Schema;

class PurchaseController extends Controller
{
    public function getStocks(Request $request)
    {

        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->startOfMonth()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : Carbon::now()->endOfMonth()->format('Y-m-d');

        $purchases = Purchase::all();
        $items = Item::all();
        $contacts = Contact::all();
        $stations = Station::all();
        $itemCategories = ItemCategory::all();
        $paymentMethods = PaymentMethod::all();

        return view("stocks", compact("paymentMethods", "purchases", "items", "contacts", "startDate", "endDate", "itemCategories"));
    }

    public function generateBarcode(Request $request){
        $itemId = str_pad($request->itemId, 4, '0', STR_PAD_LEFT);
        $barcode = '';

        do {
            $randomString = strtoupper(substr(str_shuffle('ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'), 0, 5));
            $barcode = $itemId . '-' . $randomString;
        } while (ItemPurchase::where('barcode', $barcode)->exists());
    
        return response()->json(['barcode' => $barcode]);
    }

    public function generateStockBarcode($itemId){
        $itemId = str_pad($itemId, 4, '0', STR_PAD_LEFT);
        $barcode = '';

        do {
            $randomString = strtoupper(substr(str_shuffle('ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'), 0, 5));
            $barcode = $itemId . '-' . $randomString;
        } while (ItemPurchase::where('barcode', $barcode)->exists());
        
        return $barcode;
        // return response()->json(['barcode' => $barcode]);
    }

    public function addStock(Request $request){
        
        $purchase = new Purchase();
        $purchase->purchase_number = $this->generatePurchaseNumber();
        $purchase->invoice_number = $request->invoiceNumber;
        $purchase->contact_id = $request->contactId;
        $purchase->purchase_date = $request->purchaseDate;
        $purchase->discount_amount = $request->discountAmount;
        $purchase->user_id = Auth::user()->id;
        $purchase->save();

        $itemPurchases = $request->itemPurchases;
        foreach ($itemPurchases as $itemPurchase) {

            $item = new Item();
            $item->item_name =  $itemPurchase['itemName'];
            // $item->item_category_id =  isset($itemPurchase["itemCategoryId"]) ? $itemPurchase['itemCategoryId'] : 1;
            $item->item_category_id = 1;
            $item->item_description = $itemPurchase['itemName'];
            $item->stock_alert_below = 20;
            $item->item_price = $itemPurchase['itemPrice'];
            $item->item_measurement = 'UNIT';
            // $item->item_measurement = $itemPurchase['itemMeasurement'];
            $item->item_status = "Active";
            $item->save();

            $stockBarcode = $this->generateStockBarcode($item->id);

            $itemPurchaseModel = new ItemPurchase();
            $itemPurchaseModel->purchase_id = $purchase->id;
            $itemPurchaseModel->item_id = $item->id;
            $itemPurchaseModel->measurement_id = null;
            $itemPurchaseModel->measurement_quantity = null;
            $itemPurchaseModel->purchase_quantity = $itemPurchase['stockQuantity'];
            $itemPurchaseModel->expiry_date = $itemPurchase['expiryDate'];
            $itemPurchaseModel->cost_price = $itemPurchase['costPrice'] * $itemPurchase["stockQuantity"];
            $itemPurchaseModel->unit_price = $itemPurchase['costPrice'];
            $itemPurchaseModel->barcode = isset($itemPurchase['barcode']) ? $itemPurchase['barcode'] : $stockBarcode;
            $itemPurchaseModel->save();
        }

        return response()->json(['status' => "success"]);
    }

    public function getPurchases(Request $request)
    {

        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->startOfMonth()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : Carbon::now()->endOfMonth()->format('Y-m-d');

        $purchases = Purchase::all();
        $items = Item::all();
        $stations = Station::all();
        $contacts = Contact::all();
        $itemCategories = ItemCategory::all();
        $paymentMethods = PaymentMethod::all();

        return view("purchases", compact("paymentMethods", "stations", "purchases", "items", "contacts", "startDate", "endDate", "itemCategories"));
    }

    public function ajaxPurchases(Request $request)
    {
        $purchases = Purchase::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $purchases->whereBetween('purchase_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $purchases->whereDate('purchase_date', $request->startDate);
        } else {
            $purchases->whereDate('purchase_date', now()->toDateString());
        }
        $purchases = $purchases->get();
        $main_json = [];
        $i = 0;
        foreach ($purchases as $purchase) {
            $purchasePaymentsAmount = PurchasePayment::where('purchase_id', $purchase->id)->sum('payment_amount');
            $contact = Contact::find($purchase->contact_id);
            $totalCostPrice = ItemPurchase::where("purchase_id", $purchase->id)->sum("cost_price");
            $itemPurchases = ItemPurchase::where("purchase_id", $purchase->id)->get();
            $itemNames = $purchase->itemPurchases->pluck('item.item_name')->implode(', ');
            $v = 0;
            $main_json[$i][$v++] = $purchase->purchase_number;
            $main_json[$i][$v++] = $purchase->invoice_number;
            $main_json[$i][$v++] = $contact->contact_name;
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($totalCostPrice, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m btn-outline btn-outline-dashed btn-outline-info btn-active-light-info p-3 z-depth-1">₦' . number_format($purchase->discount_amount, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m btn-outline btn-outline-dashed btn-outline-success btn-active-light-success p-3 z-depth-1">₦' . number_format($purchasePaymentsAmount, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m btn-outline btn-outline-dashed btn-outline-danger btn-active-light-danger p-3 z-depth-1">₦' . number_format(($totalCostPrice - ($purchasePaymentsAmount + $purchase->discount_amount)), 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" data-id="' . $purchase->id . '" data-bs-toggle="modal" data-bs-target="#viewPurchaseItemsModal" class="btn btn-sm btn-dark viewItemPurchases"><i class="bi bi-list-check fs-4 me-2"></i>Item List (' . $itemPurchases->count() . '/' . $itemPurchases->count() . ')</a>';
            $main_json[$i][$v++] = Carbon::parse($purchase->purchase_date)->isoFormat('ddd, DD/MMM/YYYY');
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
                Actions
                <i class="ki-duotone ki-down fs-5 ms-1"></i>
            </a>
            <div
                class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
                data-kt-menu="true"
            >

                <div class="menu-item px-3">
                    <a href="javascript:;" data-bs-toggle="modal" data-bs-target="#purchasePaymentsModal" data-id="' . $purchase->id . '" class="menu-link px-3 purchasePayments">
                        Payments
                    </a>
                </div>

                <div class="menu-item px-3">
                    <a href="javascript:;" data-id="' . $purchase->id . '" data-bs-toggle="modal" data-bs-target="#viewPurchaseItemsModal" class="menu-link px-3 editPurchase">
                        Edit
                    </a>
                </div>

                <div class="menu-item px-3">
                    <a
                        href="javascript:;"
                        data-id="' . $purchase->id . '"
                        class="menu-link px-3 deletePurchase"
                        data-kt-customer-table-filter="delete_row"
                    >
                        Delete
                    </a>
                </div>
            </div>';
            $main_json[$i][$v++] = $itemNames;
            $i++;
        }
        return response()->json(["returned_data" => $main_json]);
    }

    public function editPurchaseForm(Request $request){
        
        $itemPurchases = ItemPurchase::where("purchase_id", $request->purchaseId)->orderByDesc("id")->get();
        $main_json = [];
        $i = 0;
        foreach($itemPurchases as $itemPurchase){
            $body = "";
            $item = $itemPurchase->item;
            $totalPurchases = $itemPurchase->purchase_quantity;
            $expiryDate = isset($itemPurchase->expiry_date) ? Carbon::parse($itemPurchase->expiry_date)->isoFormat('ddd, DD/MMM/YYYY') : null;
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemMeasurementQuantity = intval($totalPurchases / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalPurchases - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<form class="updateItemPurchaseForm'.$itemPurchase->id.'"><div class="flex justify-end gap-2.5"><a href="javascript:;" data-id="'.$itemPurchase->id.'" class="btn me-2 mb-2 btn-sm fw-bold btn-danger btn-active-light-danger p-3 rounded-1 z-depth-1 deleteItemPurchase"><i class="bi bi-trash fs-4 me-0"></i></a>
            <a href="javascript:;" data-id="'.$itemPurchase->id.'" class="btn btn-sm fw-bold btn-success btn-active-light-success p-3 rounded-1 z-depth-1 editItemPurchase"><i class="bi bi-save fs-4 me-0"></i></a></div>';
            $main_json[$i][$v++] = '<input type="text" value="'.$itemPurchase->barcode.'" class="form-control mb-2 mb-md-0" name="barcodes['.$itemPurchase->id.']" placeholder="Enter barcode" />';
            $main_json[$i][$v++] = $itemPurchase->item->item_name;
            $main_json[$i][$v++] = '<input type="text" value="'.$totalPurchases.'" class="form-control mb-2 mb-md-0" name="purchaseQuantities['.$itemPurchase->id.']" placeholder="Enter purchase quantity" />';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">'. $item->item_measurement.'</a>';
            $main_json[$i][$v++] = '<input type="date" value="'.$itemPurchase->expiry_date.'" class="form-control mb-2 mb-md-0" name="expiryDates['.$itemPurchase->id.']" placeholder="Enter purchase quantity" />';
            $main_json[$i][$v++] = '<input type="text" value="'.$itemPurchase->cost_price.'" class="form-control mb-2 mb-md-0" name="costPrices['.$itemPurchase->id.']" placeholder="Enter cost price" /></form>';
            $i++;
        }
        return response()->json(["returned_data" => $main_json]);
    }

    public function addItemToPurchase(Request $request){

        $itemPurchaseModel = new ItemPurchase();
        $itemPurchaseModel->purchase_id = $request->purchaseId;
        $itemPurchaseModel->item_id = $request->itemId;
        $itemPurchaseModel->measurement_id = $request->measurementId === "0" ? null : $request->measurementId;
        $itemPurchaseModel->measurement_quantity = $request->measurementId === "0" ? null : $request->measurementQuantity;
        $itemPurchaseModel->purchase_quantity = $request->purchaseQuantity;
        $itemPurchaseModel->unit_price = $request->costPrice / $request->purchaseQuantity;
        $itemPurchaseModel->cost_price = $request->costPrice;
        $itemPurchaseModel->barcode = isset($request->barcode) ? $request->barcode : $this->generateStockBarcode($request->itemId);
        $itemPurchaseModel->expiry_date = $request->expiryDate;
        $itemPurchaseModel->save();

        return response()->json(['status' => "success"]);
    }

    public function viewPurchaseItems(Request $request){

        $purchase = Purchase::find($request->purchaseId);
        $itemPurchases = ItemPurchase::where("purchase_id", $request->purchaseId)->get();
        $main_json = [];
        $i = 0;
        foreach ($itemPurchases as $itemPurchase) {
            $body = "";
            $item = $itemPurchase->item;
            $totalPurchases = $itemPurchase->purchase_quantity;
            $expiryDate = isset($itemPurchase->expiry_date) ? Carbon::parse($itemPurchase->expiry_date)->isoFormat('ddd, DD/MMM/YYYY') : null;
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
                $itemMeasurementQuantity = intval($totalPurchases / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalPurchases - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<a href="'.url('print_barcode?barcode='.$itemPurchase->barcode).'" target="_blank" class="btn btn-sm fw-bold btn-dark btn-active-light-dark p-3 rounded-1 z-depth-1"><i class="bi bi-printer fs-4 me-0"></i> PRINT</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $itemPurchase->barcode . '</a>';
            $main_json[$i][$v++] = $itemPurchase->item->item_name;
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' . number_format($totalPurchases, decimals: 0) . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $expiryDate . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-success btn-active-light-success p-3 z-depth-1">₦' . number_format($itemPurchase->cost_price, decimals: 2) . '</a>';

            $i++;
        }
        return response()->json(["returned_data" => $main_json]);
    }

    public function getPurchasesSummary(Request $request)
    {
        $purchases = Purchase::orderByDesc("id");

        if ($request->has('startDate') && $request->has('endDate')) {
            $purchases->whereBetween('purchase_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $purchases->whereDate('purchase_date', $request->startDate);
        } else {
            $purchases->whereDate('purchase_date', now()->toDateString());
        }

        $purchases = $purchases->get();
        $purchaseIds = $purchases->pluck("id")->toArray();

        $totalPurchaseAmount = $purchases->map(function ($purchase) {
            return $purchase->itemPurchases->sum('cost_price');
        })->sum();

        $totalDiscountAmount = $purchases->sum("discount_amount");
        $totalCostPrice = ItemPurchase::whereIn("purchase_id", $purchaseIds)->sum("cost_price");
        $totalPaymentAmount = PurchasePayment::whereIn("purchase_id", $purchaseIds)->sum("payment_amount");
        $totalBalanceAmount = $totalCostPrice - ($totalDiscountAmount + $totalPaymentAmount);
        return response()->json(["status" => "success", "totalCostPrice" => number_format($totalCostPrice, 2), "totalPaymentAmount" => number_format($totalPaymentAmount, 2), "totalDiscountAmount" => number_format($totalDiscountAmount, 2), "totalPurchases" => $purchases->count(), "totalPurchaseAmount" => number_format($totalPurchaseAmount, 2), "totalBalanceAmount" => number_format($totalBalanceAmount, 2)]);
    }

    public function generatePurchaseNumber()
    {
        $purchaseNumber = mt_rand(0, 999999999);
        if (strlen($purchaseNumber) < 9) {
            $purchaseNumber = str_pad($purchaseNumber, 9, '0', STR_PAD_LEFT);
        }
        $purchaseStoreItem = Purchase::where("purchase_number", $purchaseNumber)->first();
        if ($purchaseStoreItem !== null) {
            $this->generatePurchaseNumber();
        } else {
            return $purchaseNumber;
        }
    }

    public function addPurchase(Request $request)
    {
        $purchase = new Purchase();
        $purchase->purchase_number = $this->generatePurchaseNumber();
        $purchase->invoice_number = $request->invoiceNumber;
        $purchase->contact_id = $request->contactId;
        $purchase->purchase_date = $request->purchaseDate;
        $purchase->discount_amount = $request->discountAmount;
        $purchase->user_id = Auth::user()->id;
        $purchase->save();

        $itemPurchases = $request->itemPurchases;
        foreach ($itemPurchases as $itemPurchase) {
            $itemPurchaseModel = new ItemPurchase();
            $itemPurchaseModel->purchase_id = $purchase->id;
            $itemPurchaseModel->item_id = $itemPurchase['itemId'];
            $itemPurchaseModel->measurement_id = null;
            $itemPurchaseModel->measurement_quantity = null;
            // $itemPurchaseModel->measurement_id = $itemPurchase['measurementId'] === "0" ? null : $itemPurchase['measurementId'];
            // $itemPurchaseModel->measurement_quantity = $itemPurchase['measurementId'] === "0" ? null : $itemPurchase['measurementQuantity'];
            $itemPurchaseModel->purchase_quantity = $itemPurchase['purchaseQuantity'];
            $itemPurchaseModel->unit_price = $itemPurchase['costPrice'] / $itemPurchase["purchaseQuantity"];
            $itemPurchaseModel->cost_price = $itemPurchase['costPrice'];
            $itemPurchaseModel->barcode = isset($itemPurchase["barcode"]) ? $itemPurchase['barcode'] : $this->generateStockBarcode($itemPurchase['itemId']);
            $itemPurchaseModel->expiry_date = $itemPurchase['expiryDate'];
            $itemPurchaseModel->save();
        }

        return response()->json(['status' => "success"]);
    }

    public function deletePurchase(Request $request)
    {
        $tables = Schema::getTables();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table["name"], 'purchase_id')) {
                $hasPurchaseId = DB::table($table["name"])->where('purchase_id', $request->purchaseId)->exists();
                if ($hasPurchaseId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Purchase has data!"]);
                }
            }
        }
        Purchase::where("id", $request->purchaseId)->delete();
        return response()->json(["status" => "success"]);
    }

    public function priceCheck(Request $request)
    {
        $searchQuery = $request->searchQuery;
        $itemPurchases = ItemPurchase::where("barcode", $searchQuery)
            ->groupBy('item_id')
            ->pluck('item_id')
            ->toArray();

        $itemIds = Item::where("item_name", "LIKE", "%{$searchQuery}%")
            ->pluck("id")
            ->toArray();

        $uniqueItemIds = array_unique(array_merge($itemPurchases, $itemIds));

        $itemPurchases = ItemPurchase::whereIn("item_id", $uniqueItemIds)->groupBy('item_id')->get();
        // $itemPurchases = ItemPurchase::where("barcode", $request->barcode)->groupBy('item_id')->get();

        $main_json = [];
        $i = 0;
        foreach ($itemPurchases as $itemPurchase) {
            $body = "";
            foreach ($itemPurchase->item->itemMeasurements as $itemMeasurement) {
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">₦' . number_format($itemPurchase->item->item_price * $itemMeasurement->quantity, decimals: 2) . ' per ' . Str::lower($itemMeasurement->measurement->measurement_name) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $itemPurchase->item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($itemPurchase->item->item_price, decimals: 2) . ' per ' . Str::lower($itemPurchase->item->item_measurement) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                    MEASUREMENTS
                    <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                </a>
                <div
                    class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                    data-kt-menu="true"
                >
                    ' . $body . '
                </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" data-id="' . $itemPurchase->id . '" class="btn fw-bold  btn-m btn-warning btn-flex btn-center addItemPurchase">
                        <i class="ki-duotone ki-plus fs-5 fw-bold px-0 me-2"></i> ADD
                    </a>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }
}
