<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\ItemCategory;
use App\Models\ItemOrder;
use App\Models\ItemPurchase;
use App\Models\Purchase;
use App\Models\Item;
use App\Models\Order;
use App\Models\Contact;
use App\Models\User;
use App\Models\ItemMeasurement;
use App\Models\Measurement;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Str;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;

class ReportController extends Controller
{
    public function getSalesReport(Request $request)
    {
        $branches = Branch::all();
        $itemCategories = ItemCategory::all();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemCategoryId = isset($request->itemCategoryId) ? $request->itemCategoryId : null;
        return view("sales_report", compact("branches", "itemCategories", "itemCategoryId", "endDate", "startDate"));
    }
    public function ajaxSalesReport(Request $request)
    {
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemCategoryId = $request->itemCategoryId;
        $itemCategoryIds = isset($itemCategoryId) ? [$itemCategoryId] : ItemCategory::pluck("id")->toArray();

        $orders = Order::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $orders->whereBetween('order_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $orders->whereDate('order_date', $request->startDate);
        } else {
            $orders->whereDate('order_date', now()->toDateString());
        }

        $orders = $orders->whereIn("order_status", ["Settled", "Paid"])->get();

        $itemPurchaseIds = $orders->map(function ($order) {
            return $order->itemOrders->map(function ($itemOrder) {
                return $itemOrder->itemPurchase->id;
            });
        })->flatten()->toArray();

        $itemPurchases = ItemPurchase::whereIn("id", array_unique($itemPurchaseIds))->get();

        $itemIds = $itemPurchases->map(function ($itemPurchase) {
            return $itemPurchase->item->id;
        })->flatten()->toArray();

        $items = Item::whereIn("id", array_unique($itemIds))->whereIn("item_category_id", $itemCategoryIds)->get();
        $itemOrders = ItemOrder::whereIn("order_id", $orders->pluck("id")->toArray())->get();
        $totalSalesAmount = 0;
        $main_json = [];
        $i = 0;
        foreach ($items as $item) {

            $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
            $body = "";
            $totalSales = ItemOrder::whereIn("order_id", $orders->pluck("id"))->whereIn("item_purchase_id", $itemPurchaseIds)->sum("order_quantity");
            $totalAmount = $itemOrders->whereIn("item_purchase_id", $itemPurchaseIds)->sum("order_price");
            $totalSalesAmount += $totalAmount;

            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
                $itemMeasurementQuantity = intval($totalSales / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalSales - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->itemCategory->item_category_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' . number_format($totalSales, decimals: 0) . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-success btn-active-light-success p-3 z-depth-1">₦' . number_format($totalAmount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" data-id="'.$item->id.'" data-start_date="'.$startDate.'" data-end_date="'.$endDate.'" data-bs-toggle="modal" data-bs-target="#viewSalesReportModal" class="btn btn-sm fw-bold btn-dark btn-active-light-dark p-3 rounded-1 z-depth-1 viewSalesReport"><i class="bi bi-eye fs-4 me-0"></i> VIEW</a>';
            $i++;
        }

        $totalSalesAmount = "₦".number_format($totalSalesAmount, decimals:2);

        return response()->json(["returned_data" => $main_json, "totalSalesAmount" => $totalSalesAmount]);
    }
   
    public function viewSalesReport(Request $request){
        $itemId = $request->itemId;
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $orders = Order::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $orders->whereBetween('order_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $orders->whereDate('order_date', $request->startDate);
        } else {
            $orders->whereDate('order_date', now()->toDateString());
        }

        $orders = $orders->whereIn("order_status", ["Settled", "Paid"])->get();

        $item = Item::find($itemId);
        $itemOrders = $orders->map(function ($order) use ($itemId) {
            $matchingItemOrders = $order->itemOrders->filter(function ($itemOrder) use ($itemId) {
                return $itemOrder->itemPurchase->item_id === intval($itemId);
                
            });
            return $matchingItemOrders->isNotEmpty() ? $order : null;
        })->filter();

        $main_json = [];
        $i = 0;
        foreach ($itemOrders as $order) {
            $totalItemQuantity = $order->itemOrders->filter(function ($itemOrder) use ($itemId) {
                return $itemOrder->itemPurchase->item_id === intval($itemId);
            })->sum('order_quantity');

            $totalItemAmount = $order->itemOrders->filter(function ($itemOrder) use ($itemId) {
                return $itemOrder->itemPurchase->item_id === intval($itemId);
            })->sum('order_price');

            $body = "";
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $measurementQuantity = intval($totalItemQuantity / $itemMeasurement->quantity);
                $remainder = $totalItemQuantity - ($measurementQuantity * $itemMeasurement->quantity);
                $unitParts = [];
                if ($measurementQuantity > 0) {
                    $unitParts[] = $measurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name);
                }
                if ($remainder > 0) {
                    $unitParts[] = $remainder . ' ' . Str::upper($item->item_measurement);
                }
                $unit = implode(' and ', $unitParts);
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' .$unit . '</a>
                    </div>
                ';
            }

            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $order->order_number . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $order->user->name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $order->contact->contact_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . Carbon::parse($order->order_date)->isoFormat('ddd, DD/MMM/YYYY') . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' .$totalItemQuantity . ' '.$item->item_measurement.'</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-outline btn-outline-dashed btn-outline-success btn-active-light-success p-3 z-depth-1">₦' . number_format($totalItemAmount, decimals: 2) . '</a>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);

    }

    public function salesReportSummary(Request $request)
    {

    }

    public function getPurchasesReport(Request $request)
    {
        $branches = Branch::all();
        $itemCategories = ItemCategory::all();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemCategoryId = $request->itemCategoryId;
        return view("purchases_report", compact("branches", "itemCategories", "itemCategoryId", "endDate", "startDate"));
    }

    public function ajaxPurchasesReport(Request $request)
    {
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemCategoryId = $request->itemCategoryId;

        $purchases = Purchase::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $purchases->whereBetween('purchase_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $purchases->whereDate('purchase_date', $request->startDate);
        } else {
            $purchases->whereDate('purchase_date', now()->toDateString());
        }

        $purchases = $purchases->get();

        $itemPurchaseIds = $purchases->map(function ($purchase) {
            return $purchase->itemPurchases->map(function ($itemPurchase) {
                return $itemPurchase->id;
            });
        })->flatten()->toArray();


        $itemPurchases = ItemPurchase::whereIn("id", array_unique($itemPurchaseIds))->get();

        $itemIds = $itemPurchases->map(function ($itemPurchase) {
            return $itemPurchase->item->id;
        })->flatten()->toArray();

        $items = Item::whereIn("id", array_unique($itemIds))->get();
        $itemPurchasesGrouped = $itemPurchases->groupBy('item_id');
        // dd($items);

        $main_json = [];
        $i = 0;
        $totalPurchasesAmount = 0;
        foreach ($items as $item) {

            $itemPurchasesForItem = $itemPurchasesGrouped[$item->id] ?? collect();
    
            $itemPurchaseIds = $itemPurchasesForItem->pluck("id")->toArray();
            $totalPurchases = $itemPurchasesForItem->sum("purchase_quantity");
            $totalAmount = $itemPurchasesForItem->sum("cost_price");
            $totalPurchasesAmount += $totalAmount;

            // $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
            // $totalPurchases = $itemPurchases->where("item_id", $item->id)->sum("purchase_quantity");
            // $totalAmount = $itemPurchases->where("item_id", $item->id)->sum("cost_price");
            // $totalPurchasesAmount += $totalAmount;

            $body = "";
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemMeasurementQuantity = intval($totalPurchases / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalPurchases - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->itemCategory->item_category_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' . number_format($totalPurchases, decimals: 0) . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-success btn-active-light-success p-3 z-depth-1">₦' . number_format($totalAmount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" data-id="'.$item->id.'" data-bs-toggle="modal" data-bs-target="#viewPurchasesModal" class="btn btn-sm fw-bold btn-dark btn-active-light-dark p-3 rounded-1 z-depth-1 viewPurchases"><i class="bi bi-eye fs-4 me-0"></i> VIEW</a>';
            $i++;
        }

        $totalPurchasesAmount = "₦".number_format($totalPurchasesAmount, decimals:2);
        return response()->json(["returned_data" => $main_json, "totalPurchasesAmount" => $totalPurchasesAmount]);
    }

    public function ajaxItemPurchasesReport(Request $request){
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemId = $request->itemId;

        $purchases = Purchase::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $purchases->whereBetween('purchase_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $purchases->whereDate('purchase_date', $request->startDate);
        } else {
            $purchases->whereDate('purchase_date', now()->toDateString());
        }

        $purchases = $purchases->get();

        $itemPurchaseIds = $purchases->map(function ($purchase) {
            return $purchase->itemPurchases->map(function ($itemPurchase) {
                return $itemPurchase->id;
            });
        })->flatten()->toArray();


        $itemPurchases = ItemPurchase::where("item_id", $itemId)->whereIn("id", array_unique($itemPurchaseIds))->get();

        $main_json = [];
        $i = 0;
        foreach($itemPurchases as $itemPurchase) {
            $body = "";
            $item = $itemPurchase->item->first();
            $totalPurchases = $itemPurchase->purchase_quantity;
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
                $itemMeasurementQuantity = intval($totalPurchases / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalPurchases - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $purchase = $itemPurchase->purchase->first();
            $v = 0; 
            $main_json[$i][$v++] = '<a href="'.url('print_barcode?barcode='.$itemPurchase->barcode).'" target="_blank" class="btn btn-sm fw-bold btn-dark btn-active-light-dark p-3 rounded-1 z-depth-1"><i class="bi bi-printer fs-4 me-0"></i> PRINT</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $itemPurchase->barcode . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' . number_format($totalPurchases, decimals: 0) . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $purchase->contact->contact_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $purchase->invoice_number . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . Carbon::parse($purchase->purchase_date)->isoFormat('ddd, DD/MMM/YYYY') . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-success btn-active-light-success p-3 z-depth-1">₦' . number_format($itemPurchase->cost_price, decimals: 2) . '</a>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);

    }

    public function getStockReport(Request $request)
    {
        $branches = Branch::all();
        $itemCategories = ItemCategory::all();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        $itemCategoryId = $request->itemCategoryId;
        return view("stock_report", compact("branches", "itemCategories", "itemCategoryId", "endDate", "startDate"));
    }

    public function ajaxStockReport(Request $request)
    {

        $itemCategoryId = $request->itemCategoryId;

        $purchases = Purchase::orderByDesc("id");

        $purchases = $purchases->get();

        $orders = Order::orderByDesc("id");

        $orders = $orders->whereIn("order_status", ["Settled", "Paid"])->get();

        // $itemPurchaseIds = $purchases->map(function ($purchase) {
        //     return $purchase->itemPurchases->map(function ($itemPurchase) {
        //         return $itemPurchase->id;
        //     });
        // })->flatten()->toArray();

        // $itemPurchases = ItemPurchase::whereIn("id", array_unique($itemPurchaseIds))->get();
        // $itemOrders = ItemOrder::whereIn("order_id", $orders->pluck("id")->toArray())->get();

        $items = Item::where("item_status", "Active")->get();

        $main_json = [];
        $i = 0;

        $itemPurchases = ItemPurchase::whereIn("item_id", $items->pluck("id"))
            ->selectRaw("item_id, SUM(purchase_quantity) as total_purchases")
            ->groupBy("item_id")
            ->pluck("total_purchases", "item_id");

        $itemSales = ItemOrder::join('item_purchases', 'item_orders.item_purchase_id', '=', 'item_purchases.id')
            ->whereIn("item_purchases.item_id", $items->pluck("id"))
            ->selectRaw("item_purchases.item_id, SUM(item_orders.order_quantity) as total_sales")
            ->groupBy("item_purchases.item_id")
            ->pluck("total_sales", "item_id");

            $expiredStock = ItemPurchase::leftJoin(DB::raw("(SELECT item_purchase_id, SUM(order_quantity) as total_orders FROM item_orders GROUP BY item_purchase_id) as orders"), function ($join) {
                $join->on('item_purchases.id', '=', 'orders.item_purchase_id');
            })
            ->whereNotNull('expiry_date')
            ->where('expiry_date', '<=', date('Y-m-d'))
            ->selectRaw("item_purchases.item_id, SUM(item_purchases.purchase_quantity - COALESCE(orders.total_orders, 0)) as expired_stock")
            ->groupBy("item_purchases.item_id")
            ->pluck("expired_stock", "item_id");

        $totalStockAmount = 0;    
        foreach ($items as $item) {
            $totalPurchases = $itemPurchases[$item->id] ?? 0;
            $totalSales = $itemSales[$item->id] ?? 0;
            $expiredStockCount = $expiredStock[$item->id] ?? 0;

            $totalStock = $totalPurchases - $totalSales;
            $totalAmount = $totalStock * $item->item_price;
            $totalStockAmount += $totalAmount;
        // foreach ($items as $item) {
        //     $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
        //     $totalSales = $itemOrders->whereIn("item_purchase_id", $itemPurchaseIds)->sum("order_quantity");
        //     $totalPurchases = $itemPurchases->where("item_id", $item->id)->sum("purchase_quantity");
        //     $expiredStock = $itemPurchases->where("item_id", $item->id)->whereNotNull("expiry_date")->where("expiry_date", "<=", date("Y-m-d"))->map(function ($itemPurchase) use ($itemOrders) {
        //         return $itemPurchase->purchase_quantity - $itemOrders->where("item_purchase_id", $itemPurchase->id)->sum("order_quantity");
        //     })->sum();
        //     $totalStock = $totalPurchases - $totalSales;
        //     $totalAmount = $totalStock * $item->item_price;
            $body = "";
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemMeasurementQuantity = intval($totalStock / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalStock - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $expiredBody = "";
            foreach ($item->itemMeasurements as $itemMeasurement) {
                if ($expiredStockCount < 0) {
                    $expiredStockCount = 0;
                }
                $itemMeasurementQuantity = intval($expiredStockCount / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($expiredStockCount - ($itemMeasurementQuantity * $itemMeasurement->quantity));

                $expiredBody .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->itemCategory->item_category_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' . number_format($totalStock, decimals: 0) . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-success btn-active-light-success p-3 z-depth-1">₦' . number_format($totalAmount, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-warning btn-active-light-warning p-3 z-depth-1">' . number_format($expiredStockCount, decimals: 0) . ' ' . $item->item_measurement . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-secondary btn-flex btn-center btn-active-light-secondary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $expiredBody . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-danger btn-active-light-danger p-3 z-depth-1">₦' . number_format($expiredStockCount * $item->item_price, decimals: 2) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" data-id="'.$item->id.'" data-bs-toggle="modal" data-bs-target="#viewStocksModal" class="btn btn-sm fw-bold btn-dark btn-active-light-dark p-3 rounded-1 z-depth-1 viewStocks"><i class="bi bi-eye fs-4 me-0"></i> VIEW</a>';
            $i++;
        }

        $totalStockAmount = "₦".number_format($totalStockAmount, decimals:2);
        return response()->json(["returned_data" => $main_json, "totalStockAmount" => $totalStockAmount]);
    }

    public function viewItemStockReport(Request $request){
        $itemId = $request->itemId;
        $item = Item::find($itemId);
        $itemPurchases = ItemPurchase::where("item_id", $itemId)
            ->select("id", "purchase_quantity", "expiry_date", "purchase_id", "barcode", "unit_price")
            ->get();

        $itemSales = ItemOrder::whereIn("item_purchase_id", $itemPurchases->pluck("id"))
            ->selectRaw("item_purchase_id, SUM(order_quantity) as total_sold")
            ->groupBy("item_purchase_id")
            ->pluck("total_sold", "item_purchase_id");

        $remainingPurchases = [];

        $main_json = [];
        $i = 0;
        // dd($itemPurchases);
        foreach ($itemPurchases as $itemPurchase) {
            $purchase = Purchase::find($itemPurchase->purchase_id);
            $itemPurchaseId = $itemPurchase->id;
            $purchaseQuantity = $itemPurchase->purchase_quantity;
            $soldQuantity = $itemSales[$itemPurchaseId] ?? 0;

            $isExpired = !is_null($itemPurchase->expiry_date) && $itemPurchase->expiry_date <= date('Y-m-d');

            $expiredStock = $isExpired ? ($purchaseQuantity - $soldQuantity) : 0;

            $remainingStock = $purchaseQuantity - $soldQuantity - $expiredStock;

            if ($remainingStock > 0) {
                $remainingPurchases[] = [
                    "purchase_id" => $itemPurchaseId,
                    "total_purchased" => $purchaseQuantity,
                    "sold" => $soldQuantity,
                    "expired" => $expiredStock,
                    "remaining_stock" => $remainingStock
                ];
                $body = "";
                // $item = $itemPurchase->item->first();
                $totalPurchases = $itemPurchase->purchase_quantity;
                foreach ($item->itemMeasurements as $itemMeasurement) {
                    $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
                    $itemMeasurementQuantity = intval($totalPurchases / $itemMeasurement->quantity);
                    $itemMeasurementRemainder = intval($totalPurchases - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                    $body .= '
                        <div class="menu-item px-3">
                            <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                            </div>
                        ';
                }
                $purchase = $itemPurchase->purchase->first();
                $v = 0; 
                $main_json[$i][$v++] = '<a href="'.url('print_barcode?barcode='.$itemPurchase->barcode).'" target="_blank" class="btn btn-sm fw-bold btn-dark btn-active-light-dark p-3 rounded-1 z-depth-1"><i class="bi bi-printer fs-4 me-0"></i> PRINT</a>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $itemPurchase->barcode . '</a>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">' . number_format($totalPurchases, decimals: 0) . ' ' . $item->item_measurement . '</a>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                            MEASUREMENTS
                            <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                        </a>
                        <div
                            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                            data-kt-menu="true"
                        >
                            ' . $body . '
                        </div>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $purchase->contact->contact_name . '</a>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $purchase->invoice_number . '</a>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . Carbon::parse($purchase->purchase_date)->isoFormat('ddd, DD/MMM/YYYY') . '</a>';
                $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-success btn-active-light-success p-3 z-depth-1">₦' . number_format(($itemPurchase->unit_price * $remainingStock), decimals: 2) . '</a>';
                $i++;
            }
        }

        // return response()->json($remainingPurchases);
        return response()->json(["returned_data" => $main_json]);
    }

    public function ajaxItemsStock(Request $request)
    {
        $purchases = Purchase::orderByDesc("id");

        $purchases = $purchases->get();

        $orders = Order::orderByDesc("id");

        $orders = $orders->whereIn("order_status", ["Settled", "Paid"])->get();

        $itemPurchaseIds = $purchases->map(function ($purchase) {
            return $purchase->itemPurchases->map(function ($itemPurchase) {
                return $itemPurchase->id;
            });
        })->flatten()->toArray();

        $itemPurchases = ItemPurchase::whereIn("id", array_unique($itemPurchaseIds))->get();
        $itemOrders = ItemOrder::whereIn("order_id", $orders->pluck("id")->toArray())->get();

        $items = Item::where("item_status", "Active")->get();

        $main_json = [];
        $i = 0;
        foreach ($items as $item) {
            $itemPurchaseIds = $itemPurchases->where("item_id", $item->id)->pluck("id")->toArray();
            $totalSales = $itemOrders->whereIn("item_purchase_id", $itemPurchaseIds)->sum("order_quantity");
            $totalPurchases = $itemPurchases->where("item_id", $item->id)->sum("purchase_quantity");
            $itemPurchase = ItemPurchase::where("item_id", $item->id)->where("status", "Open")->first();
            $itemPurchaseId = isset($itemPurchase) ? $itemPurchase->id : null;
            $totalStock = $totalPurchases - $totalSales;
            $body = "";
            foreach ($item->itemMeasurements as $itemMeasurement) {
                $itemMeasurementQuantity = intval($totalStock / $itemMeasurement->quantity);
                $itemMeasurementRemainder = intval($totalStock - ($itemMeasurementQuantity * $itemMeasurement->quantity));
                $body .= '
                <div class="menu-item px-3">
                    <a href="javascript:;" class="btn btn-m btn-info fw-bold  btn-active-light-info p-3 z-depth-1">' . $itemMeasurementQuantity . ' ' . Str::upper($itemMeasurement->measurement->measurement_name) . ', ' . $itemMeasurementRemainder . ' ' . Str::upper($item->item_measurement) . '</a>
                    </div>
                ';
            }
            $v = 0;
            $main_json[$i][$v++] = '<a href="javascript:;" class="text-dark fw-bold fs-6">' . $item->item_name . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-m fw-bold btn-primary btn-active-light-primary p-3 z-depth-1">₦' . number_format($item->item_price, decimals: 2) . ' per ' . Str::lower($item->item_measurement) . '</a>';
            $main_json[$i][$v++] = '<a href="javascript:;" class="btn btn-sm btn-info btn-flex btn-center btn-active-light-info" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-start">
                        MEASUREMENTS
                        <i class="ki-duotone ki-down fs-5 ms-2 px-0"></i>
                    </a>
                    <div
                        class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-info fw-semibold fs-7 w-200px py-4"
                        data-kt-menu="true"
                    >
                        ' . $body . '
                    </div>';
            $main_json[$i][$v++] = '<a href="javascript:;"  data-id="' .$itemPurchaseId. '" class="btn fw-bold  btn-m btn-warning btn-flex btn-center addItemPurchase">
                        <i class="ki-duotone ki-plus fs-5 fw-bold px-0 me-2"></i> ADD
                    </a>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }
}
