<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\SalesAudit;
use App\Models\ItemCategory;
use App\Models\ItemOrder;
use App\Models\ItemPurchase;
use App\Models\Purchase;
use App\Models\Item;
use Illuminate\Support\Facades\Auth;
use App\Models\Order;
use App\Models\OrderPayment;
use App\Models\PaymentMethod;
use App\Models\Contact;
use App\Models\User;
use App\Models\ItemMeasurement;
use App\Models\Measurement;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Str;
use Carbon\Carbon;
use Illuminate\Http\Request;

class SalesAuditController extends Controller
{
    public function getSalesAudit(Request $request)
    {
        $paymentMethods = PaymentMethod::all();
        $users = User::all();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        return view("sales_audit", compact('users', 'paymentMethods', 'startDate', 'endDate'));
    }

    public function ajaxSalesAudit(Request $request)
    {
        $orders = Order::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $orders->whereBetween('order_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $orders->whereDate('order_date', $request->startDate);
        } else {
            $orders->whereDate('order_date', now()->toDateString());
        }

        $orderIds = $orders->where("order_status", "Paid")->pluck("id")->toArray();
        $orderCashierIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->pluck("user_id")->toArray());
        $paymentCashierIds = array_unique(OrderPayment::where("payment_date", $request->startDate)->pluck("user_id")->toArray());
        $cashierIds = array_merge($paymentCashierIds, $orderCashierIds);

        $main_json = [];
        $i = 0;

        foreach (array_unique($cashierIds) as $key => $cashierId) {
            $staff = User::find($cashierId);
            $cashierOrderIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->pluck("order_id")->toArray());
            $orderAmount = ItemOrder::whereIn("order_id", $cashierOrderIds)->sum("order_price");
            $discountAmount = Order::whereIn("id", $cashierOrderIds)->sum("discount_amount");
            $changeAmount = Order::whereIn("id", $cashierOrderIds)->sum("change_amount");
            $totalOrders = count($cashierOrderIds);
            $salesAudit = SalesAudit::where("user_id", $cashierId)->where("audit_date", $request->startDate)->first();
            $userName = isset($salesAudit) ? User::find($salesAudit->audit_by)->name : "---";
            $totalPayment = OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->sum("payment_amount");
            $amountPaid = isset($salesAudit) ? number_format($salesAudit->amount_paid, 2) : " ---";
            $difference = isset($salesAudit) ? number_format($salesAudit->amount_paid - ($orderAmount - $discountAmount), 2) : " ---";
            $v = 0;
            $main_json[$i][$v++] = '<a href="#" data-start_date="' . $request->startDate . '" data-end_date="' . $request->endDate . '" data-cashier_id="' . $cashierId . '"  class="btn btn-sm btn-primary editSalesPOSAudit"> AUDIT</a>';
            $main_json[$i][$v++] = '<h6>' . $staff->name . '</h6>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning">₦' . number_format(($orderAmount - $discountAmount), 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-success btn-active-light-success">₦' . $amountPaid . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-dark btn-active-light-dark">₦' . $difference . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-secondary">' . $totalOrders . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary">₦' . number_format($orderAmount, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-danger btn-active-light-danger">₦' . number_format($discountAmount, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-dark btn-active-light-dark">₦' . number_format($totalPayment, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-info btn-active-light-info">₦' . number_format($changeAmount, 2) . '</a>';
            $main_json[$i][$v++] = Carbon::parse($request->startDate)->isoFormat('ddd, DD/MMM/YYYY');
            $main_json[$i][$v++] = '<h6>' . $userName . '</h6>';
            $i++;
        }
        return response()->json(["returned_data" => $main_json]);

    }

    function getValueByID($audits, $id) {
        foreach ($audits as $audit) {
            if ($audit->id === $id) {
                return $audit->value;
            }
        }
        return null;
    }

    public function getCashierAudit(Request $request){
        $orders = Order::orderByDesc("id");
        $cashPaymentId = PaymentMethod::where("payment_method_name", "CASH")->value("id");
        $posPaymentId = PaymentMethod::where("payment_method_name", "MONIEPOINT")->value("id");
        $bankPaymentId = PaymentMethod::where("payment_method_name", "GLOBUS BANK")->value("id");
        $gtbPaymentId = PaymentMethod::where("payment_method_name", "GT BANK")->value("id");
        $voucherPaymentId = PaymentMethod::where("payment_method_name", "VOUCHER")->value("id");
        $walletPaymentId = PaymentMethod::where("payment_method_name", "WALLET")->value("id");
        $cashierId = $request->cashierId;
        $staff = User::find($cashierId);

        $posAudit = SalesAudit::where("user_id", $cashierId)->where("audit_date", $request->startDate)->first();


        if ($request->has('startDate') && $request->has('endDate')) {
            $startDate = $request->startDate;
            $endDate = $request->endDate;
            $orders->whereBetween('order_date', [$startDate, $endDate]);
        } elseif ($request->has('startDate')) {
            $startDate = $request->startDate;
            $endDate = $request->endDate;
            $orders->whereBetween('order_date', [$startDate, $endDate]);
        } else {
            $startDate = $request->startDate;
            $endDate = $request->endDate;
            $orders->whereBetween('order_date', [$startDate, $endDate]);
        }

        $orderIds = $orders->where("order_status", "Paid")->pluck("id")->toArray();

        $totalCashPayments = OrderPayment::whereIn("order_id", $orderIds)->where("payment_method_id", $cashPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
        $totalPOSPayments = OrderPayment::whereIn("order_id", $orderIds)->where("payment_method_id", $posPaymentId)->where("user_id", $cashierId)->sum("payment_amount");        
        $todaysTotalPOSPayments = OrderPayment::where("payment_method_id", $posPaymentId)->where("payment_date", $request->startDate)->where("user_id", $cashierId)->sum("payment_amount");
        $totalBankPayments = OrderPayment::whereIn("order_id", $orderIds)->where("payment_method_id", $bankPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
        $totalGTBPayments = OrderPayment::whereIn("order_id", $orderIds)->where("payment_method_id", $gtbPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
        $totalVoucherPayments = OrderPayment::whereIn("order_id", $orderIds)->where("payment_method_id", $voucherPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
        $totalWalletPayments = OrderPayment::whereIn("order_id", $orderIds)->where("payment_method_id", $walletPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
        $cashier = User::find($cashierId);

        $usedPaymentMethodIds = OrderPayment::whereIn("order_id", $orderIds)->pluck("payment_method_id")->toArray();


        if($posAudit){
            $paymentAudits = json_decode($posAudit->payment_audits);
            $cashRecorded = $this->getValueByID($paymentAudits, $cashPaymentId);
            $posRecorded = $this->getValueByID($paymentAudits, $posPaymentId);
            $bankRecorded = $this->getValueByID($paymentAudits, $bankPaymentId);
            $gtbRecorded = $this->getValueByID($paymentAudits, $gtbPaymentId);
            $voucherRecorded = $this->getValueByID($paymentAudits, $voucherPaymentId);
            $walletRecorded = $this->getValueByID($paymentAudits, $walletPaymentId);
        }
        else{
            $cashRecorded = 0;
            $posRecorded = 0;
            $bankRecorded = 0;
            $gtbRecorded = 0;
            $voucherRecorded = 0;
            $walletRecorded = 0;
        }

        $cashierOrderIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->pluck("order_id")->toArray());
        $cashierOrdersPaymentMethodIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->pluck("payment_method_id")->toArray());

        $totalDiscountAmount = Order::whereIn("id", $cashierOrderIds)->sum("discount_amount");
        $totalChangeAmount = Order::whereIn("id", $cashierOrderIds)->sum("change_amount");
        $orderAmount = Order::whereIn("id", $cashierOrderIds)->sum("order_amount");
        $title = Str::title($cashier->name)." Audit for ".Carbon::parse($request->startDate)->isoFormat('ddd, DD/MMM/YYYY');
        $body = "";

        $body.='<form id="cashierAuditForm">
                <input value="'.$cashierId.'" name="cashierId" class="d-none">
                <input value="'.$request->startDate.'" name="startDate" class="d-none">
                <input value="'.$request->endDate.'" name="endDate" class="d-none">
                <div class="card py-3">
                        <div class="table-responsive">
                        <table class="table table-hover table-bordered mb-0">
                            <thead class="">
                                <tr>';
                                foreach(array_unique($cashierOrdersPaymentMethodIds) as $usedPaymentMethodId){
                                    $paymentMethod = PaymentMethod::find($usedPaymentMethodId);
                                    $body.='
                                    <th>'.$paymentMethod->payment_method_name.' PAYMENTS</th>
                                    ';
                                }
                                $body.='
                                <th>TOTAL DISCOUNT AMOUNT</th>
                                <th>TOTAL CHANGE AMOUNT</th>
                                </tr>
                            </thead>
                            <tbody class="table-border-bottom-0"><tr>';
                                foreach(array_unique($cashierOrdersPaymentMethodIds) as $usedPaymentMethodId){
                                    $paymentMethodAmount = OrderPayment::where("payment_method_id", $usedPaymentMethodId)->whereIn("order_id", $cashierOrderIds)->sum("payment_amount");
                                    $body.='
                                    <th>₦<span class="">'.number_format($paymentMethodAmount, 2).'</span></th>
                                    ';
                                }
                            $body.='
                                <th>₦<span class="">'.number_format($totalDiscountAmount,2).'</span></th>
                                <th>₦<span class="">'.number_format($totalChangeAmount,2).'</span></th>
                                </tr>
                                </tbody>
                        </table></div></div>'; 
                    
                
               

        $body.='<div class="card py-3"><div class="table-responsive">
                    <table class="table table-hover table-bordered mb-0">
                            <thead class="">
                                <tr>';
                                foreach(array_unique($cashierOrdersPaymentMethodIds) as $usedPaymentMethodId){
                                    $paymentMethod = PaymentMethod::find($usedPaymentMethodId);
                                    $body.='
                                    <th>'.$paymentMethod->payment_method_name.' RECORDED</th>
                                    ';
                                }
                                $body.='
                                </tr>
                            </thead>
                            <tbody class="table-border-bottom-0"><tr>
                                ';
                                foreach(array_unique($cashierOrdersPaymentMethodIds) as $usedPaymentMethodId){
                                    if($posAudit){
                                        $paymentAudits = json_decode($posAudit->payment_audits);
                                        $amountRecorded = $this->getValueByID($paymentAudits, $usedPaymentMethodId);
                                    }
                                    else{
                                        $amountRecorded = 0;
                                    }
                                    $paymentMethod = PaymentMethod::find($usedPaymentMethodId);
                                    $paymentMethodAmount = OrderPayment::where("payment_method_id", $usedPaymentMethodId)->whereIn("order_id", $cashierOrderIds)->sum("payment_amount");
                                    $body.='
                                    <th><input type="text" name="'.$usedPaymentMethodId.'" value="'.$amountRecorded.'" class="form-control mb-2 mb-md-0"/></th>
                                    ';
        
                                }
                                $body.='
                                </tr>';
                            $body.='</tbody>
                        </table></div></div>';

        $body.='<div class="col-12 row"><button class="text-white btn-full bg-dark fs-4 fw-semibold" type="button"  style="color:whitesmoke;width:100%">
                                       '.count($cashierOrderIds).' Orders (₦'.number_format($orderAmount,2).')
                                    </button></div>';

        foreach($cashierOrderIds as $cashierOrderId){

            $cashierOrderPaymentMethodIds = OrderPayment::where("order_id", $cashierOrderId)->pluck("payment_method_id")->toArray();

            $totalCashPayment = OrderPayment::where("order_id", $cashierOrderId)->where("payment_method_id", $cashPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
            $totalPOSPayment = OrderPayment::where("order_id", $cashierOrderId)->where("payment_method_id", $posPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
            $totalBankPayment = OrderPayment::where("order_id", $cashierOrderId)->where("payment_method_id", $bankPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
            $totalGTBPayment = OrderPayment::where("order_id", $cashierOrderId)->where("payment_method_id", $gtbPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
            $totalVoucherPayment = OrderPayment::where("order_id", $cashierOrderId)->where("payment_method_id", $voucherPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
            $totalWalletPayment = OrderPayment::where("order_id", $cashierOrderId)->where("payment_method_id", $walletPaymentId)->where("user_id", $cashierId)->sum("payment_amount");
            $order = Order::find($cashierOrderId);
            $discountAmount = isset($order->discount_amount) ? $order->discount_amount : 0.00;
            $changeAmount = isset($order->change_amount) ? $order->change_amount  : 0.00;

            $body.= '<div class="card py-3"> <a href="#" class="btn btn-lg mb-3 btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary" style="width: -webkit-fill-available;">'.$cashier->name.' -> ('.$order->order_number.') | <span class="text-dark">(₦'.number_format($order->order_amount,2).')</span> | <span class="text-warning">(₦'.number_format($discountAmount,2).')</span> | <span class="text-danger">(₦'.number_format($changeAmount,2).')</span></a>';
                     $body.='
                             <table class="table table-hover table-bordered mb-0">
                                 <thead class="d-none">
                                     <tr>
                                     <th>Project</th>
                                     <th>Project</th>
                                     </tr>
                                 </thead>
                                 <tbody class="table-border-bottom-0">';
                                     foreach(array_unique($cashierOrderPaymentMethodIds) as $usedPaymentMethodId){
                                         $paymentMethod = PaymentMethod::find($usedPaymentMethodId);
                                         $paymentMethodAmount = OrderPayment::where("payment_method_id", $usedPaymentMethodId)->where("order_id", $cashierOrderId)->sum("payment_amount");
                                         $body.='<tr>
                                         <th>'.$paymentMethod->payment_method_name.'</th>
                                         <th>₦<span class="">'.number_format($paymentMethodAmount,2).'</span></th>
                                         </tr>';
                                     }
                                 $body.='</tbody>
                             </table></div>'; 
        }
                    

        $body.= '

                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
            </form>
            
        ';

        return response()->json(["status"=>"success", "body"=>$body, "title"=>$title]);

    }


    public function auditCashier(Request $request){
        $orders = Order::orderByDesc("id");

        $cashierId = $request->cashierId;
        $staff = User::find($cashierId);
        $posAudit = SalesAudit::where("user_id", $cashierId)->where("audit_date", $request->startDate)->first();


        $paymentMethods = PaymentMethod::all();
        $paymentMethodIds = $paymentMethods->pluck("id")->toArray();


        if ($request->has('startDate') && $request->has('endDate')) {
            $startDate = $request->startDate;
            $endDate = $request->endDate;
            $orders->whereBetween('order_date', [$startDate, $endDate]);
        } elseif ($request->has('startDate')) {
            $startDate = $request->startDate;
            $endDate = $request->endDate;
            $orders->whereBetween('order_date', [$startDate, $endDate]);
        } else {
            $startDate = $request->startDate;
            $endDate = $request->endDate;
            $orders->whereBetween('order_date', [$startDate, $endDate]);
        }

        $orderIds = $orders->where("order_status", "Paid")->pluck("id")->toArray();
        $cashierOrderIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->pluck("order_id")->toArray());


        $paymentAudits = [];
        $totalReceived = 0;
        foreach($paymentMethodIds as $paymentMethodId){
            $amountRecorded = $request[$paymentMethodId];
            if(isset($amountRecorded)){
                $totalReceived += $amountRecorded;
                $paymentAudits[] = ["id"=>$paymentMethodId, "value"=>$amountRecorded];
            }
        }

        if($posAudit){
            $posAudit->amount_paid = $totalReceived;
            $posAudit->audit_amount = $totalReceived;
            $posAudit->payment_audits = json_encode($paymentAudits);
            $posAudit->audit_details = json_encode($paymentAudits);
            $posAudit->save();
        }
        else{
            $newPosAudit = new SalesAudit();
            $newPosAudit->user_id = $cashierId;
            $newPosAudit->audit_date = $request->startDate;
            $newPosAudit->amount_paid = $totalReceived;
            $newPosAudit->audit_amount = $totalReceived;
            $newPosAudit->payment_audits = json_encode($paymentAudits);
            $newPosAudit->audit_details = json_encode($paymentAudits);
            $newPosAudit->created_by = Auth::user()->id;
            $newPosAudit->audit_by = Auth::user()->id;
            $newPosAudit->save();
        }
        return response()->json(["status"=>"success"]);
    }

    public function posAuditSummary(Request $request){
        $payments = OrderPayment::where("payment_date", $request->startDate)->get();
        $mainPaymentMethodIds = OrderPayment::where("payment_date", $request->startDate)->pluck("payment_method_id")->toArray();
        $body = "";
        foreach(array_unique($mainPaymentMethodIds) as $mainPaymentMethodId){
            $paymentMethod = PaymentMethod::find($mainPaymentMethodId);
            $ordersPaymentAmount = OrderPayment::where("payment_date", $request->startDate)->where("payment_method_id", $mainPaymentMethodId)->sum("payment_amount");
            $paymentAmount = OrderPayment::where("payment_date", $request->startDate)->where("payment_method_id", $mainPaymentMethodId)->sum("payment_amount");
        
            $body.= ' <a href="#" class="btn btn-lg mb-3 btn-outline btn-outline-dashed btn-dark" style="width: -webkit-fill-available;">'.$paymentMethod->payment_method_name.'</a>';
            $body.= '<div class="row">

                <div class="col-xl-6 mb-xl-10">
                    <div class="card border-success bgi-no-repeat bgi-position-y-top bgi-position-x-end statistics-widget-3 h-xl-100" style="border: 1px dashed;">
                        <div class="card-body">
                            <a href="#" class="card-title fw-bold text-muted text-hover-success fs-4">Orders Payment</a>
                            <div class="fw-bold text-success my-6"></div>
                            <a href="#" class="btn btn-lg btn-outline btn-outline-dashed btn-outline-success btn-active-light-success">₦<span class="">'.number_format($ordersPaymentAmount,2).'</span></a>
                        </div>
                    </div>
                </div>

                <div class="col-xl-6 mb-xl-10">
                    <div class="card bgi-no-repeat border-info bgi-position-y-top bgi-position-x-end statistics-widget-3 h-xl-100" style="border: 1px dashed;">
                        <div class="card-body">
                            <a href="#" class="card-title fw-bold text-muted text-hover-info fs-4">Total Payment</a>
                            <div class="fw-bold text-primary my-6"></div>
                            <a href="#" class="btn btn-lg btn-outline btn-outline-dashed btn-outline-info btn-active-light-info">₦<span class="">'.number_format($paymentAmount, 2).'</span></a>
                        </div>
                    </div>
                </div>
            </div>';
        }

        $body.='<div class="modal-footer">
            <a href="'.url('report?date='.$request->startDate).'" target="_blank" class="btn btn-primary">Comment and Send Report</a>
        </div>';

        $title = "Payments Audit";

        return response()->json(["status"=>"success", "body"=>$body, "title"=>$title]);
    }

    public function salesAuditsSummary(Request $request)
    {

    }
}
