<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\SalesAudit;
use App\Models\ItemCategory;
use App\Models\ItemOrder;
use App\Models\ItemPurchase;
use App\Models\Purchase;
use App\Models\Item;
use App\Models\Order;
use App\Models\OrderPayment;
use App\Models\PaymentMethod;
use App\Models\Contact;
use App\Models\User;
use App\Models\ItemMeasurement;
use App\Models\Measurement;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Str;
use Carbon\Carbon;
use Illuminate\Http\Request;

class SalesAuditController extends Controller
{
    public function getSalesAudit(Request $request)
    {
        $paymentMethods = PaymentMethod::all();
        $users = User::all();
        $date = date("Y-m-d");
        $startDate = isset($request->startDate) ? $request->startDate : Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;
        return view("sales_audit", compact('users', 'paymentMethods', 'startDate', 'endDate'));
    }

    public function ajaxSalesAudit(Request $request)
    {
        $orders = Order::orderByDesc("id");
        if ($request->has('startDate') && $request->has('endDate')) {
            $orders->whereBetween('order_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $orders->whereDate('order_date', $request->startDate);
        } else {
            $orders->whereDate('order_date', now()->toDateString());
        }

        $orderIds = $orders->where("order_status", "Paid")->pluck("id")->toArray();
        $orderCashierIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->pluck("user_id")->toArray());
        $paymentCashierIds = array_unique(OrderPayment::where("payment_date", $request->startDate)->pluck("user_id")->toArray());
        $cashierIds = array_merge($paymentCashierIds, $orderCashierIds);

        $main_json = [];
        $i = 0;

        foreach (array_unique($cashierIds) as $key => $cashierId) {
            $staff = User::find($cashierId);
            $cashierOrderIds = array_unique(OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->pluck("order_id")->toArray());
            $orderAmount = ItemOrder::whereIn("order_id", $cashierOrderIds)->sum("order_price");
            $discountAmount = Order::whereIn("id", $cashierOrderIds)->sum("discount_amount");
            $changeAmount = Order::whereIn("id", $cashierOrderIds)->sum("change_amount");
            $totalOrders = count($cashierOrderIds);
            $salesAudit = SalesAudit::where("user_id", $cashierId)->where("audit_date", $request->startDate)->first();
            $userName = isset($salesAudit) ? User::find($salesAudit->audit_by)->name : "---";
            $totalPayment = OrderPayment::whereIn("order_id", $orderIds)->where("user_id", $cashierId)->sum("payment_amount");
            $amountPaid = isset($salesAudit) ? number_format($salesAudit->amount_paid, 2) : " ---";
            $difference = isset($salesAudit) ? number_format($salesAudit->amount_paid - ($orderAmount - $discountAmount), 2) : " ---";
            $v = 0;
            $main_json[$i][$v++] = '<a href="#" data-start_date="' . $request->startDate . '" data-end_date="' . $request->endDate . '" data-cashier_id="' . $cashierId . '"  class="btn btn-sm btn-primary editSalesAudit"> AUDIT</a>';
            $main_json[$i][$v++] = '<h6>' . $staff->name . '</h6>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-warning btn-active-light-warning">₦' . number_format(($orderAmount - $discountAmount), 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-success btn-active-light-success">₦' . $amountPaid . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-dark btn-active-light-dark">₦' . $difference . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-secondary">' . $totalOrders . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-primary btn-active-light-primary">₦' . number_format($orderAmount, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-danger btn-active-light-danger">₦' . number_format($discountAmount, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-dark btn-active-light-dark">₦' . number_format($totalPayment, 2) . '</a>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-info btn-active-light-info">₦' . number_format($changeAmount, 2) . '</a>';
            $main_json[$i][$v++] = Carbon::parse($request->startDate)->isoFormat('ddd, DD/MMM/YYYY');
            $main_json[$i][$v++] = '<h6>' . $userName . '</h6>';
            $i++;
        }
        return response()->json(["returned_data" => $main_json]);

    }

    public function salesAuditsSummary(Request $request)
    {

    }
}
