<?php

namespace App\Http\Controllers;

use App\Models\Station;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class StationController extends Controller
{

    public function getStations(Request $request)
    {
        $stations = Station::all();
        return view("stations", compact("stations"));
    }

    public function ajaxStations(Request $request)
    {
        $stations = Station::all();

        $main_json = [];
        $i = 0;

        foreach ($stations as $station) {
            if ($station->station_status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $station->station_name;
            $main_json[$i][$v++] = $station->tax_rate.'%';
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $station->station_status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="' . $station->id . '" class="menu-link px-3 editStation">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="' . $station->id . '"
                    class="menu-link px-3 deleteStation"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $i++;
        }

        return response()->json(["returned_data" => $main_json]);
    }

    public function createStation(Request $request)
    {
        $station = new Station();
        $station->station_name = $request->stationName;
        $station->tax_rate = $request->taxRate;
        $station->save();

        return response()->json(["status" => "success"]);
    }

    public function editStationForm(Request $request)
    {
        $station = Station::find($request->stationId);
        $stationStatus = $station->station_status === 'Active' ? 'checked' : '';
        $title = "Edit Station";
        $body = "";
        $body .= '
                <form id="editStationForm">
                <input value="' . $station->id . '" name="stationId" class="d-none">
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Name</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter station name" name="stationName" value="' . $station->station_name . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Tax Rate(%)</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <input type="text" class="form-control form-control-solid" placeholder="Enter tax rate" name="taxRate" value="' . $station->tax_rate . '" />
                    <!--end::Input-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <!--end::Label-->
                    <!--begin::Input-->
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" id="stationStatus" name="stationStatus" ' . $stationStatus . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="stationStatus">
                            Active
                        </label>
                    </div>
                    <!--end::Input-->
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
                </form>
                           ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editStation(Request $request)
    {
        $station = Station::where("id", $request->stationId)->first();
        $station->station_name = $request->stationName;
        $station->tax_rate = $request->taxRate;
        if ($request->stationStatus) {
            $station->station_status = $request->stationStatus;
        } else {
            $station->station_status = "Inactive";
        }
        $station->save();

        return response()->json(["status" => "success"]);
    }

    public function deleteStation(Request $request)
    {
        $tables = Schema::getConnection()->getDoctrineSchemaManager()->listTableNames();
        foreach ($tables as $table) {
            if (Schema::hasColumn($table, 'station_id')) {
                $hasStationId = DB::table($table)->where('station_id', $request->stationId)->exists();
                if ($hasStationId) {
                    return response()->json(["status" => "failed", "message" => "Cannot delete, Station has data!"]);
                }
            }
        }
        Station::where("id", $request->stationId)->delete();
        return response()->json(["status" => "success"]);
    }
}
