<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\Station;
use App\Models\Transaction;
use App\Models\TransactionCategory;
use App\Models\TransactionSubcategory;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;

class TransactionController extends Controller
{
    
    public function getTransactions(Request $request){

        $startDate = isset($request->startDate) ? $request->startDate : \Carbon\Carbon::now()->format('Y-m-d');
        $endDate = isset($request->endDate) ? $request->endDate : $startDate;

        $transCategories = TransactionCategory::all();
        $branches = Branch::all();
        $stations = Station::all();
        return view("transactions", compact("transCategories", "branches", "startDate", "endDate", "stations"));
    }

    public function transactionsSummary(Request $request){
        $transactions = Transaction::orderByDesc("id");

        if ($request->has('startDate') && $request->has('endDate')) {
            $transactions->whereBetween('transaction_start_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $transactions->whereDate('transaction_start_date', $request->startDate);
        } else {
            $transactions->whereDate('transaction_start_date', now()->toDateString());
        }

        $transactions = $transactions->get();

        $totalTransactionAmount = $transactions->sum("transaction_amount");
        $totalIncome = $transactions->where("transaction_type", "Income")->sum("transaction_amount");
        $totalExpense = $transactions->where("transaction_type", "Expense")->sum("transaction_amount");
        $totalBalance = $totalIncome - $totalExpense;

        return response()->json(["status"=>"success", "totalTransactionAmount"=>number_format($totalTransactionAmount,2), "totalIncome"=>number_format($totalIncome,2), "totalExpense"=>number_format($totalExpense,2), "totalBalance"=>number_format($totalBalance,2)]);
    }

    public function ajaxTransactions(Request $request) {

        $transactions = Transaction::orderByDesc("id");

        if ($request->has('startDate') && $request->has('endDate')) {
            $transactions->whereBetween('transaction_start_date', [$request->startDate, $request->endDate]);
        } elseif ($request->has('startDate')) {
            $transactions->whereDate('transaction_start_date', $request->startDate);
        } else {
            $transactions->whereDate('transaction_start_date', now()->toDateString());
        }

        $transactions = $transactions->get();

        $main_json = [];
        $i = 0;

        foreach ($transactions as $transaction) {
            $branch = Branch::find($transaction->branch_id);
            // $transactionMode = $transaction->model_type;
            // if($transactionMode){
            //     if($transactionMode === "Store"){
            //         if($transaction->model_id){
            //             $store = Store::find($transaction->model_id);
            //             $assignedTo = isset($store) ? "---" : $store->store_name;
            //         }
            //         else{
            //             $assignedTo = "---";
            //         }
            //     }
            //     if($transactionMode === "Kitchen"){
            //         if($transaction->model_id){
            //             $kitchen = Kitchen::find($transaction->model_id);
            //             $assignedTo = isset($kitchen) ? $kitchen->kitchen_name : "---";
            //         }
            //         else{
            //             $assignedTo = "---";
            //         }
            //     }
            //     if($transactionMode === "Asset"){
            //         if($transaction->model_id){
            //             $asset = Asset::find($transaction->model_id);
            //             $assignedTo = isset($asset) ? $asset->asset_name : "---";
            //         }
            //         else{
            //             $assignedTo = "---";
            //         }
            //     }
            // }
            // else{
                $assignedTo = "---";
            // }
            $transSubCategory = TransactionSubcategory::where("id", $transaction->trans_subcategory_id)->first();
            $transCategory = TransactionCategory::where("id", $transSubCategory->trans_category_id)->first();
            $badge = $transaction->transaction_type === "Income" ? "badge-success" : "badge-danger";
            $v = 0;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
            Actions
            <i class="ki-duotone ki-down fs-5 ms-1"></i>
        </a>
        <div
            class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
            data-kt-menu="true"
        >
            <div class="menu-item px-3">
                <a href="#" data-id="'.$transaction->id.'" class="menu-link px-3 editTransaction">
                    Edit
                </a>
            </div>

            <div class="menu-item px-3">
                <a
                    href="#"
                    data-id="'.$transaction->id.'"
                    class="menu-link px-3 deleteTransaction"
                    data-kt-customer-table-filter="delete_row"
                >
                    Delete
                </a>
            </div>
        </div>';
            $main_json[$i][$v++] = '<h6>'.$transaction->transaction_number.'</h6>';
            $main_json[$i][$v++] = isset($branch) ? $branch->branch_name : "All Branch(es)";
            $main_json[$i][$v++] = '<span class="badge '.$badge.' p-3 z-depth-1">'.$transaction->transaction_type.'</span>';
            $main_json[$i][$v++] = $transCategory->category_name;
            $main_json[$i][$v++] = $transSubCategory->trans_subcategory_name;
            $main_json[$i][$v++] = $assignedTo;
            $main_json[$i][$v++] = '<a href="#" class="btn btn-outline btn-outline-dashed btn-outline-info btn-active-light-info">₦'.number_format($transaction->transaction_amount, 2).'</a>';
            $main_json[$i][$v++] = Carbon::parse($transaction->transaction_start_date)->isoFormat( 'ddd, DD/MMM/YYYY');
            $i++;
        }
        return response()->json(["returned_data"=> $main_json]);
    }

    public function generateTransactionNumber() {
        $transactionNumber = mt_rand(0, 999999999);
        if (strlen($transactionNumber) < 9) {
            $transactionNumber = str_pad($transactionNumber, 9, '0', STR_PAD_LEFT);
        }
        $transaction = Transaction::where("transaction_number", $transactionNumber)->first();
        if($transaction !== null){
            $this->generateTransactionNumber();
        }
        else{
            return $transactionNumber;
        }
    }

    public function createTransaction(Request $request){
        $transaction = new Transaction();
        $transaction->trans_subcategory_id = $request->transSubCategoryId;
        $transaction->transaction_start_date = $request->transactionDate;
        $transaction->branch_id = $request->branchId;
        if($request->transactionMode){
            $transaction->model_type = $request->transactionMode;
            if($request->transactionMode === "Store"){
                $transaction->model_id = $request->storeId;
            }
            if($request->transactionMode === "Asset"){
                $transaction->model_id = $request->assetId;
            }
            if($request->transactionMode === "Kitchen"){
                $transaction->model_id = $request->kitchenId;
            }
        }
        else{
            $transaction->model_type = NULL;
            $transaction->model_id = NULL;
        }
        $transaction->transaction_type = $request->transactionType;
        $transaction->transaction_number = $this->generateTransactionNumber();
        $transaction->transaction_amount = floatval($request->transactionAmount);
        $transaction->transaction_description = $request->transactionDescription;
        $transaction->created_by = Auth::user()->id;
        $transaction->save();
        return response()->json(["status"=>"success"]);
    }
}
