<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\ComputerOrder;
use App\Models\Department;
use App\Models\Kitchen;
use App\Models\Store;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;

class UserController extends Controller
{
    public function getUsers(Request $request)
    {
        $users = User::where("role", "!=", "Backend")->get();
        return view("users", compact("users"));
    }

    public function ajaxUsers(Request $request)
    {
        $users = User::all();

        $main_json = [];
        $i = 0;
        foreach ($users as $user) {
            if ($user->status === "Active") {
                $badge_class = "badge-success";
            } else {
                $badge_class = "badge-danger";
            }
            $v = 0;
            $main_json[$i][$v++] = $user->name;
            $main_json[$i][$v++] = $user->email;
            $main_json[$i][$v++] = $user->phone_number;
            $main_json[$i][$v++] = $user->pin;
            $main_json[$i][$v++] = '<span class="badge ' . $badge_class . '">' . $user->status . '</span>';
            $main_json[$i][$v++] = '<a href="#" class="btn btn-sm btn-light btn-flex btn-center btn-active-light-primary" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
                    Actions
                    <i class="ki-duotone ki-down fs-5 ms-1"></i>
                </a>
                <div
                    class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-125px py-4"
                    data-kt-menu="true"
                >
                    <div class="menu-item px-3">
                        <a href="#" data-id="' . $user->id . '" class="menu-link px-3 changeUserPin">
                            Change Pin
                        </a>
                    </div>

                    <div class="menu-item px-3">
                        <a href="#" data-id="' . $user->id . '" class="menu-link px-3 editUser">
                            Edit
                        </a>
                    </div>

                    <div class="menu-item px-3">
                        <a 
                            href="#"
                            data-id="' . $user->id . '"
                            class="menu-link px-3 deleteUser"
                            data-kt-customer-table-filter="delete_row"
                        >
                            Delete
                        </a>
                    </div>
                </div>';
            $i++;
        }
        return response()->json(["returned_data" => $main_json]);
    }

    public function createUser(Request $request)
    {
        $user = new User();
        $user->name = Str::upper($request->name);
        $user->email = Str::lower($request->email);
        $user->phone_number = $request->phoneNumber;
        $user->password = Hash::make($request->password);
        $user->role = $request->role;
        $user->status = isset($request->status) ? $request->status : "Inactive";
        $user->pin = $this->generateUserPin();
        $user->save();
        return response()->json(["status" => "success"]);
    }

    public function editUserForm(Request $request)
    {
        $user = User::find($request->userId);
        $status = $user->status === 'Active' ? 'checked' : '';

        $title = "Edit User";
        $body = "";
        $body .= '
            <form id="editUserForm">
                <input value="' . $user->id . '" name="userId" class="d-none">
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <label class="form-label">Name:</label>
                    <input type="text" name="name" value="' . $user->name . '" class="form-control mb-2 mb-md-0" placeholder="Enter name" />
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <label class="form-label">Email:</label>
                    <input type="email" name="email" value="' . $user->email . '" class="form-control mb-2 mb-md-0" placeholder="Enter email" />
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <label class="form-label">Phone Number:</label>
                    <input type="text" name="phoneNumber" value="' . $user->phone_number . '" class="form-control mb-2 mb-md-0" placeholder="Enter phone number" />
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <label class="form-label">User Password:</label>
                    <input type="password" name="userPassword" class="form-control mb-2 mb-md-0" placeholder="Enter user password" />
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <!--begin::Label-->
                    <label class="required fs-6 fw-semibold mb-2">Select Role</label>
                    <!--end::Label-->

                    <!--begin::Select-->
                    <select class="mb-2 editUserRole" id="editUserRole" data-live-search="true" data-width="100%" name="userRole" data-placeholder="Select role" data-dropdown-parent="#emptyModal">
                        <option value="Admin"';
        if ($user->role === "Admin") {
            $body .= 'selected';
        } else {
        }
        $body .= '>Admin</option>
                                            <option value="Store Keeper"';
        if ($user->role === "Store Keeper") {
            $body .= 'selected';
        } else {
        }
        $body .= '>Store Keeper</option>
                                            <option value="Cashier"';
        if ($user->role === "Cashier") {
            $body .= 'selected';
        } else {
        }
        $body .= '>Cashier</option>
                                            <option value="Supervisor"';
        if ($user->role === "Supervisor") {
            $body .= 'selected';
        } else {
        }
        $body .= '>Supervisor</option>
                                            <option value="Accountant"';
        if ($user->role === "Accountant") {
            $body .= 'selected';
        } else {
        }
        $body .= '>Accountant</option>
                                            <option value="Manager"';
        if ($user->role === "Manager") {
            $body .= 'selected';
        } else {
        }
        $body .= '>Manager</option>
                    </select>
                    <!--end::Select-->
                </div>
                <!--end::Input group-->
                <!--begin::Input group-->
                <div class="fv-row mb-7">
                    <label class="required fs-6 fw-semibold mb-2">Status</label>
                    <div class="form-check form-switch form-check-custom form-check-solid">
                        <input class="form-check-input" type="checkbox" value="Active" name="status" ' . $status . '>
                        <label class="form-check-label fw-semibold text-gray-400 ms-3" for="status">
                            Active
                        </label>
                    </div>
                </div>
                <!--end::Input group-->
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
            </form>
        ';

        return response()->json(["status" => "success", "body" => $body, "title" => $title]);
    }

    public function editUser(Request $request)
    {
        $user = User::find($request->userId);
        $oldPassword = $user->password;
        $user->role = $request->role;
        $user->name = Str::upper($request->name);
        $user->email = Str::lower($request->email);
        $user->phone_number = $request->phoneNumber;
        $user->password = isset($request->password) ? Hash::make($request->password) : $oldPassword;
        $user->status = isset($request->status) ? $request->status : "Inactive";
        $user->save();
        return response()->json(["status" => "success"]);
    }

    public function signInUser(Request $request)
    {
        $user = User::where('email', $request->email)->first();
        $currentPassword = $request->password;
        if ($user !== null) {
            if (Hash::check($currentPassword, $user->password)) {
                Auth::login($user);
                if (Auth::user()->role === "Admin") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("orders")]);
                } elseif (Auth::user()->role === "Store Keeper") {
                    if ($user->email !== "wisdom@citypot.com") {
                        return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("dispense_store_items")]);
                    }
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("stock_items")]);
                } elseif (Auth::user()->role === "Auditor") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("store_audits")]);
                } elseif (Auth::user()->role === "Chef") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("kitchen_stock_items")]);
                } elseif (Auth::user()->role === "Accountant") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("invoices")]);
                } elseif (Auth::user()->role === "Waiter") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("waiter_index")]);
                } elseif ($user->role === "Waiter_Cashier") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("waiter_cashier")]);
                } elseif ($user->role === "Station Manager") {
                    if ($user->email === "kitchen2@citypot.com") {
                        return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("kitchen_alerts")]);
                    }
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("station_manager")]);
                } elseif ($user->role === "Manager") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("sale_items")]);
                } elseif ($user->role === "Supervisor") {
                    return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("prepare_sale_items")]);
                }
            } else {
                return response()->json(["status" => "failed", "msg" => "User Details incorrect!"]);
            }
        } else {
            return response()->json(["status" => "failed", "msg" => "User not found!"]);
        }
    }

    public function signOutUser(Request $request)
    {
        Auth::logout();
        Session::flush();
        return redirect('/');
    }

    public function loginUser(Request $request)
    {
        Auth::logout();
        Session::flush();
        $computerId = isset($request->computerId) ? $request->computerId : null;
        Session::put("computerId", $computerId);
        ComputerOrder::where("computer_id", $computerId)->update(["order_id" => null]);
        return view('login');
    }

    public function posLoginUser(Request $request)
    {
        Auth::logout();
        $computerId = isset($request->computerId) ? $request->computerId : null;
        $keys = array_keys(Session::all());
        foreach ($keys as $key) {
            if ($key !== '_token' && $key !== '_previous') {
                Session::forget($key);
            }
        }
        if (isset($computerId)) {
            Session::put("computerId", $computerId);
            ComputerOrder::where("computer_id", $computerId)->update(["order_id" => null]);
        } else {
            Session::put("computerId", null);
        }
        return view('pos_login');
    }

    public function signOutPOS(Request $request)
    {
        Auth::logout();
        $computerId = isset($request->computerId) ? $request->computerId : null;
        $keys = array_keys(Session::all());
        foreach ($keys as $key) {
            if ($key !== '_token' && $key !== '_previous') {
                Session::forget($key);
            }
        }
        if (isset($computerId)) {
            Session::put("computerId", $computerId);
            ComputerOrder::where("computer_id", $computerId)->update(["order_id" => null]);
        } else {
            Session::put("computerId", null);
        }
        
        return view('login');
    }

    public function deleteUser(Request $request)
    {
        User::where("id", $request->userId)->delete();
        return response()->json(["status" => "success"]);
    }

    public function generateUserPin()
    {
        $userPin = mt_rand(0, 999999);
        if (strlen($userPin) < 6) {
            $userPin = str_pad($userPin, 6, '0', STR_PAD_LEFT);
        }
        $user = User::where("pin", $userPin)->first();
        if ($user !== null) {
            $this->generateUserPin();
        } else {
            return $userPin;
        }
    }

    public function changeUserPin(Request $request)
    {
        $user = User::find($request->userId);
        $user->pin = $this->generateUserPin();
        $user->save();
        return response()->json(["status" => "success"]);
    }

    public function signInWithPin(Request $request)
    {
        $computerId = Session::get("computerId");
        $userPin = $request->code_1 . $request->code_2 . $request->code_3 . $request->code_4 . $request->code_5 . $request->code_6;
        $user = User::where("pin", strval($userPin))->first();
        if ($user !== null) {
            Auth::login($user);
            if (Auth::user()->role === "Admin") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("orders")]);
            } elseif (Auth::user()->role === "Store Keeper") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("stock_items")]);
            } elseif (Auth::user()->role === "Auditor") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("store_audits")]);
            } elseif (Auth::user()->role === "Chef") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("kitchen_stock_items")]);
            } elseif (Auth::user()->role === "Accountant") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("invoices")]);
            } elseif (Auth::user()->role === "Cashier") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("point_of_sale?computerId=1")]);
            } elseif (Auth::user()->role === "Waiter") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("point_of_sale?computerId=1")]);
            } elseif ($user->role === "Waiter_Cashier") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("waiter_cashier")]);
            } elseif ($user->role === "Station Manager") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("station_manager")]);
            } elseif ($user->role === "Supervisor") {
                return response()->json(["status" => "success", "msg" => "User Logged In!", "url" => url("prepare_sale_items")]);
            }
        } else {
            return response()->json(["status" => "failed", "msg" => "User not found!"]);
        }
    }

    public function createAdmin(Request $request)
    {
        $zeonPOSUser = User::where("name", "Zeon POS")->where("role", "Admin")->first();
        if (!$zeonPOSUser) {
            $user = new User();
            $user->name = "Zeon POS";
            $user->role = "Admin";
            $user->password = Hash::make("password");
            $user->email = "admin@zeonpos.com";
            $user->phone_number = "09055555414";
            $user->status = "Active";
            $user->pin = $this->generateUserPin();
            $user->save();
        }
        return response()->json(["status" => "success"]);
    }
}
