<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\BranchController;
use App\Http\Controllers\ContactController;
use App\Http\Controllers\ContactGroupController;
use App\Http\Controllers\ComputerOrderController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\DeliveryLocationController;
use App\Http\Controllers\DeliveryCompanyController;
use App\Http\Controllers\DeliveryPriceController;
use App\Http\Controllers\POSAuditController;
use App\Http\Controllers\ItemCategoryController;
use App\Http\Controllers\ItemMeasurementController;
use App\Http\Controllers\PurchaseController;
use App\Http\Controllers\ReportController;
use App\Http\Controllers\ItemCheckController;
use App\Http\Controllers\ItemContactGroupController;
use App\Http\Controllers\ItemPurchaseController;
use App\Http\Controllers\ItemWasteController;
use App\Http\Controllers\WasteController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\SalesAuditController;
use App\Http\Controllers\OrderPaymentController;
use App\Http\Controllers\ItemController;
use App\Http\Controllers\MeasurementController;
use App\Http\Controllers\MedicationPlanController;
use App\Http\Controllers\MedicationController;
use App\Http\Controllers\PaymentMethodController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\StationController;
use App\Http\Controllers\TransactionController;
use App\Http\Controllers\TransactionCategoryController;
use App\Http\Controllers\TransactionSubcategoryController;
use App\Http\Controllers\TransactionPaymentController;
use Illuminate\Support\Facades\Session;

Route::get('point_of_sale', function () {
    // Session::put("orderId", 1);
    return view('point_of_sale');
});

Route::get('report', [OrderController::class, 'report']);
Route::post('update_comment', [OrderController::class, 'updateComment']);
Route::get('print_report', [OrderController::class, 'printReport']);
Route::get('wastes_summary', function () {
    return response()->json(["status" => "success"]);
});

Route::get('generate_barcode', [PurchaseController::class, 'generateBarcode']);
Route::get('computer_orders', [ComputerOrderController::class, 'computerOrders']);
Route::get('login', [UserController::class, 'loginUser'])->name("login");
Route::get('pos_login', [UserController::class, 'posLoginUser']);
Route::post('sign_in', [UserController::class, 'signInUser']);
Route::post('sign_in_pos', [UserController::class, 'signInWithPin']);
Route::post('sign_out_pos', [UserController::class, 'signOutPOS'])->name("signoutpos");
Route::get('sign_out', [UserController::class, 'signOutUser'])->name("signout");


Route::get('stocks', [PurchaseController::class, 'getStocks']);
Route::post('add_stock', [PurchaseController::class, 'addStock']);
// Route::get('former_stock', [PurchaseController::class, 'formerStock']);
Route::delete('delete_stock', [PurchaseController::class, 'deleteStock']);
Route::get('view_purchase_items', [PurchaseController::class, 'viewPurchaseItems']);
Route::get('edit_purchase_form', [PurchaseController::class, 'editPurchaseForm']);
Route::delete('delete_item_purchase', [ItemPurchaseController::class, 'deleteItemPurchase']);
Route::post('edit_item_purchase', [ItemPurchaseController::class, 'editItemPurchase']);
Route::post('add_item_purchase', [PurchaseController::class, 'addItemToPurchase']);

Route::get('/', function () {
    $authCheck = \Illuminate\Support\Facades\Auth::check();
    if ($authCheck) {
        $user = \Illuminate\Support\Facades\Auth::user();
        $computerId = Session::get('computerId');
        if ($user->role === "Admin") {
            return redirect('orders');
        } elseif ($user->role === "Store Keeper") {
            if ($user->email !== "wisdom@citypot.com") {
                return redirect('dispense_store_items');
            }
            return redirect('stock_items');
        } elseif ($user->role === "Auditor") {
            return redirect('store_audits');
        } elseif ($user->role === "Chef") {
            return redirect('kitchen_stock_items');
        } elseif ($user->role === "Accountant") {
            return redirect('invoices');
        } elseif ($user->role === "Waiter") {
            return redirect('waiter_index');
        } elseif ($user->role === "Waiter_Cashier") {
            return redirect('waiter_cashier');
        } elseif ($user->role === "Station Manager") {
            if ($user->email === "kitchen2@citypot.com") {
                return redirect('kitchen_alerts');
            }
            return redirect('station_manager');
        } elseif ($user->role === "Manager") {
            return redirect('items');
        } elseif ($user->role === "Supervisor") {
            return redirect('item_checks');
        } elseif ($user->role === "Cashier") {
            return redirect('point_of_sale?computerId=1');
        }
    } else {
        return view('login');
    }
});

Route::get('pos_audits', [POSAuditController::class, 'getPOSAudits']);
Route::get('payments_audit', [SalesAuditController::class, 'posAuditSummary']);
Route::get('cashier_audit', [SalesAuditController::class, 'getCashierAudit']);
Route::put('audit_cashier', [SalesAuditController::class, 'auditCashier']);
Route::get('ajax_sales_pos_audits', [POSAuditController::class, 'ajaxSalesPOSAudits']);
Route::get('pos_audits_summary', [POSAuditController::class, 'posAuditsSummary']);
Route::get('ajax_pos_audits', [POSAuditController::class, 'ajaxPOSAudits']);
Route::post('create_pos_audit', [POSAuditController::class, 'createPOSAudit']);
Route::get('edit_pos_audit_form', [POSAuditController::class, 'editPOSAuditForm']);
Route::put('edit_pos_audit', [POSAuditController::class, 'editPOSAudit']);
Route::delete('delete_pos_audit', [POSAuditController::class, 'deletePOSAudit']);

Route::get('print_customer_bill', [OrderController::class, 'printCustomerBill']);

Route::get('customer_view', [OrderController::class, 'getCustomerView']);
Route::get('customer_current_order_div', [OrderController::class, 'customerCurrentOrderDiv']);
Route::get('customer_order_summary_div', [OrderController::class, 'customerOrderSummaryDiv']);

Route::middleware(['auth:web'])->group(function () {

    Route::get('transactions', [TransactionController::class, 'getTransactions']);
    Route::get('transactions_summary', [TransactionController::class, 'transactionsSummary']);
    Route::post('create_transaction', [TransactionController::class, 'createTransaction']);
    Route::get('ajax_transactions', [TransactionController::class, 'ajaxTransactions']);


    Route::get('dashboard', [DashboardController::class, 'getDashboard']);
    Route::get('month_summary', [DashboardController::class, 'getMonthSummary']);
    Route::get('dashboard_sale_items_summary', [DashboardController::class, 'saleItemsSummary']);
    Route::get('stations_summary', [DashboardController::class, 'stationsSummary']);
    Route::get('sales_chart', [DashboardController::class, 'monthlySalesAnalysis']);
    Route::get('net_profits_chart', [DashboardController::class, 'yearlyNetProfitAnalysis']);

    Route::get('sales_audit', [SalesAuditController::class, 'getSalesAudit']);
    Route::get('ajax_sales_audit', [SalesAuditController::class, 'ajaxSalesAudit']);

    Route::get('ajax_sales_report', [ReportController::class, 'ajaxSalesReport']);
    Route::get('sales_report', [ReportController::class, 'getSalesReport']);
    Route::get('view_sales_report', [ReportController::class, 'viewSalesReport']);
    
    Route::get('print_barcode', [ItemController::class, 'printBarcode']);

    Route::get('ajax_item_purchases_report', [ReportController::class, 'ajaxItemPurchasesReport']);
    Route::get('ajax_purchases_report', [ReportController::class, 'ajaxPurchasesReport']);
    Route::get('purchases_report', [ReportController::class, 'getPurchasesReport']);

    Route::get('ajax_items_stock', [ReportController::class, 'ajaxItemsStock']);
    Route::get('ajax_stock_report', [ReportController::class, 'ajaxStockReport']);
    Route::get('stock_report', [ReportController::class, 'getStockReport']);
    Route::get('view_item_stock_report', [ReportController::class, 'viewItemStockReport']);

    Route::post('make_order_payments', [OrderPaymentController::class, 'makeOrderPayments']);
    Route::get('view_order_payments', [OrderPaymentController::class, 'orderPayments']);

    Route::get('item_checks', [ItemCheckController::class, 'getItemChecks']);
    Route::get('ajax_item_checks', [ItemCheckController::class, 'ajaxItemChecks']);

    Route::get('wastes', [WasteController::class, 'getWastes']);
    Route::get('wastes_summary', [WasteController::class, 'wastesSummary']);
    Route::post('add_waste', [WasteController::class, 'addWaste']);
    Route::get('ajax_wastes', [WasteController::class, 'ajaxWastes']);

    Route::get('item_wastes', [ItemWasteController::class, 'getItemWastes']);
    Route::get('ajax_item_wastes', [ItemWasteController::class, 'ajaxItemWastes']);
    Route::get('view_item_wastes', [ItemWasteController::class, 'viewItemWastes']);

    Route::get('orders', [OrderController::class, 'orders']);
    Route::get('orders_summary', [OrderController::class, 'ordersSummary']);
    Route::get('view_item_orders', [OrderController::class, 'viewItemOrders']);
    Route::post('revert_order', [OrderController::class, 'revertOrder']);
    Route::post('recall_order', [OrderController::class, 'recallOrder']);
    Route::post('clear_order', [OrderController::class, 'clearOrder']);
    Route::delete('delete_order', [OrderController::class, 'deleteOrder']);
    Route::post('settle_order', [OrderController::class, 'settleOrder']);
    Route::post('save_order', [OrderController::class, 'saveOrder']);
    Route::get('print_order', [OrderController::class, 'printOrder']);
    Route::get('ajax_orders', [OrderController::class, 'ajaxOrders']);
    Route::get('ajax_pos_orders', [OrderController::class, 'ajaxPOSOrders']);
    Route::get('point_of_sale', [OrderController::class, 'pointOfSale']);
    Route::get('point_of_sale_summary', [OrderController::class, 'pointOfSaleSummary']);

    Route::get('current_order_div', [OrderController::class, 'currentOrderDiv']);
    Route::get('order_summary_div', [OrderController::class, 'orderSummaryDiv']);

    Route::post('add_item_to_order', [OrderController::class, 'addItemToOrder']);
    Route::post('add_item_purchase_to_order', [OrderController::class, 'addItemPurchaseToOrder']);
    Route::post('increase_item_order', [OrderController::class, 'increaseItemOrder']);
    Route::post('update_item_order_quantity', [OrderController::class, 'updateItemOrderQuantity']);
    Route::post('decrease_item_order', [OrderController::class, 'decreaseItemOrder']);
    Route::post('update_order_customer', [OrderController::class, 'updateOrderCustomer']);
    Route::post('update_item_order_measurement', [OrderController::class, 'updateItemOrderMeasurement']);

    Route::get('item_measurements', [ItemMeasurementController::class, 'getItemMeasurements']);
    Route::post('create_item_measurement', [ItemMeasurementController::class, 'createItemMeasurement']);
    Route::get('edit_item_measurement_form', [ItemMeasurementController::class, 'editItemMeasurementForm']);
    Route::put('edit_item_measurement', [ItemMeasurementController::class, 'editItemMeasurement']);
    Route::delete('delete_item_measurement', [ItemMeasurementController::class, 'deleteItemMeasurement']);


    Route::get('measurements', [MeasurementController::class, 'getMeasurements']);
    Route::get('ajax_measurements', [MeasurementController::class, 'ajaxMeasurements']);
    Route::post('create_measurements', [MeasurementController::class, 'createMeasurements']);
    Route::get('edit_measurement_form', [MeasurementController::class, 'editMeasurementForm']);
    Route::put('edit_measurement', [MeasurementController::class, 'editMeasurement']);
    Route::delete('delete_measurement', [MeasurementController::class, 'deleteMeasurement']);


    Route::get('medication_plans', [MedicationPlanController::class, 'getMedicationPlans']);
    Route::get('ajax_medication_plans', [MedicationPlanController::class, 'ajaxMedicationPlans']);
    Route::post('create_medication_plan', [MedicationPlanController::class, 'createMedicationPlan']);
    Route::get('edit_medication_plan_form', [MedicationPlanController::class, 'editMeasurementForm']);
    Route::put('edit_medication_plan', [MedicationPlanController::class, 'editMeasurement']);
    Route::delete('delete_medication_plan', [MedicationPlanController::class, 'deleteMeasurement']);


    Route::get('medications', [MedicationController::class, 'getMedications']);
    Route::get('ajax_medications', [MedicationController::class, 'ajaxMedications']);
    Route::post('create_medication', [MedicationController::class, 'createMedication']);
    Route::get('edit_medication_form', [MedicationController::class, 'editMedicationForm']);
    Route::put('edit_medication', [MedicationController::class, 'editMedication']);
    Route::delete('delete_medication', [MedicationController::class, 'deleteMedication']);



    Route::get('item_contact_groups', [ItemContactGroupController::class, 'itemContactGroups']);
    Route::post('update_item_contact_groups', [ItemContactGroupController::class, 'updateItemContactGroups']);

    Route::get('payment_methods', [PaymentMethodController::class, 'getPaymentMethods']);
    Route::get('ajax_payment_methods', [PaymentMethodController::class, 'ajaxPaymentMethods']);
    Route::post('create_payment_method', [PaymentMethodController::class, 'createPaymentMethod']);
    Route::get('edit_payment_method_form', [PaymentMethodController::class, 'editPaymentMethodForm']);
    Route::post('edit_payment_method', [PaymentMethodController::class, 'editPaymentMethod']);
    Route::delete('delete_payment_method', [PaymentMethodController::class, 'deletePaymentMethod']);


    Route::get('item_purchases', [ItemPurchaseController::class, 'itemPurchases']);

    Route::get('purchases', [PurchaseController::class, 'getPurchases']);
    Route::get('price_check', [PurchaseController::class, 'priceCheck']);
    Route::get('purchases_summary', [PurchaseController::class, 'getPurchasesSummary']);
    Route::get('ajax_purchases', [PurchaseController::class, 'ajaxPurchases']);
    Route::post('add_purchase', [PurchaseController::class, 'addPurchase']);
    Route::delete('delete_purchase', [PurchaseController::class, 'deletePurchase']);

    Route::get('branches', [BranchController::class, 'getBranches']);
    Route::get('ajax_branches', [BranchController::class, 'ajaxBranches']);
    Route::post('create_branch', [BranchController::class, 'createBranch']);
    Route::get('edit_branch_form', [BranchController::class, 'editBranchForm']);
    Route::put('edit_branch', [BranchController::class, 'editBranch']);
    Route::delete('delete_branch', [BranchController::class, 'deleteBranch']);


    Route::get('stations', [StationController::class, 'getStations']);
    Route::get('ajax_stations', [StationController::class, 'ajaxStations']);
    Route::post('create_station', [StationController::class, 'createStation']);
    Route::get('edit_station_form', [StationController::class, 'editStationForm']);
    Route::put('edit_station', [StationController::class, 'editStation']);
    Route::delete('delete_station', [StationController::class, 'deleteStation']);



    Route::get('delivery_locations', [DeliveryLocationController::class, 'getDeliveryLocations']);
    Route::get('ajax_delivery_locations', [DeliveryLocationController::class, 'ajaxDeliveryLocations']);
    Route::post('create_delivery_location', [DeliveryLocationController::class, 'createDeliveryLocation']);
    Route::get('edit_delivery_location_form', [DeliveryLocationController::class, 'editDeliveryLocationForm']);
    Route::post('edit_delivery_location', [DeliveryLocationController::class, 'editDeliveryLocation']);
    Route::delete('delete_delivery_location', [DeliveryLocationController::class, 'deleteDeliveryLocation']);


    Route::get('delivery_companies', [DeliveryCompanyController::class, 'getDeliveryCompanies']);
    Route::get('ajax_delivery_companies', [DeliveryCompanyController::class, 'ajaxDeliveryCompanies']);
    Route::post('create_delivery_company', [DeliveryCompanyController::class, 'createDeliveryCompany']);
    Route::get('edit_delivery_company_form', [DeliveryCompanyController::class, 'editDeliveryCompanyForm']);
    Route::post('edit_delivery_company', [DeliveryCompanyController::class, 'editDeliveryCompany']);
    Route::delete('delete_delivery_company', [DeliveryCompanyController::class, 'deleteDeliveryCompany']);


    Route::get('item_categories', [ItemCategoryController::class, 'getItemCategories']);
    Route::post('create_item_category', [ItemCategoryController::class, 'createItemCategory']);
    Route::post('create_item_categories', [ItemCategoryController::class, 'createItemCategories']);
    Route::get('edit_item_category_form', [ItemCategoryController::class, 'editItemCategoryForm']);
    Route::put('edit_item_category', [ItemCategoryController::class, 'editItemCategory']);
    Route::delete('delete_item_category', [ItemCategoryController::class, 'deleteItemCategory']);



    Route::get('items', [ItemController::class, 'getItems']);
    Route::get('items_summary', [ItemController::class, 'itemsSummary']);
    Route::get('ajax_items', [ItemController::class, 'ajaxItems']);
    Route::post('create_item', [ItemController::class, 'createItem']);
    Route::get('edit_item_form', [ItemController::class, 'editItemForm']);
    Route::post('edit_item', [ItemController::class, 'editItem']);


    Route::get('pricing_items', [ItemController::class, 'getPricingItems']);
    Route::get('ajax_pricing_items', [ItemController::class, 'ajaxPricingItems']);


    Route::get('pricing_items_summary', [ItemController::class, 'pricingItemsSummary']);
    Route::get('ajax_adjust_pricing', [ItemController::class, 'ajaxAdjustPricing']);
    Route::post('adjust_prices', [ItemController::class, 'adjustPrices']);
    Route::get('price_log', [ItemController::class, 'getPriceLog']);
    Route::get('price_review_log', [ItemController::class, 'priceReviewLog']);



    Route::get('contacts', [ContactController::class, 'getContacts']);
    Route::get('get_contacts', [ContactController::class, 'ajaxGetContacts']);
    Route::get('ajax_contacts', [ContactController::class, 'ajaxContacts']);
    Route::post('create_contact', [ContactController::class, 'createContact']);
    Route::post('create_contacts', [ContactController::class, 'createContacts']);
    Route::get('edit_contact_form', [ContactController::class, 'editContactForm']);
    Route::put('edit_contact', [ContactController::class, 'editContact']);
    Route::delete('delete_contact', [ContactController::class, 'deleteContact']);


    Route::get('contact_groups', [ContactGroupController::class, 'getContactGroups']);
    Route::post('create_contact_group', [ContactGroupController::class, 'createContactGroup']);
    Route::post('create_contact_groups', [ContactGroupController::class, 'createContactGroup']);
    Route::get('edit_contact_group_form', [ContactGroupController::class, 'editContactGroupForm']);
    Route::put('edit_contact_group', [ContactGroupController::class, 'editContactGroup']);
    Route::delete('delete_contact_group', [ContactGroupController::class, 'deleteContactGroupForm']);



    Route::get('users', [UserController::class, 'getUsers']);
    Route::get('ajax_users', [UserController::class, 'ajaxUsers']);
    Route::post('create_user', [UserController::class, 'createUser']);
    Route::post('change_user_pin', [UserController::class, 'changeUserPin']);
    Route::get('edit_user_form', [UserController::class, 'editUserForm']);
    Route::put('edit_user', [UserController::class, 'editUser']);
    Route::delete('delete_user', [UserController::class, 'deleteUser']);
    Route::get('create_admin', [UserController::class, 'createAdmin']);

});